#[non_exhaustive]pub enum AddArtifactError {
AccessDeniedException(AccessDeniedException),
InternalServerException(InternalServerException),
ResourceNotFoundException(ResourceNotFoundException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the AddArtifactError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Request denied due to insufficient permissions
InternalServerException(InternalServerException)
Unexpected server error occurred
ResourceNotFoundException(ResourceNotFoundException)
Specified resource was not found
ThrottlingException(ThrottlingException)
Request denied due to throttling
ValidationException(ValidationException)
A standard error for input validation failures. This should be thrown by services when a member of the input structure falls outside of the modeled or documented constraints.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl AddArtifactError
impl AddArtifactError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the AddArtifactError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the AddArtifactError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is AddArtifactError::AccessDeniedException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is AddArtifactError::InternalServerException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is AddArtifactError::ResourceNotFoundException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is AddArtifactError::ThrottlingException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is AddArtifactError::ValidationException.