#[non_exhaustive]pub struct BatchCreateSecurityRequirementsOutputBuilder { /* private fields */ }Expand description
A builder for BatchCreateSecurityRequirementsOutput.
Implementations
Sourceimpl BatchCreateSecurityRequirementsOutputBuilder
impl BatchCreateSecurityRequirementsOutputBuilder
Sourcepub fn security_requirements(
self,
input: BatchCreateSecurityRequirementResult,
) -> Self
pub fn security_requirements( self, input: BatchCreateSecurityRequirementResult, ) -> Self
Appends an item to security_requirements.
To override the contents of this collection use set_security_requirements.
The list of security requirements that were successfully created.
Sourcepub fn set_security_requirements(
self,
input: Option<Vec<BatchCreateSecurityRequirementResult>>,
) -> Self
pub fn set_security_requirements( self, input: Option<Vec<BatchCreateSecurityRequirementResult>>, ) -> Self
The list of security requirements that were successfully created.
Sourcepub fn get_security_requirements(
&self,
) -> &Option<Vec<BatchCreateSecurityRequirementResult>>
pub fn get_security_requirements( &self, ) -> &Option<Vec<BatchCreateSecurityRequirementResult>>
The list of security requirements that were successfully created.
Sourcepub fn errors(self, input: BatchSecurityRequirementError) -> Self
pub fn errors(self, input: BatchSecurityRequirementError) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
The list of errors for security requirements that failed to be created.
Sourcepub fn set_errors(
self,
input: Option<Vec<BatchSecurityRequirementError>>,
) -> Self
pub fn set_errors( self, input: Option<Vec<BatchSecurityRequirementError>>, ) -> Self
The list of errors for security requirements that failed to be created.
Sourcepub fn get_errors(&self) -> &Option<Vec<BatchSecurityRequirementError>>
pub fn get_errors(&self) -> &Option<Vec<BatchSecurityRequirementError>>
The list of errors for security requirements that failed to be created.
Sourcepub fn build(self) -> Result<BatchCreateSecurityRequirementsOutput, BuildError>
pub fn build(self) -> Result<BatchCreateSecurityRequirementsOutput, BuildError>
Consumes the builder and constructs a BatchCreateSecurityRequirementsOutput.
This method will fail if any of the following fields are not set: