#[non_exhaustive]pub struct BatchCreateSecurityRequirementsOutput {
pub security_requirements: Vec<BatchCreateSecurityRequirementResult>,
pub errors: Vec<BatchSecurityRequirementError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_requirements: Vec<BatchCreateSecurityRequirementResult>The list of security requirements that were successfully created.
errors: Vec<BatchSecurityRequirementError>The list of errors for security requirements that failed to be created.
Implementations
Sourceimpl BatchCreateSecurityRequirementsOutput
impl BatchCreateSecurityRequirementsOutput
Sourcepub fn security_requirements(&self) -> &[BatchCreateSecurityRequirementResult]
pub fn security_requirements(&self) -> &[BatchCreateSecurityRequirementResult]
The list of security requirements that were successfully created.
Sourcepub fn errors(&self) -> &[BatchSecurityRequirementError]
pub fn errors(&self) -> &[BatchSecurityRequirementError]
The list of errors for security requirements that failed to be created.
Sourceimpl BatchCreateSecurityRequirementsOutput
impl BatchCreateSecurityRequirementsOutput
Sourcepub fn builder() -> BatchCreateSecurityRequirementsOutputBuilder
pub fn builder() -> BatchCreateSecurityRequirementsOutputBuilder
Creates a new builder-style object to manufacture BatchCreateSecurityRequirementsOutput.