pub struct BatchDeleteCodeReviewsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchDeleteCodeReviews.
Deletes one or more code reviews from an agent space.
Implementations
Sourceimpl BatchDeleteCodeReviewsFluentBuilder
impl BatchDeleteCodeReviewsFluentBuilder
Sourcepub fn as_input(&self) -> &BatchDeleteCodeReviewsInputBuilder
pub fn as_input(&self) -> &BatchDeleteCodeReviewsInputBuilder
Access the BatchDeleteCodeReviews as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchDeleteCodeReviewsOutput, SdkError<BatchDeleteCodeReviewsError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchDeleteCodeReviewsOutput, SdkError<BatchDeleteCodeReviewsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchDeleteCodeReviewsOutput, BatchDeleteCodeReviewsError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchDeleteCodeReviewsOutput, BatchDeleteCodeReviewsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn code_review_ids(self, input: impl Into<String>) -> Self
pub fn code_review_ids(self, input: impl Into<String>) -> Self
Appends an item to codeReviewIds.
To override the contents of this collection use set_code_review_ids.
The list of code review identifiers to delete.
Sourcepub fn set_code_review_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_code_review_ids(self, input: Option<Vec<String>>) -> Self
The list of code review identifiers to delete.
Sourcepub fn get_code_review_ids(&self) -> &Option<Vec<String>>
pub fn get_code_review_ids(&self) -> &Option<Vec<String>>
The list of code review identifiers to delete.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the code reviews to delete.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the code reviews to delete.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the code reviews to delete.