#[non_exhaustive]pub struct BatchDeleteCodeReviewsInputBuilder { /* private fields */ }Expand description
A builder for BatchDeleteCodeReviewsInput.
Implementations
Sourceimpl BatchDeleteCodeReviewsInputBuilder
impl BatchDeleteCodeReviewsInputBuilder
Sourcepub fn code_review_ids(self, input: impl Into<String>) -> Self
pub fn code_review_ids(self, input: impl Into<String>) -> Self
Appends an item to code_review_ids.
To override the contents of this collection use set_code_review_ids.
The list of code review identifiers to delete.
Sourcepub fn set_code_review_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_code_review_ids(self, input: Option<Vec<String>>) -> Self
The list of code review identifiers to delete.
Sourcepub fn get_code_review_ids(&self) -> &Option<Vec<String>>
pub fn get_code_review_ids(&self) -> &Option<Vec<String>>
The list of code review identifiers to delete.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the code reviews to delete.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the code reviews to delete.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the code reviews to delete.
Sourcepub fn build(self) -> Result<BatchDeleteCodeReviewsInput, BuildError>
pub fn build(self) -> Result<BatchDeleteCodeReviewsInput, BuildError>
Consumes the builder and constructs a BatchDeleteCodeReviewsInput.
Sourceimpl BatchDeleteCodeReviewsInputBuilder
impl BatchDeleteCodeReviewsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchDeleteCodeReviewsOutput, SdkError<BatchDeleteCodeReviewsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchDeleteCodeReviewsOutput, SdkError<BatchDeleteCodeReviewsError, HttpResponse>>
Sends a request with this input using the given client.