#[non_exhaustive]pub struct BatchDeleteCodeReviewsInput {
pub code_review_ids: Option<Vec<String>>,
pub agent_space_id: Option<String>,
}Expand description
Input for deleting multiple code reviews.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_ids: Option<Vec<String>>The list of code review identifiers to delete.
agent_space_id: Option<String>The unique identifier of the agent space that contains the code reviews to delete.
Implementations
Sourceimpl BatchDeleteCodeReviewsInput
impl BatchDeleteCodeReviewsInput
Sourcepub fn code_review_ids(&self) -> &[String]
pub fn code_review_ids(&self) -> &[String]
The list of code review identifiers to delete.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .code_review_ids.is_none().
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the code reviews to delete.
Sourceimpl BatchDeleteCodeReviewsInput
impl BatchDeleteCodeReviewsInput
Sourcepub fn builder() -> BatchDeleteCodeReviewsInputBuilder
pub fn builder() -> BatchDeleteCodeReviewsInputBuilder
Creates a new builder-style object to manufacture BatchDeleteCodeReviewsInput.