#[non_exhaustive]pub struct BatchDeleteCodeReviewsOutput {
pub deleted: Option<Vec<String>>,
pub failed: Option<Vec<DeleteCodeReviewFailure>>,
/* private fields */
}Expand description
Output for the BatchDeleteCodeReviews operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deleted: Option<Vec<String>>The list of identifiers of the code reviews that were successfully deleted.
failed: Option<Vec<DeleteCodeReviewFailure>>The list of code reviews that failed to delete, including the reason for each failure.
Implementations
Sourceimpl BatchDeleteCodeReviewsOutput
impl BatchDeleteCodeReviewsOutput
Sourcepub fn deleted(&self) -> &[String]
pub fn deleted(&self) -> &[String]
The list of identifiers of the code reviews that were successfully deleted.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .deleted.is_none().
Sourcepub fn failed(&self) -> &[DeleteCodeReviewFailure]
pub fn failed(&self) -> &[DeleteCodeReviewFailure]
The list of code reviews that failed to delete, including the reason for each failure.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .failed.is_none().
Sourceimpl BatchDeleteCodeReviewsOutput
impl BatchDeleteCodeReviewsOutput
Sourcepub fn builder() -> BatchDeleteCodeReviewsOutputBuilder
pub fn builder() -> BatchDeleteCodeReviewsOutputBuilder
Creates a new builder-style object to manufacture BatchDeleteCodeReviewsOutput.