#[non_exhaustive]pub struct BatchDeletePentestsInput {
pub pentest_ids: Option<Vec<String>>,
pub agent_space_id: Option<String>,
}Expand description
Input for deleting multiple pentests
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_ids: Option<Vec<String>>List of pentest IDs to delete
agent_space_id: Option<String>ID of the agent space where the pentests exist
Implementations
Sourceimpl BatchDeletePentestsInput
impl BatchDeletePentestsInput
Sourcepub fn pentest_ids(&self) -> &[String]
pub fn pentest_ids(&self) -> &[String]
List of pentest IDs to delete
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .pentest_ids.is_none().
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
ID of the agent space where the pentests exist
Sourceimpl BatchDeletePentestsInput
impl BatchDeletePentestsInput
Sourcepub fn builder() -> BatchDeletePentestsInputBuilder
pub fn builder() -> BatchDeletePentestsInputBuilder
Creates a new builder-style object to manufacture BatchDeletePentestsInput.