#[non_exhaustive]pub struct BatchDeleteSecurityRequirementsOutputBuilder { /* private fields */ }Expand description
A builder for BatchDeleteSecurityRequirementsOutput.
Implementations
Sourceimpl BatchDeleteSecurityRequirementsOutputBuilder
impl BatchDeleteSecurityRequirementsOutputBuilder
Sourcepub fn deleted_security_requirement_names(
self,
input: impl Into<String>,
) -> Self
pub fn deleted_security_requirement_names( self, input: impl Into<String>, ) -> Self
Appends an item to deleted_security_requirement_names.
To override the contents of this collection use set_deleted_security_requirement_names.
The list of security requirement names that were successfully deleted.
Sourcepub fn set_deleted_security_requirement_names(
self,
input: Option<Vec<String>>,
) -> Self
pub fn set_deleted_security_requirement_names( self, input: Option<Vec<String>>, ) -> Self
The list of security requirement names that were successfully deleted.
Sourcepub fn get_deleted_security_requirement_names(&self) -> &Option<Vec<String>>
pub fn get_deleted_security_requirement_names(&self) -> &Option<Vec<String>>
The list of security requirement names that were successfully deleted.
Sourcepub fn errors(self, input: BatchSecurityRequirementError) -> Self
pub fn errors(self, input: BatchSecurityRequirementError) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
The list of errors for security requirements that failed to be deleted.
Sourcepub fn set_errors(
self,
input: Option<Vec<BatchSecurityRequirementError>>,
) -> Self
pub fn set_errors( self, input: Option<Vec<BatchSecurityRequirementError>>, ) -> Self
The list of errors for security requirements that failed to be deleted.
Sourcepub fn get_errors(&self) -> &Option<Vec<BatchSecurityRequirementError>>
pub fn get_errors(&self) -> &Option<Vec<BatchSecurityRequirementError>>
The list of errors for security requirements that failed to be deleted.
Sourcepub fn build(self) -> Result<BatchDeleteSecurityRequirementsOutput, BuildError>
pub fn build(self) -> Result<BatchDeleteSecurityRequirementsOutput, BuildError>
Consumes the builder and constructs a BatchDeleteSecurityRequirementsOutput.
This method will fail if any of the following fields are not set: