#[non_exhaustive]pub struct BatchDeleteSecurityRequirementsOutput {
pub deleted_security_requirement_names: Vec<String>,
pub errors: Vec<BatchSecurityRequirementError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deleted_security_requirement_names: Vec<String>The list of security requirement names that were successfully deleted.
errors: Vec<BatchSecurityRequirementError>The list of errors for security requirements that failed to be deleted.
Implementations
Sourceimpl BatchDeleteSecurityRequirementsOutput
impl BatchDeleteSecurityRequirementsOutput
Sourcepub fn deleted_security_requirement_names(&self) -> &[String]
pub fn deleted_security_requirement_names(&self) -> &[String]
The list of security requirement names that were successfully deleted.
Sourcepub fn errors(&self) -> &[BatchSecurityRequirementError]
pub fn errors(&self) -> &[BatchSecurityRequirementError]
The list of errors for security requirements that failed to be deleted.
Sourceimpl BatchDeleteSecurityRequirementsOutput
impl BatchDeleteSecurityRequirementsOutput
Sourcepub fn builder() -> BatchDeleteSecurityRequirementsOutputBuilder
pub fn builder() -> BatchDeleteSecurityRequirementsOutputBuilder
Creates a new builder-style object to manufacture BatchDeleteSecurityRequirementsOutput.