#[non_exhaustive]pub struct BatchGetArtifactMetadataInput {
pub agent_space_id: Option<String>,
pub artifact_ids: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>Unique identifier of the agent space
artifact_ids: Option<Vec<String>>List of artifact identifiers
Implementations
Sourceimpl BatchGetArtifactMetadataInput
impl BatchGetArtifactMetadataInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
Unique identifier of the agent space
Sourcepub fn artifact_ids(&self) -> &[String]
pub fn artifact_ids(&self) -> &[String]
List of artifact identifiers
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .artifact_ids.is_none().
Sourceimpl BatchGetArtifactMetadataInput
impl BatchGetArtifactMetadataInput
Sourcepub fn builder() -> BatchGetArtifactMetadataInputBuilder
pub fn builder() -> BatchGetArtifactMetadataInputBuilder
Creates a new builder-style object to manufacture BatchGetArtifactMetadataInput.