pub struct BatchGetCodeReviewJobTasksFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchGetCodeReviewJobTasks.
Retrieves information about one or more tasks within a code review job.
Implementations
Sourceimpl BatchGetCodeReviewJobTasksFluentBuilder
impl BatchGetCodeReviewJobTasksFluentBuilder
Sourcepub fn as_input(&self) -> &BatchGetCodeReviewJobTasksInputBuilder
pub fn as_input(&self) -> &BatchGetCodeReviewJobTasksInputBuilder
Access the BatchGetCodeReviewJobTasks as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchGetCodeReviewJobTasksOutput, SdkError<BatchGetCodeReviewJobTasksError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchGetCodeReviewJobTasksOutput, SdkError<BatchGetCodeReviewJobTasksError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchGetCodeReviewJobTasksOutput, BatchGetCodeReviewJobTasksError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchGetCodeReviewJobTasksOutput, BatchGetCodeReviewJobTasksError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the tasks.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the tasks.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the tasks.
Sourcepub fn code_review_job_task_ids(self, input: impl Into<String>) -> Self
pub fn code_review_job_task_ids(self, input: impl Into<String>) -> Self
Appends an item to codeReviewJobTaskIds.
To override the contents of this collection use set_code_review_job_task_ids.
The list of task identifiers to retrieve.
Sourcepub fn set_code_review_job_task_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_code_review_job_task_ids(self, input: Option<Vec<String>>) -> Self
The list of task identifiers to retrieve.
Sourcepub fn get_code_review_job_task_ids(&self) -> &Option<Vec<String>>
pub fn get_code_review_job_task_ids(&self) -> &Option<Vec<String>>
The list of task identifiers to retrieve.