#[non_exhaustive]pub struct BatchGetCodeReviewJobTasksInputBuilder { /* private fields */ }Expand description
A builder for BatchGetCodeReviewJobTasksInput.
Implementations
Sourceimpl BatchGetCodeReviewJobTasksInputBuilder
impl BatchGetCodeReviewJobTasksInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the tasks.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the tasks.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the tasks.
Sourcepub fn code_review_job_task_ids(self, input: impl Into<String>) -> Self
pub fn code_review_job_task_ids(self, input: impl Into<String>) -> Self
Appends an item to code_review_job_task_ids.
To override the contents of this collection use set_code_review_job_task_ids.
The list of task identifiers to retrieve.
Sourcepub fn set_code_review_job_task_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_code_review_job_task_ids(self, input: Option<Vec<String>>) -> Self
The list of task identifiers to retrieve.
Sourcepub fn get_code_review_job_task_ids(&self) -> &Option<Vec<String>>
pub fn get_code_review_job_task_ids(&self) -> &Option<Vec<String>>
The list of task identifiers to retrieve.
Sourcepub fn build(self) -> Result<BatchGetCodeReviewJobTasksInput, BuildError>
pub fn build(self) -> Result<BatchGetCodeReviewJobTasksInput, BuildError>
Consumes the builder and constructs a BatchGetCodeReviewJobTasksInput.
Sourceimpl BatchGetCodeReviewJobTasksInputBuilder
impl BatchGetCodeReviewJobTasksInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetCodeReviewJobTasksOutput, SdkError<BatchGetCodeReviewJobTasksError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetCodeReviewJobTasksOutput, SdkError<BatchGetCodeReviewJobTasksError, HttpResponse>>
Sends a request with this input using the given client.