#[non_exhaustive]pub struct BatchGetCodeReviewJobTasksInput {
pub agent_space_id: Option<String>,
pub code_review_job_task_ids: Option<Vec<String>>,
}Expand description
Input for retrieving multiple tasks associated with a code review job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space that contains the tasks.
code_review_job_task_ids: Option<Vec<String>>The list of task identifiers to retrieve.
Implementations
Sourceimpl BatchGetCodeReviewJobTasksInput
impl BatchGetCodeReviewJobTasksInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the tasks.
Sourcepub fn code_review_job_task_ids(&self) -> &[String]
pub fn code_review_job_task_ids(&self) -> &[String]
The list of task identifiers to retrieve.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .code_review_job_task_ids.is_none().
Sourceimpl BatchGetCodeReviewJobTasksInput
impl BatchGetCodeReviewJobTasksInput
Sourcepub fn builder() -> BatchGetCodeReviewJobTasksInputBuilder
pub fn builder() -> BatchGetCodeReviewJobTasksInputBuilder
Creates a new builder-style object to manufacture BatchGetCodeReviewJobTasksInput.