#[non_exhaustive]pub struct BatchGetCodeReviewJobsOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetCodeReviewJobsOutput.
Implementations
Sourceimpl BatchGetCodeReviewJobsOutputBuilder
impl BatchGetCodeReviewJobsOutputBuilder
Sourcepub fn code_review_jobs(self, input: CodeReviewJob) -> Self
pub fn code_review_jobs(self, input: CodeReviewJob) -> Self
Appends an item to code_review_jobs.
To override the contents of this collection use set_code_review_jobs.
The list of code review jobs that were found.
Sourcepub fn set_code_review_jobs(self, input: Option<Vec<CodeReviewJob>>) -> Self
pub fn set_code_review_jobs(self, input: Option<Vec<CodeReviewJob>>) -> Self
The list of code review jobs that were found.
Sourcepub fn get_code_review_jobs(&self) -> &Option<Vec<CodeReviewJob>>
pub fn get_code_review_jobs(&self) -> &Option<Vec<CodeReviewJob>>
The list of code review jobs that were found.
Sourcepub fn not_found(self, input: impl Into<String>) -> Self
pub fn not_found(self, input: impl Into<String>) -> Self
Appends an item to not_found.
To override the contents of this collection use set_not_found.
The list of code review job identifiers that were not found.
Sourcepub fn set_not_found(self, input: Option<Vec<String>>) -> Self
pub fn set_not_found(self, input: Option<Vec<String>>) -> Self
The list of code review job identifiers that were not found.
Sourcepub fn get_not_found(&self) -> &Option<Vec<String>>
pub fn get_not_found(&self) -> &Option<Vec<String>>
The list of code review job identifiers that were not found.
Sourcepub fn build(self) -> BatchGetCodeReviewJobsOutput
pub fn build(self) -> BatchGetCodeReviewJobsOutput
Consumes the builder and constructs a BatchGetCodeReviewJobsOutput.