#[non_exhaustive]pub struct BatchGetCodeReviewJobsOutput {
pub code_review_jobs: Option<Vec<CodeReviewJob>>,
pub not_found: Option<Vec<String>>,
/* private fields */
}Expand description
Output for the BatchGetCodeReviewJobs operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_jobs: Option<Vec<CodeReviewJob>>The list of code review jobs that were found.
not_found: Option<Vec<String>>The list of code review job identifiers that were not found.
Implementations
Sourceimpl BatchGetCodeReviewJobsOutput
impl BatchGetCodeReviewJobsOutput
Sourcepub fn code_review_jobs(&self) -> &[CodeReviewJob]
pub fn code_review_jobs(&self) -> &[CodeReviewJob]
The list of code review jobs that were found.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .code_review_jobs.is_none().
Sourceimpl BatchGetCodeReviewJobsOutput
impl BatchGetCodeReviewJobsOutput
Sourcepub fn builder() -> BatchGetCodeReviewJobsOutputBuilder
pub fn builder() -> BatchGetCodeReviewJobsOutputBuilder
Creates a new builder-style object to manufacture BatchGetCodeReviewJobsOutput.