#[non_exhaustive]pub struct BatchGetCodeReviewsOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetCodeReviewsOutput.
Implementations
Sourceimpl BatchGetCodeReviewsOutputBuilder
impl BatchGetCodeReviewsOutputBuilder
Sourcepub fn code_reviews(self, input: CodeReview) -> Self
pub fn code_reviews(self, input: CodeReview) -> Self
Appends an item to code_reviews.
To override the contents of this collection use set_code_reviews.
The list of code reviews that were found.
Sourcepub fn set_code_reviews(self, input: Option<Vec<CodeReview>>) -> Self
pub fn set_code_reviews(self, input: Option<Vec<CodeReview>>) -> Self
The list of code reviews that were found.
Sourcepub fn get_code_reviews(&self) -> &Option<Vec<CodeReview>>
pub fn get_code_reviews(&self) -> &Option<Vec<CodeReview>>
The list of code reviews that were found.
Sourcepub fn not_found(self, input: impl Into<String>) -> Self
pub fn not_found(self, input: impl Into<String>) -> Self
Appends an item to not_found.
To override the contents of this collection use set_not_found.
The list of code review identifiers that were not found.
Sourcepub fn set_not_found(self, input: Option<Vec<String>>) -> Self
pub fn set_not_found(self, input: Option<Vec<String>>) -> Self
The list of code review identifiers that were not found.
Sourcepub fn get_not_found(&self) -> &Option<Vec<String>>
pub fn get_not_found(&self) -> &Option<Vec<String>>
The list of code review identifiers that were not found.
Sourcepub fn build(self) -> BatchGetCodeReviewsOutput
pub fn build(self) -> BatchGetCodeReviewsOutput
Consumes the builder and constructs a BatchGetCodeReviewsOutput.