#[non_exhaustive]pub struct BatchGetPentestsInputBuilder { /* private fields */ }Expand description
A builder for BatchGetPentestsInput.
Implementations
Sourceimpl BatchGetPentestsInputBuilder
impl BatchGetPentestsInputBuilder
Sourcepub fn pentest_ids(self, input: impl Into<String>) -> Self
pub fn pentest_ids(self, input: impl Into<String>) -> Self
Appends an item to pentest_ids.
To override the contents of this collection use set_pentest_ids.
The list of pentest identifiers to retrieve.
Sourcepub fn set_pentest_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_pentest_ids(self, input: Option<Vec<String>>) -> Self
The list of pentest identifiers to retrieve.
Sourcepub fn get_pentest_ids(&self) -> &Option<Vec<String>>
pub fn get_pentest_ids(&self) -> &Option<Vec<String>>
The list of pentest identifiers to retrieve.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the pentests.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the pentests.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the pentests.
Sourcepub fn build(self) -> Result<BatchGetPentestsInput, BuildError>
pub fn build(self) -> Result<BatchGetPentestsInput, BuildError>
Consumes the builder and constructs a BatchGetPentestsInput.
Sourceimpl BatchGetPentestsInputBuilder
impl BatchGetPentestsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetPentestsOutput, SdkError<BatchGetPentestsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetPentestsOutput, SdkError<BatchGetPentestsError, HttpResponse>>
Sends a request with this input using the given client.