#[non_exhaustive]pub struct BatchGetPentestsInput {
pub pentest_ids: Option<Vec<String>>,
pub agent_space_id: Option<String>,
}Expand description
Input for retrieving multiple pentests by their IDs
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_ids: Option<Vec<String>>List of pentest IDs to retrieve
agent_space_id: Option<String>ID of the agent space where the pentest exists
Implementations
Sourceimpl BatchGetPentestsInput
impl BatchGetPentestsInput
Sourcepub fn pentest_ids(&self) -> &[String]
pub fn pentest_ids(&self) -> &[String]
List of pentest IDs to retrieve
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .pentest_ids.is_none().
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
ID of the agent space where the pentest exists
Sourceimpl BatchGetPentestsInput
impl BatchGetPentestsInput
Sourcepub fn builder() -> BatchGetPentestsInputBuilder
pub fn builder() -> BatchGetPentestsInputBuilder
Creates a new builder-style object to manufacture BatchGetPentestsInput.