#[non_exhaustive]pub struct BatchGetSecurityRequirementsInputBuilder { /* private fields */ }Expand description
A builder for BatchGetSecurityRequirementsInput.
Implementations
Sourceimpl BatchGetSecurityRequirementsInputBuilder
impl BatchGetSecurityRequirementsInputBuilder
Sourcepub fn pack_id(self, input: impl Into<String>) -> Self
pub fn pack_id(self, input: impl Into<String>) -> Self
The unique identifier of the security requirement pack to retrieve requirements from.
This field is required.Sourcepub fn set_pack_id(self, input: Option<String>) -> Self
pub fn set_pack_id(self, input: Option<String>) -> Self
The unique identifier of the security requirement pack to retrieve requirements from.
Sourcepub fn get_pack_id(&self) -> &Option<String>
pub fn get_pack_id(&self) -> &Option<String>
The unique identifier of the security requirement pack to retrieve requirements from.
Sourcepub fn security_requirement_names(self, input: impl Into<String>) -> Self
pub fn security_requirement_names(self, input: impl Into<String>) -> Self
Appends an item to security_requirement_names.
To override the contents of this collection use set_security_requirement_names.
The list of security requirement names to retrieve.
Sourcepub fn set_security_requirement_names(self, input: Option<Vec<String>>) -> Self
pub fn set_security_requirement_names(self, input: Option<Vec<String>>) -> Self
The list of security requirement names to retrieve.
Sourcepub fn get_security_requirement_names(&self) -> &Option<Vec<String>>
pub fn get_security_requirement_names(&self) -> &Option<Vec<String>>
The list of security requirement names to retrieve.
Sourcepub fn build(self) -> Result<BatchGetSecurityRequirementsInput, BuildError>
pub fn build(self) -> Result<BatchGetSecurityRequirementsInput, BuildError>
Consumes the builder and constructs a BatchGetSecurityRequirementsInput.
Sourceimpl BatchGetSecurityRequirementsInputBuilder
impl BatchGetSecurityRequirementsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetSecurityRequirementsOutput, SdkError<BatchGetSecurityRequirementsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetSecurityRequirementsOutput, SdkError<BatchGetSecurityRequirementsError, HttpResponse>>
Sends a request with this input using the given client.