#[non_exhaustive]pub struct BatchGetSecurityRequirementsOutput {
pub security_requirements: Vec<BatchGetSecurityRequirementResult>,
pub errors: Vec<BatchSecurityRequirementError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_requirements: Vec<BatchGetSecurityRequirementResult>The list of security requirements that were successfully retrieved.
errors: Vec<BatchSecurityRequirementError>The list of errors for security requirements that failed to be retrieved.
Implementations
Sourceimpl BatchGetSecurityRequirementsOutput
impl BatchGetSecurityRequirementsOutput
Sourcepub fn security_requirements(&self) -> &[BatchGetSecurityRequirementResult]
pub fn security_requirements(&self) -> &[BatchGetSecurityRequirementResult]
The list of security requirements that were successfully retrieved.
Sourcepub fn errors(&self) -> &[BatchSecurityRequirementError]
pub fn errors(&self) -> &[BatchSecurityRequirementError]
The list of errors for security requirements that failed to be retrieved.
Sourceimpl BatchGetSecurityRequirementsOutput
impl BatchGetSecurityRequirementsOutput
Sourcepub fn builder() -> BatchGetSecurityRequirementsOutputBuilder
pub fn builder() -> BatchGetSecurityRequirementsOutputBuilder
Creates a new builder-style object to manufacture BatchGetSecurityRequirementsOutput.