#[non_exhaustive]pub struct BatchGetThreatModelsOutput {
pub threat_models: Option<Vec<ThreatModel>>,
pub not_found: Option<Vec<String>>,
/* private fields */
}Expand description
Output for the BatchGetThreatModels operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_models: Option<Vec<ThreatModel>>The list of threat models that were found.
not_found: Option<Vec<String>>The list of threat model identifiers that were not found.
Implementations
Sourceimpl BatchGetThreatModelsOutput
impl BatchGetThreatModelsOutput
Sourcepub fn threat_models(&self) -> &[ThreatModel]
pub fn threat_models(&self) -> &[ThreatModel]
The list of threat models that were found.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .threat_models.is_none().
Sourceimpl BatchGetThreatModelsOutput
impl BatchGetThreatModelsOutput
Sourcepub fn builder() -> BatchGetThreatModelsOutputBuilder
pub fn builder() -> BatchGetThreatModelsOutputBuilder
Creates a new builder-style object to manufacture BatchGetThreatModelsOutput.