pub struct BatchUpdateSecurityRequirementsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchUpdateSecurityRequirements.
Batch updates security requirements within a customer managed pack.
Implementations
Sourceimpl BatchUpdateSecurityRequirementsFluentBuilder
impl BatchUpdateSecurityRequirementsFluentBuilder
Sourcepub fn as_input(&self) -> &BatchUpdateSecurityRequirementsInputBuilder
pub fn as_input(&self) -> &BatchUpdateSecurityRequirementsInputBuilder
Access the BatchUpdateSecurityRequirements as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchUpdateSecurityRequirementsOutput, SdkError<BatchUpdateSecurityRequirementsError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchUpdateSecurityRequirementsOutput, SdkError<BatchUpdateSecurityRequirementsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchUpdateSecurityRequirementsOutput, BatchUpdateSecurityRequirementsError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchUpdateSecurityRequirementsOutput, BatchUpdateSecurityRequirementsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn pack_id(self, input: impl Into<String>) -> Self
pub fn pack_id(self, input: impl Into<String>) -> Self
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn set_pack_id(self, input: Option<String>) -> Self
pub fn set_pack_id(self, input: Option<String>) -> Self
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn get_pack_id(&self) -> &Option<String>
pub fn get_pack_id(&self) -> &Option<String>
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn security_requirements(
self,
input: UpdateSecurityRequirementEntry,
) -> Self
pub fn security_requirements( self, input: UpdateSecurityRequirementEntry, ) -> Self
Appends an item to securityRequirements.
To override the contents of this collection use set_security_requirements.
The list of security requirement updates to apply.
Sourcepub fn set_security_requirements(
self,
input: Option<Vec<UpdateSecurityRequirementEntry>>,
) -> Self
pub fn set_security_requirements( self, input: Option<Vec<UpdateSecurityRequirementEntry>>, ) -> Self
The list of security requirement updates to apply.
Sourcepub fn get_security_requirements(
&self,
) -> &Option<Vec<UpdateSecurityRequirementEntry>>
pub fn get_security_requirements( &self, ) -> &Option<Vec<UpdateSecurityRequirementEntry>>
The list of security requirement updates to apply.