#[non_exhaustive]pub struct BatchUpdateSecurityRequirementsInputBuilder { /* private fields */ }Expand description
A builder for BatchUpdateSecurityRequirementsInput.
Implementations
Sourceimpl BatchUpdateSecurityRequirementsInputBuilder
impl BatchUpdateSecurityRequirementsInputBuilder
Sourcepub fn pack_id(self, input: impl Into<String>) -> Self
pub fn pack_id(self, input: impl Into<String>) -> Self
The unique identifier of the security requirement pack containing the requirements to update.
This field is required.Sourcepub fn set_pack_id(self, input: Option<String>) -> Self
pub fn set_pack_id(self, input: Option<String>) -> Self
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn get_pack_id(&self) -> &Option<String>
pub fn get_pack_id(&self) -> &Option<String>
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn security_requirements(
self,
input: UpdateSecurityRequirementEntry,
) -> Self
pub fn security_requirements( self, input: UpdateSecurityRequirementEntry, ) -> Self
Appends an item to security_requirements.
To override the contents of this collection use set_security_requirements.
The list of security requirement updates to apply.
Sourcepub fn set_security_requirements(
self,
input: Option<Vec<UpdateSecurityRequirementEntry>>,
) -> Self
pub fn set_security_requirements( self, input: Option<Vec<UpdateSecurityRequirementEntry>>, ) -> Self
The list of security requirement updates to apply.
Sourcepub fn get_security_requirements(
&self,
) -> &Option<Vec<UpdateSecurityRequirementEntry>>
pub fn get_security_requirements( &self, ) -> &Option<Vec<UpdateSecurityRequirementEntry>>
The list of security requirement updates to apply.
Sourcepub fn build(self) -> Result<BatchUpdateSecurityRequirementsInput, BuildError>
pub fn build(self) -> Result<BatchUpdateSecurityRequirementsInput, BuildError>
Consumes the builder and constructs a BatchUpdateSecurityRequirementsInput.
Sourceimpl BatchUpdateSecurityRequirementsInputBuilder
impl BatchUpdateSecurityRequirementsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchUpdateSecurityRequirementsOutput, SdkError<BatchUpdateSecurityRequirementsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchUpdateSecurityRequirementsOutput, SdkError<BatchUpdateSecurityRequirementsError, HttpResponse>>
Sends a request with this input using the given client.