#[non_exhaustive]pub struct BatchUpdateSecurityRequirementsInput {
pub pack_id: Option<String>,
pub security_requirements: Option<Vec<UpdateSecurityRequirementEntry>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pack_id: Option<String>The unique identifier of the security requirement pack containing the requirements to update.
security_requirements: Option<Vec<UpdateSecurityRequirementEntry>>The list of security requirement updates to apply.
Implementations
Sourceimpl BatchUpdateSecurityRequirementsInput
impl BatchUpdateSecurityRequirementsInput
Sourcepub fn pack_id(&self) -> Option<&str>
pub fn pack_id(&self) -> Option<&str>
The unique identifier of the security requirement pack containing the requirements to update.
Sourcepub fn security_requirements(&self) -> &[UpdateSecurityRequirementEntry]
pub fn security_requirements(&self) -> &[UpdateSecurityRequirementEntry]
The list of security requirement updates to apply.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_requirements.is_none().
Sourceimpl BatchUpdateSecurityRequirementsInput
impl BatchUpdateSecurityRequirementsInput
Sourcepub fn builder() -> BatchUpdateSecurityRequirementsInputBuilder
pub fn builder() -> BatchUpdateSecurityRequirementsInputBuilder
Creates a new builder-style object to manufacture BatchUpdateSecurityRequirementsInput.