CreateAgentSpaceFluentBuilder

Struct CreateAgentSpaceFluentBuilder 

pub struct CreateAgentSpaceFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateAgentSpace.

Creates an agent space record

Implementations

Source

impl CreateAgentSpaceFluentBuilder

pub fn as_input(&self) -> &CreateAgentSpaceInputBuilder

Access the CreateAgentSpace as a reference.

pub async fn send( self, ) -> Result<CreateAgentSpaceOutput, SdkError<CreateAgentSpaceError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateAgentSpaceOutput, CreateAgentSpaceError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn name(self, input: impl Into<String>) -> Self

Name of the agent space

pub fn set_name(self, input: Option<String>) -> Self

Name of the agent space

pub fn get_name(&self) -> &Option<String>

Name of the agent space

pub fn description(self, input: impl Into<String>) -> Self

Description of the agent space

pub fn set_description(self, input: Option<String>) -> Self

Description of the agent space

pub fn get_description(&self) -> &Option<String>

Description of the agent space

pub fn aws_resources(self, input: AwsResources) -> Self

AWS resource configurations associated with the agent space

pub fn set_aws_resources(self, input: Option<AwsResources>) -> Self

AWS resource configurations associated with the agent space

pub fn get_aws_resources(&self) -> &Option<AwsResources>

AWS resource configurations associated with the agent space

pub fn target_domain_ids(self, input: impl Into<String>) -> Self

Appends an item to targetDomainIds.

To override the contents of this collection use set_target_domain_ids.

Target domain IDs to associate with the agent space

pub fn set_target_domain_ids(self, input: Option<Vec<String>>) -> Self

Target domain IDs to associate with the agent space

pub fn get_target_domain_ids(&self) -> &Option<Vec<String>>

Target domain IDs to associate with the agent space

pub fn code_review_settings(self, input: CodeReviewSettings) -> Self

Configuration for code review analysis, including controls scanning and general purpose scanning settings

pub fn set_code_review_settings(self, input: Option<CodeReviewSettings>) -> Self

Configuration for code review analysis, including controls scanning and general purpose scanning settings

pub fn get_code_review_settings(&self) -> &Option<CodeReviewSettings>

Configuration for code review analysis, including controls scanning and general purpose scanning settings

pub fn kms_key_id(self, input: impl Into<String>) -> Self

Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.

pub fn set_kms_key_id(self, input: Option<String>) -> Self

Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.

pub fn get_kms_key_id(&self) -> &Option<String>

Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

Tags to associate with the agent space

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

Tags to associate with the agent space

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

Tags to associate with the agent space