#[non_exhaustive]pub struct CreateAgentSpaceOutputBuilder { /* private fields */ }Expand description
A builder for CreateAgentSpaceOutput.
Implementations
Sourceimpl CreateAgentSpaceOutputBuilder
impl CreateAgentSpaceOutputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the created agent space.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the created agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the created agent space.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the agent space.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the agent space.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the agent space.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the agent space.
Sourcepub fn aws_resources(self, input: AwsResources) -> Self
pub fn aws_resources(self, input: AwsResources) -> Self
The AWS resources associated with the agent space.
Sourcepub fn set_aws_resources(self, input: Option<AwsResources>) -> Self
pub fn set_aws_resources(self, input: Option<AwsResources>) -> Self
The AWS resources associated with the agent space.
Sourcepub fn get_aws_resources(&self) -> &Option<AwsResources>
pub fn get_aws_resources(&self) -> &Option<AwsResources>
The AWS resources associated with the agent space.
Sourcepub fn target_domain_ids(self, input: impl Into<String>) -> Self
pub fn target_domain_ids(self, input: impl Into<String>) -> Self
Appends an item to target_domain_ids.
To override the contents of this collection use set_target_domain_ids.
The list of target domain identifiers associated with the agent space.
Sourcepub fn set_target_domain_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_target_domain_ids(self, input: Option<Vec<String>>) -> Self
The list of target domain identifiers associated with the agent space.
Sourcepub fn get_target_domain_ids(&self) -> &Option<Vec<String>>
pub fn get_target_domain_ids(&self) -> &Option<Vec<String>>
The list of target domain identifiers associated with the agent space.
Sourcepub fn code_review_settings(self, input: CodeReviewSettings) -> Self
pub fn code_review_settings(self, input: CodeReviewSettings) -> Self
The code review settings for the agent space.
Sourcepub fn set_code_review_settings(self, input: Option<CodeReviewSettings>) -> Self
pub fn set_code_review_settings(self, input: Option<CodeReviewSettings>) -> Self
The code review settings for the agent space.
Sourcepub fn get_code_review_settings(&self) -> &Option<CodeReviewSettings>
pub fn get_code_review_settings(&self) -> &Option<CodeReviewSettings>
The code review settings for the agent space.
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
The identifier of the AWS KMS key used to encrypt data in the agent space.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
The identifier of the AWS KMS key used to encrypt data in the agent space.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
The identifier of the AWS KMS key used to encrypt data in the agent space.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the agent space was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the agent space was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the agent space was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the agent space was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the agent space was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the agent space was last updated, in UTC format.
Sourcepub fn build(self) -> Result<CreateAgentSpaceOutput, BuildError>
pub fn build(self) -> Result<CreateAgentSpaceOutput, BuildError>
Consumes the builder and constructs a CreateAgentSpaceOutput.
This method will fail if any of the following fields are not set: