#[non_exhaustive]pub struct CreateAgentSpaceInput {
pub name: Option<String>,
pub description: Option<String>,
pub aws_resources: Option<AwsResources>,
pub target_domain_ids: Option<Vec<String>>,
pub code_review_settings: Option<CodeReviewSettings>,
pub kms_key_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Input for creating a new agent space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the agent space.
description: Option<String>A description of the agent space.
aws_resources: Option<AwsResources>The AWS resources to associate with the agent space.
target_domain_ids: Option<Vec<String>>The list of target domain identifiers to associate with the agent space.
code_review_settings: Option<CodeReviewSettings>The code review settings for the agent space.
kms_key_id: Option<String>The identifier of the AWS KMS key to use for encrypting data in the agent space.
The tags to associate with the agent space.
Implementations
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the agent space.
Sourcepub fn aws_resources(&self) -> Option<&AwsResources>
pub fn aws_resources(&self) -> Option<&AwsResources>
The AWS resources to associate with the agent space.
Sourcepub fn target_domain_ids(&self) -> &[String]
pub fn target_domain_ids(&self) -> &[String]
The list of target domain identifiers to associate with the agent space.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .target_domain_ids.is_none().
Sourcepub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
pub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
The code review settings for the agent space.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The identifier of the AWS KMS key to use for encrypting data in the agent space.
The tags to associate with the agent space.
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn builder() -> CreateAgentSpaceInputBuilder
pub fn builder() -> CreateAgentSpaceInputBuilder
Creates a new builder-style object to manufacture CreateAgentSpaceInput.