pub struct CreateApplicationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateApplication.
Creates a new application
Implementations
Sourceimpl CreateApplicationFluentBuilder
impl CreateApplicationFluentBuilder
Sourcepub fn as_input(&self) -> &CreateApplicationInputBuilder
pub fn as_input(&self) -> &CreateApplicationInputBuilder
Access the CreateApplication as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateApplicationOutput, SdkError<CreateApplicationError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateApplicationOutput, SdkError<CreateApplicationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateApplicationOutput, CreateApplicationError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateApplicationOutput, CreateApplicationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn idc_instance_arn(self, input: impl Into<String>) -> Self
pub fn idc_instance_arn(self, input: impl Into<String>) -> Self
ARN of the IAM Identity Center instance used for user authentication. Optional for non-IdC applications
Sourcepub fn set_idc_instance_arn(self, input: Option<String>) -> Self
pub fn set_idc_instance_arn(self, input: Option<String>) -> Self
ARN of the IAM Identity Center instance used for user authentication. Optional for non-IdC applications
Sourcepub fn get_idc_instance_arn(&self) -> &Option<String>
pub fn get_idc_instance_arn(&self) -> &Option<String>
ARN of the IAM Identity Center instance used for user authentication. Optional for non-IdC applications
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn default_kms_key_id(self, input: impl Into<String>) -> Self
pub fn default_kms_key_id(self, input: impl Into<String>) -> Self
Default KMS key identifier used to encrypt application data
Sourcepub fn set_default_kms_key_id(self, input: Option<String>) -> Self
pub fn set_default_kms_key_id(self, input: Option<String>) -> Self
Default KMS key identifier used to encrypt application data
Sourcepub fn get_default_kms_key_id(&self) -> &Option<String>
pub fn get_default_kms_key_id(&self) -> &Option<String>
Default KMS key identifier used to encrypt application data
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags to associate with the application
Tags to associate with the application
Tags to associate with the application