#[non_exhaustive]pub struct CreateCodeReviewInputBuilder { /* private fields */ }Expand description
A builder for CreateCodeReviewInput.
Implementations
Sourceimpl CreateCodeReviewInputBuilder
impl CreateCodeReviewInputBuilder
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the code review.
This field is required.Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space to create the code review in.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space to create the code review in.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space to create the code review in.
Sourcepub fn assets(self, input: Assets) -> Self
pub fn assets(self, input: Assets) -> Self
The assets to include in the code review, such as documents and source code.
This field is required.Sourcepub fn set_assets(self, input: Option<Assets>) -> Self
pub fn set_assets(self, input: Option<Assets>) -> Self
The assets to include in the code review, such as documents and source code.
Sourcepub fn get_assets(&self) -> &Option<Assets>
pub fn get_assets(&self) -> &Option<Assets>
The assets to include in the code review, such as documents and source code.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The IAM service role to use for the code review.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The IAM service role to use for the code review.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The IAM service role to use for the code review.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The CloudWatch Logs configuration for the code review.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The CloudWatch Logs configuration for the code review.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The CloudWatch Logs configuration for the code review.
Sourcepub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
Sourcepub fn set_code_remediation_strategy(
self,
input: Option<CodeRemediationStrategy>,
) -> Self
pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self
The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
Sourcepub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
Sourcepub fn build(self) -> Result<CreateCodeReviewInput, BuildError>
pub fn build(self) -> Result<CreateCodeReviewInput, BuildError>
Consumes the builder and constructs a CreateCodeReviewInput.
Sourceimpl CreateCodeReviewInputBuilder
impl CreateCodeReviewInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateCodeReviewOutput, SdkError<CreateCodeReviewError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateCodeReviewOutput, SdkError<CreateCodeReviewError, HttpResponse>>
Sends a request with this input using the given client.