#[non_exhaustive]pub struct CreateCodeReviewInput {
pub title: Option<String>,
pub agent_space_id: Option<String>,
pub assets: Option<Assets>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
}Expand description
Input for creating a new code review.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the code review.
agent_space_id: Option<String>The unique identifier of the agent space to create the code review in.
assets: Option<Assets>The assets to include in the code review, such as documents and source code.
service_role: Option<String>The IAM service role to use for the code review.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the code review.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
Implementations
Sourceimpl CreateCodeReviewInput
impl CreateCodeReviewInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to create the code review in.
Sourcepub fn assets(&self) -> Option<&Assets>
pub fn assets(&self) -> Option<&Assets>
The assets to include in the code review, such as documents and source code.
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role to use for the code review.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the code review.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
Sourceimpl CreateCodeReviewInput
impl CreateCodeReviewInput
Sourcepub fn builder() -> CreateCodeReviewInputBuilder
pub fn builder() -> CreateCodeReviewInputBuilder
Creates a new builder-style object to manufacture CreateCodeReviewInput.