#[non_exhaustive]pub struct CreateCodeReviewOutput {
pub code_review_id: String,
pub title: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub assets: Option<Assets>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub agent_space_id: Option<String>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
/* private fields */
}Expand description
Output for the CreateCodeReview operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_id: StringThe unique identifier of the created code review.
title: Option<String>The title of the code review.
created_at: Option<DateTime>The date and time the code review was created, in UTC format.
updated_at: Option<DateTime>The date and time the code review was last updated, in UTC format.
assets: Option<Assets>The assets included in the code review.
service_role: Option<String>The IAM service role used for the code review.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the code review.
agent_space_id: Option<String>The unique identifier of the agent space that contains the code review.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the code review.
Implementations
Sourceimpl CreateCodeReviewOutput
impl CreateCodeReviewOutput
Sourcepub fn code_review_id(&self) -> &str
pub fn code_review_id(&self) -> &str
The unique identifier of the created code review.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the code review was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the code review was last updated, in UTC format.
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the code review.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the code review.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the code review.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the code review.
Sourceimpl CreateCodeReviewOutput
impl CreateCodeReviewOutput
Sourcepub fn builder() -> CreateCodeReviewOutputBuilder
pub fn builder() -> CreateCodeReviewOutputBuilder
Creates a new builder-style object to manufacture CreateCodeReviewOutput.