#[non_exhaustive]pub struct CreateIntegrationInputBuilder { /* private fields */ }Expand description
A builder for CreateIntegrationInput.
Implementations
Sourceimpl CreateIntegrationInputBuilder
impl CreateIntegrationInputBuilder
Sourcepub fn provider(self, input: Provider) -> Self
pub fn provider(self, input: Provider) -> Self
Provider to integrate with This field is required.
Sourcepub fn set_provider(self, input: Option<Provider>) -> Self
pub fn set_provider(self, input: Option<Provider>) -> Self
Provider to integrate with
Sourcepub fn get_provider(&self) -> &Option<Provider>
pub fn get_provider(&self) -> &Option<Provider>
Provider to integrate with
Sourcepub fn input(self, input: ProviderInput) -> Self
pub fn input(self, input: ProviderInput) -> Self
Provider-specific input parameters This field is required.
Sourcepub fn set_input(self, input: Option<ProviderInput>) -> Self
pub fn set_input(self, input: Option<ProviderInput>) -> Self
Provider-specific input parameters
Sourcepub fn get_input(&self) -> &Option<ProviderInput>
pub fn get_input(&self) -> &Option<ProviderInput>
Provider-specific input parameters
Sourcepub fn integration_display_name(self, input: impl Into<String>) -> Self
pub fn integration_display_name(self, input: impl Into<String>) -> Self
Display name for the integration This field is required.
Sourcepub fn set_integration_display_name(self, input: Option<String>) -> Self
pub fn set_integration_display_name(self, input: Option<String>) -> Self
Display name for the integration
Sourcepub fn get_integration_display_name(&self) -> &Option<String>
pub fn get_integration_display_name(&self) -> &Option<String>
Display name for the integration
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
KMS key ID for encrypting integration details
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
KMS key ID for encrypting integration details
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
KMS key ID for encrypting integration details
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Tags to associate with the integration
Tags to associate with the integration
Tags to associate with the integration
Sourcepub fn build(self) -> Result<CreateIntegrationInput, BuildError>
pub fn build(self) -> Result<CreateIntegrationInput, BuildError>
Consumes the builder and constructs a CreateIntegrationInput.
Sourceimpl CreateIntegrationInputBuilder
impl CreateIntegrationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateIntegrationOutput, SdkError<CreateIntegrationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateIntegrationOutput, SdkError<CreateIntegrationError, HttpResponse>>
Sends a request with this input using the given client.