#[non_exhaustive]pub struct CreateMembershipInputBuilder { /* private fields */ }Expand description
A builder for CreateMembershipInput.
Implementations
Sourceimpl CreateMembershipInputBuilder
impl CreateMembershipInputBuilder
Sourcepub fn application_id(self, input: impl Into<String>) -> Self
pub fn application_id(self, input: impl Into<String>) -> Self
The unique identifier of the application that contains the agent space.
This field is required.Sourcepub fn set_application_id(self, input: Option<String>) -> Self
pub fn set_application_id(self, input: Option<String>) -> Self
The unique identifier of the application that contains the agent space.
Sourcepub fn get_application_id(&self) -> &Option<String>
pub fn get_application_id(&self) -> &Option<String>
The unique identifier of the application that contains the agent space.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space to grant access to.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space to grant access to.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space to grant access to.
Sourcepub fn membership_id(self, input: impl Into<String>) -> Self
pub fn membership_id(self, input: impl Into<String>) -> Self
The unique identifier for the membership.
This field is required.Sourcepub fn set_membership_id(self, input: Option<String>) -> Self
pub fn set_membership_id(self, input: Option<String>) -> Self
The unique identifier for the membership.
Sourcepub fn get_membership_id(&self) -> &Option<String>
pub fn get_membership_id(&self) -> &Option<String>
The unique identifier for the membership.
Sourcepub fn member_type(self, input: MembershipType) -> Self
pub fn member_type(self, input: MembershipType) -> Self
The type of member. Currently, only USER is supported.
This field is required.Sourcepub fn set_member_type(self, input: Option<MembershipType>) -> Self
pub fn set_member_type(self, input: Option<MembershipType>) -> Self
The type of member. Currently, only USER is supported.
Sourcepub fn get_member_type(&self) -> &Option<MembershipType>
pub fn get_member_type(&self) -> &Option<MembershipType>
The type of member. Currently, only USER is supported.
Sourcepub fn config(self, input: MembershipConfig) -> Self
pub fn config(self, input: MembershipConfig) -> Self
The configuration for the membership, such as the user role.
Sourcepub fn set_config(self, input: Option<MembershipConfig>) -> Self
pub fn set_config(self, input: Option<MembershipConfig>) -> Self
The configuration for the membership, such as the user role.
Sourcepub fn get_config(&self) -> &Option<MembershipConfig>
pub fn get_config(&self) -> &Option<MembershipConfig>
The configuration for the membership, such as the user role.
Sourcepub fn build(self) -> Result<CreateMembershipInput, BuildError>
pub fn build(self) -> Result<CreateMembershipInput, BuildError>
Consumes the builder and constructs a CreateMembershipInput.
Sourceimpl CreateMembershipInputBuilder
impl CreateMembershipInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateMembershipOutput, SdkError<CreateMembershipError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateMembershipOutput, SdkError<CreateMembershipError, HttpResponse>>
Sends a request with this input using the given client.