#[non_exhaustive]pub struct CreateMembershipInput {
pub application_id: Option<String>,
pub agent_space_id: Option<String>,
pub membership_id: Option<String>,
pub member_type: Option<MembershipType>,
pub config: Option<MembershipConfig>,
}Expand description
Request structure for adding a single member to an agent space.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_id: Option<String>The unique identifier of the application that contains the agent space.
agent_space_id: Option<String>The unique identifier of the agent space to grant access to.
membership_id: Option<String>The unique identifier for the membership.
member_type: Option<MembershipType>The type of member. Currently, only USER is supported.
config: Option<MembershipConfig>The configuration for the membership, such as the user role.
Implementations
Sourceimpl CreateMembershipInput
impl CreateMembershipInput
Sourcepub fn application_id(&self) -> Option<&str>
pub fn application_id(&self) -> Option<&str>
The unique identifier of the application that contains the agent space.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to grant access to.
Sourcepub fn membership_id(&self) -> Option<&str>
pub fn membership_id(&self) -> Option<&str>
The unique identifier for the membership.
Sourcepub fn member_type(&self) -> Option<&MembershipType>
pub fn member_type(&self) -> Option<&MembershipType>
The type of member. Currently, only USER is supported.
Sourcepub fn config(&self) -> Option<&MembershipConfig>
pub fn config(&self) -> Option<&MembershipConfig>
The configuration for the membership, such as the user role.
Sourceimpl CreateMembershipInput
impl CreateMembershipInput
Sourcepub fn builder() -> CreateMembershipInputBuilder
pub fn builder() -> CreateMembershipInputBuilder
Creates a new builder-style object to manufacture CreateMembershipInput.