CreatePentestInputBuilder

Struct CreatePentestInputBuilder 

#[non_exhaustive]
pub struct CreatePentestInputBuilder { /* private fields */ }
A builder for CreatePentestInput.

Implementations

Source

impl CreatePentestInputBuilder

pub fn title(self, input: impl Into<String>) -> Self

The title of the pentest.

This field is required.
pub fn set_title(self, input: Option<String>) -> Self

The title of the pentest.

pub fn get_title(&self) -> &Option<String>

The title of the pentest.

pub fn agent_space_id(self, input: impl Into<String>) -> Self

The unique identifier of the agent space to create the pentest in.

This field is required.
pub fn set_agent_space_id(self, input: Option<String>) -> Self

The unique identifier of the agent space to create the pentest in.

pub fn get_agent_space_id(&self) -> &Option<String>

The unique identifier of the agent space to create the pentest in.

pub fn assets(self, input: Assets) -> Self

The assets to include in the pentest, such as endpoints, actors, documents, and source code.

pub fn set_assets(self, input: Option<Assets>) -> Self

The assets to include in the pentest, such as endpoints, actors, documents, and source code.

pub fn get_assets(&self) -> &Option<Assets>

The assets to include in the pentest, such as endpoints, actors, documents, and source code.

pub fn exclude_risk_types(self, input: RiskType) -> Self

Appends an item to exclude_risk_types.

To override the contents of this collection use set_exclude_risk_types.

The list of risk types to exclude from the pentest.

pub fn set_exclude_risk_types(self, input: Option<Vec<RiskType>>) -> Self

The list of risk types to exclude from the pentest.

pub fn get_exclude_risk_types(&self) -> &Option<Vec<RiskType>>

The list of risk types to exclude from the pentest.

pub fn service_role(self, input: impl Into<String>) -> Self

The IAM service role to use for the pentest.

pub fn set_service_role(self, input: Option<String>) -> Self

The IAM service role to use for the pentest.

pub fn get_service_role(&self) -> &Option<String>

The IAM service role to use for the pentest.

pub fn log_config(self, input: CloudWatchLog) -> Self

The CloudWatch Logs configuration for the pentest.

pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self

The CloudWatch Logs configuration for the pentest.

pub fn get_log_config(&self) -> &Option<CloudWatchLog>

The CloudWatch Logs configuration for the pentest.

pub fn vpc_config(self, input: VpcConfig) -> Self

The VPC configuration for the pentest.

pub fn set_vpc_config(self, input: Option<VpcConfig>) -> Self

The VPC configuration for the pentest.

pub fn get_vpc_config(&self) -> &Option<VpcConfig>

The VPC configuration for the pentest.

pub fn network_traffic_config(self, input: NetworkTrafficConfig) -> Self

The network traffic configuration for the pentest, including custom headers and traffic rules.

pub fn set_network_traffic_config( self, input: Option<NetworkTrafficConfig>, ) -> Self

The network traffic configuration for the pentest, including custom headers and traffic rules.

pub fn get_network_traffic_config(&self) -> &Option<NetworkTrafficConfig>

The network traffic configuration for the pentest, including custom headers and traffic rules.

pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self

The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.

pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self

The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.

pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>

The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.

pub fn disable_managed_skills(self, input: SkillType) -> Self

Appends an item to disable_managed_skills.

To override the contents of this collection use set_disable_managed_skills.

A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

pub fn set_disable_managed_skills(self, input: Option<Vec<SkillType>>) -> Self

A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

pub fn get_disable_managed_skills(&self) -> &Option<Vec<SkillType>>

A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

pub fn build(self) -> Result<CreatePentestInput, BuildError>

Consumes the builder and constructs a CreatePentestInput.

Source

impl CreatePentestInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreatePentestOutput, SdkError<CreatePentestError, HttpResponse>>

Sends a request with this input using the given client.