#[non_exhaustive]pub struct CreatePentestOutputBuilder { /* private fields */ }Expand description
A builder for CreatePentestOutput.
Implementations
Sourceimpl CreatePentestOutputBuilder
impl CreatePentestOutputBuilder
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
The unique identifier of the created pentest.
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
The unique identifier of the created pentest.
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
The unique identifier of the created pentest.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the pentest was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the pentest was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the pentest was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the pentest was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the pentest was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the pentest was last updated, in UTC format.
Sourcepub fn set_assets(self, input: Option<Assets>) -> Self
pub fn set_assets(self, input: Option<Assets>) -> Self
The assets included in the pentest.
Sourcepub fn get_assets(&self) -> &Option<Assets>
pub fn get_assets(&self) -> &Option<Assets>
The assets included in the pentest.
Sourcepub fn exclude_risk_types(self, input: RiskType) -> Self
pub fn exclude_risk_types(self, input: RiskType) -> Self
Appends an item to exclude_risk_types.
To override the contents of this collection use set_exclude_risk_types.
The list of risk types excluded from the pentest.
Sourcepub fn set_exclude_risk_types(self, input: Option<Vec<RiskType>>) -> Self
pub fn set_exclude_risk_types(self, input: Option<Vec<RiskType>>) -> Self
The list of risk types excluded from the pentest.
Sourcepub fn get_exclude_risk_types(&self) -> &Option<Vec<RiskType>>
pub fn get_exclude_risk_types(&self) -> &Option<Vec<RiskType>>
The list of risk types excluded from the pentest.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The IAM service role used for the pentest.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The IAM service role used for the pentest.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The IAM service role used for the pentest.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The CloudWatch Logs configuration for the pentest.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The CloudWatch Logs configuration for the pentest.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The CloudWatch Logs configuration for the pentest.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the pentest.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the pentest.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the pentest.
Sourcepub fn build(self) -> CreatePentestOutput
pub fn build(self) -> CreatePentestOutput
Consumes the builder and constructs a CreatePentestOutput.