#[non_exhaustive]pub struct CreatePentestInput {
pub title: Option<String>,
pub agent_space_id: Option<String>,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
}Expand description
Input for creating a new pentest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the pentest.
agent_space_id: Option<String>The unique identifier of the agent space to create the pentest in.
assets: Option<Assets>The assets to include in the pentest, such as endpoints, actors, documents, and source code.
exclude_risk_types: Option<Vec<RiskType>>The list of risk types to exclude from the pentest.
service_role: Option<String>The IAM service role to use for the pentest.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the pentest.
vpc_config: Option<VpcConfig>The VPC configuration for the pentest.
network_traffic_config: Option<NetworkTrafficConfig>The network traffic configuration for the pentest, including custom headers and traffic rules.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.
Implementations
Sourceimpl CreatePentestInput
impl CreatePentestInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to create the pentest in.
Sourcepub fn assets(&self) -> Option<&Assets>
pub fn assets(&self) -> Option<&Assets>
The assets to include in the pentest, such as endpoints, actors, documents, and source code.
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
The list of risk types to exclude from the pentest.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role to use for the pentest.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the pentest.
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
The VPC configuration for the pentest.
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
The network traffic configuration for the pentest, including custom headers and traffic rules.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.
Sourceimpl CreatePentestInput
impl CreatePentestInput
Sourcepub fn builder() -> CreatePentestInputBuilder
pub fn builder() -> CreatePentestInputBuilder
Creates a new builder-style object to manufacture CreatePentestInput.