#[non_exhaustive]pub struct CreatePentestOutput {
pub pentest_id: Option<String>,
pub title: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub agent_space_id: Option<String>,
/* private fields */
}Expand description
Output for the CreatePentest operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: Option<String>The unique identifier of the created pentest.
title: Option<String>The title of the pentest.
created_at: Option<DateTime>The date and time the pentest was created, in UTC format.
updated_at: Option<DateTime>The date and time the pentest was last updated, in UTC format.
assets: Option<Assets>The assets included in the pentest.
exclude_risk_types: Option<Vec<RiskType>>The list of risk types excluded from the pentest.
service_role: Option<String>The IAM service role used for the pentest.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the pentest.
agent_space_id: Option<String>The unique identifier of the agent space that contains the pentest.
Implementations
Sourceimpl CreatePentestOutput
impl CreatePentestOutput
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
The unique identifier of the created pentest.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the pentest was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the pentest was last updated, in UTC format.
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
The list of risk types excluded from the pentest.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the pentest.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the pentest.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the pentest.
Sourceimpl CreatePentestOutput
impl CreatePentestOutput
Sourcepub fn builder() -> CreatePentestOutputBuilder
pub fn builder() -> CreatePentestOutputBuilder
Creates a new builder-style object to manufacture CreatePentestOutput.