#[non_exhaustive]pub struct CreatePrivateConnectionOutputBuilder { /* private fields */ }Expand description
A builder for CreatePrivateConnectionOutput.
Implementations
Sourceimpl CreatePrivateConnectionOutputBuilder
impl CreatePrivateConnectionOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the private connection.
This field is required.Sourcepub fn type(self, input: PrivateConnectionType) -> Self
pub fn type(self, input: PrivateConnectionType) -> Self
The type of the private connection, indicating whether it is service-managed or self-managed.
This field is required.Sourcepub fn set_type(self, input: Option<PrivateConnectionType>) -> Self
pub fn set_type(self, input: Option<PrivateConnectionType>) -> Self
The type of the private connection, indicating whether it is service-managed or self-managed.
Sourcepub fn get_type(&self) -> &Option<PrivateConnectionType>
pub fn get_type(&self) -> &Option<PrivateConnectionType>
The type of the private connection, indicating whether it is service-managed or self-managed.
Sourcepub fn status(self, input: PrivateConnectionStatus) -> Self
pub fn status(self, input: PrivateConnectionStatus) -> Self
The current status of the private connection.
This field is required.Sourcepub fn set_status(self, input: Option<PrivateConnectionStatus>) -> Self
pub fn set_status(self, input: Option<PrivateConnectionStatus>) -> Self
The current status of the private connection.
Sourcepub fn get_status(&self) -> &Option<PrivateConnectionStatus>
pub fn get_status(&self) -> &Option<PrivateConnectionStatus>
The current status of the private connection.
Sourcepub fn resource_gateway_id(self, input: impl Into<String>) -> Self
pub fn resource_gateway_id(self, input: impl Into<String>) -> Self
The identifier or ARN of the VPC Lattice resource gateway.
Sourcepub fn set_resource_gateway_id(self, input: Option<String>) -> Self
pub fn set_resource_gateway_id(self, input: Option<String>) -> Self
The identifier or ARN of the VPC Lattice resource gateway.
Sourcepub fn get_resource_gateway_id(&self) -> &Option<String>
pub fn get_resource_gateway_id(&self) -> &Option<String>
The identifier or ARN of the VPC Lattice resource gateway.
Sourcepub fn host_address(self, input: impl Into<String>) -> Self
pub fn host_address(self, input: impl Into<String>) -> Self
The IP address or DNS name of the target resource.
Sourcepub fn set_host_address(self, input: Option<String>) -> Self
pub fn set_host_address(self, input: Option<String>) -> Self
The IP address or DNS name of the target resource.
Sourcepub fn get_host_address(&self) -> &Option<String>
pub fn get_host_address(&self) -> &Option<String>
The IP address or DNS name of the target resource.
Sourcepub fn vpc_id(self, input: impl Into<String>) -> Self
pub fn vpc_id(self, input: impl Into<String>) -> Self
The identifier of the VPC the resource gateway is created in.
Sourcepub fn set_vpc_id(self, input: Option<String>) -> Self
pub fn set_vpc_id(self, input: Option<String>) -> Self
The identifier of the VPC the resource gateway is created in.
Sourcepub fn get_vpc_id(&self) -> &Option<String>
pub fn get_vpc_id(&self) -> &Option<String>
The identifier of the VPC the resource gateway is created in.
Sourcepub fn resource_configuration_id(self, input: impl Into<String>) -> Self
pub fn resource_configuration_id(self, input: impl Into<String>) -> Self
The identifier or ARN of the VPC Lattice resource configuration.
Sourcepub fn set_resource_configuration_id(self, input: Option<String>) -> Self
pub fn set_resource_configuration_id(self, input: Option<String>) -> Self
The identifier or ARN of the VPC Lattice resource configuration.
Sourcepub fn get_resource_configuration_id(&self) -> &Option<String>
pub fn get_resource_configuration_id(&self) -> &Option<String>
The identifier or ARN of the VPC Lattice resource configuration.
Sourcepub fn certificate_expiry_time(self, input: DateTime) -> Self
pub fn certificate_expiry_time(self, input: DateTime) -> Self
The date and time the connection's certificate expires, in UTC format.
Sourcepub fn set_certificate_expiry_time(self, input: Option<DateTime>) -> Self
pub fn set_certificate_expiry_time(self, input: Option<DateTime>) -> Self
The date and time the connection's certificate expires, in UTC format.
Sourcepub fn get_certificate_expiry_time(&self) -> &Option<DateTime>
pub fn get_certificate_expiry_time(&self) -> &Option<DateTime>
The date and time the connection's certificate expires, in UTC format.
Sourcepub fn dns_resolution(self, input: ResourceConfigDnsResolution) -> Self
pub fn dns_resolution(self, input: ResourceConfigDnsResolution) -> Self
The DNS resolution mode for the resource gateway.
Sourcepub fn set_dns_resolution(
self,
input: Option<ResourceConfigDnsResolution>,
) -> Self
pub fn set_dns_resolution( self, input: Option<ResourceConfigDnsResolution>, ) -> Self
The DNS resolution mode for the resource gateway.
Sourcepub fn get_dns_resolution(&self) -> &Option<ResourceConfigDnsResolution>
pub fn get_dns_resolution(&self) -> &Option<ResourceConfigDnsResolution>
The DNS resolution mode for the resource gateway.
Sourcepub fn failure_message(self, input: impl Into<String>) -> Self
pub fn failure_message(self, input: impl Into<String>) -> Self
A message describing why the private connection entered a failed state, if applicable.
Sourcepub fn set_failure_message(self, input: Option<String>) -> Self
pub fn set_failure_message(self, input: Option<String>) -> Self
A message describing why the private connection entered a failed state, if applicable.
Sourcepub fn get_failure_message(&self) -> &Option<String>
pub fn get_failure_message(&self) -> &Option<String>
A message describing why the private connection entered a failed state, if applicable.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags attached to the private connection.
The tags attached to the private connection.
The tags attached to the private connection.
Sourcepub fn build(self) -> Result<CreatePrivateConnectionOutput, BuildError>
pub fn build(self) -> Result<CreatePrivateConnectionOutput, BuildError>
Consumes the builder and constructs a CreatePrivateConnectionOutput.
This method will fail if any of the following fields are not set: