CreatePrivateConnectionOutput

Struct CreatePrivateConnectionOutput 

#[non_exhaustive]
pub struct CreatePrivateConnectionOutput { pub name: String, pub type: PrivateConnectionType, pub status: PrivateConnectionStatus, pub resource_gateway_id: Option<String>, pub host_address: Option<String>, pub vpc_id: Option<String>, pub resource_configuration_id: Option<String>, pub certificate_expiry_time: Option<DateTime>, pub dns_resolution: Option<ResourceConfigDnsResolution>, pub failure_message: Option<String>, pub tags: Option<HashMap<String, String>>, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The name of the private connection.

type: PrivateConnectionType

The type of the private connection, indicating whether it is service-managed or self-managed.

status: PrivateConnectionStatus

The current status of the private connection.

resource_gateway_id: Option<String>

The identifier or ARN of the VPC Lattice resource gateway.

host_address: Option<String>

The IP address or DNS name of the target resource.

vpc_id: Option<String>

The identifier of the VPC the resource gateway is created in.

resource_configuration_id: Option<String>

The identifier or ARN of the VPC Lattice resource configuration.

certificate_expiry_time: Option<DateTime>

The date and time the connection's certificate expires, in UTC format.

dns_resolution: Option<ResourceConfigDnsResolution>

The DNS resolution mode for the resource gateway.

failure_message: Option<String>

A message describing why the private connection entered a failed state, if applicable.

tags: Option<HashMap<String, String>>

The tags attached to the private connection.

Implementations

Source

impl CreatePrivateConnectionOutput

pub fn name(&self) -> &str

The name of the private connection.

pub fn type(&self) -> &PrivateConnectionType

The type of the private connection, indicating whether it is service-managed or self-managed.

pub fn status(&self) -> &PrivateConnectionStatus

The current status of the private connection.

pub fn resource_gateway_id(&self) -> Option<&str>

The identifier or ARN of the VPC Lattice resource gateway.

pub fn host_address(&self) -> Option<&str>

The IP address or DNS name of the target resource.

pub fn vpc_id(&self) -> Option<&str>

The identifier of the VPC the resource gateway is created in.

pub fn resource_configuration_id(&self) -> Option<&str>

The identifier or ARN of the VPC Lattice resource configuration.

pub fn certificate_expiry_time(&self) -> Option<&DateTime>

The date and time the connection's certificate expires, in UTC format.

pub fn dns_resolution(&self) -> Option<&ResourceConfigDnsResolution>

The DNS resolution mode for the resource gateway.

pub fn failure_message(&self) -> Option<&str>

A message describing why the private connection entered a failed state, if applicable.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags attached to the private connection.

Source

impl CreatePrivateConnectionOutput

pub fn builder() -> CreatePrivateConnectionOutputBuilder

Creates a new builder-style object to manufacture CreatePrivateConnectionOutput.