#[non_exhaustive]pub struct CreateSecurityRequirementPackOutputBuilder { /* private fields */ }Expand description
A builder for CreateSecurityRequirementPackOutput.
Implementations
Sourceimpl CreateSecurityRequirementPackOutputBuilder
impl CreateSecurityRequirementPackOutputBuilder
Sourcepub fn pack_id(self, input: impl Into<String>) -> Self
pub fn pack_id(self, input: impl Into<String>) -> Self
The unique identifier of the created security requirement pack.
This field is required.Sourcepub fn set_pack_id(self, input: Option<String>) -> Self
pub fn set_pack_id(self, input: Option<String>) -> Self
The unique identifier of the created security requirement pack.
Sourcepub fn get_pack_id(&self) -> &Option<String>
pub fn get_pack_id(&self) -> &Option<String>
The unique identifier of the created security requirement pack.
Sourcepub fn status(self, input: SecurityRequirementPackStatus) -> Self
pub fn status(self, input: SecurityRequirementPackStatus) -> Self
The status of the created security requirement pack.
This field is required.Sourcepub fn set_status(self, input: Option<SecurityRequirementPackStatus>) -> Self
pub fn set_status(self, input: Option<SecurityRequirementPackStatus>) -> Self
The status of the created security requirement pack.
Sourcepub fn get_status(&self) -> &Option<SecurityRequirementPackStatus>
pub fn get_status(&self) -> &Option<SecurityRequirementPackStatus>
The status of the created security requirement pack.
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
The identifier of the AWS KMS key used to encrypt pack contents.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
The identifier of the AWS KMS key used to encrypt pack contents.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
The identifier of the AWS KMS key used to encrypt pack contents.
Sourcepub fn build(self) -> Result<CreateSecurityRequirementPackOutput, BuildError>
pub fn build(self) -> Result<CreateSecurityRequirementPackOutput, BuildError>
Consumes the builder and constructs a CreateSecurityRequirementPackOutput.
This method will fail if any of the following fields are not set: