#[non_exhaustive]pub struct CreateSecurityRequirementPackInput {
pub name: Option<String>,
pub description: Option<String>,
pub status: Option<SecurityRequirementPackStatus>,
pub kms_key_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the security requirement pack.
description: Option<String>A description of the security requirement pack.
status: Option<SecurityRequirementPackStatus>The status of the pack. Defaults to ENABLED if not provided.
kms_key_id: Option<String>The identifier of the AWS KMS key used to encrypt pack contents.
The tags to associate with the security requirement pack.
Implementations
Sourceimpl CreateSecurityRequirementPackInput
impl CreateSecurityRequirementPackInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the security requirement pack.
Sourcepub fn status(&self) -> Option<&SecurityRequirementPackStatus>
pub fn status(&self) -> Option<&SecurityRequirementPackStatus>
The status of the pack. Defaults to ENABLED if not provided.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The identifier of the AWS KMS key used to encrypt pack contents.
The tags to associate with the security requirement pack.
Sourceimpl CreateSecurityRequirementPackInput
impl CreateSecurityRequirementPackInput
Sourcepub fn builder() -> CreateSecurityRequirementPackInputBuilder
pub fn builder() -> CreateSecurityRequirementPackInputBuilder
Creates a new builder-style object to manufacture CreateSecurityRequirementPackInput.