#[non_exhaustive]pub struct CreateTargetDomainOutput {
pub target_domain_id: String,
pub domain_name: String,
pub verification_status: TargetDomainStatus,
pub verification_details: Option<VerificationDetails>,
pub created_at: Option<DateTime>,
pub verified_at: Option<DateTime>,
/* private fields */
}Expand description
Output for the CreateTargetDomain operation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_domain_id: StringUnique identifier of the created target domain
domain_name: StringName of the created target domain
verification_status: TargetDomainStatusCurrent verification status of the registered target domain
verification_details: Option<VerificationDetails>Verification details to verify registered target domain
created_at: Option<DateTime>Timestamp when the target domain was registered
verified_at: Option<DateTime>Timestamp when the target domain was last successfully verified
Implementations
Sourceimpl CreateTargetDomainOutput
impl CreateTargetDomainOutput
Sourcepub fn target_domain_id(&self) -> &str
pub fn target_domain_id(&self) -> &str
Unique identifier of the created target domain
Sourcepub fn domain_name(&self) -> &str
pub fn domain_name(&self) -> &str
Name of the created target domain
Sourcepub fn verification_status(&self) -> &TargetDomainStatus
pub fn verification_status(&self) -> &TargetDomainStatus
Current verification status of the registered target domain
Sourcepub fn verification_details(&self) -> Option<&VerificationDetails>
pub fn verification_details(&self) -> Option<&VerificationDetails>
Verification details to verify registered target domain
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the target domain was registered
Sourcepub fn verified_at(&self) -> Option<&DateTime>
pub fn verified_at(&self) -> Option<&DateTime>
Timestamp when the target domain was last successfully verified
Sourceimpl CreateTargetDomainOutput
impl CreateTargetDomainOutput
Sourcepub fn builder() -> CreateTargetDomainOutputBuilder
pub fn builder() -> CreateTargetDomainOutputBuilder
Creates a new builder-style object to manufacture CreateTargetDomainOutput.