#[non_exhaustive]pub struct CreateThreatInput {Show 16 fields
pub agent_space_id: Option<String>,
pub threat_job_id: Option<String>,
pub title: Option<String>,
pub statement: Option<String>,
pub severity: Option<ThreatSeverity>,
pub comments: Option<String>,
pub stride: Option<Vec<StrideCategory>>,
pub threat_source: Option<String>,
pub prerequisites: Option<String>,
pub threat_action: Option<String>,
pub threat_impact: Option<String>,
pub impacted_goal: Option<Vec<String>>,
pub impacted_assets: Option<Vec<String>>,
pub anchor: Option<ThreatAnchorShape>,
pub evidence: Option<Vec<ThreatEvidenceShape>>,
pub recommendation: Option<String>,
}Expand description
Input for creating a new threat.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space.
threat_job_id: Option<String>The unique identifier of the threat model job the threat belongs to.
title: Option<String>A short title summarizing the threat.
statement: Option<String>The natural-language threat statement.
severity: Option<ThreatSeverity>The severity level of the threat.
comments: Option<String>Optional customer comment on the threat.
stride: Option<Vec<StrideCategory>>The STRIDE categories applicable to this threat.
threat_source: Option<String>The actor or origin of the threat.
prerequisites: Option<String>The conditions required for the threat to be exploitable.
threat_action: Option<String>What the threat source can do.
threat_impact: Option<String>The direct consequence of the threat action.
impacted_goal: Option<Vec<String>>The security goals affected by the threat.
impacted_assets: Option<Vec<String>>The specific assets affected by the threat.
anchor: Option<ThreatAnchorShape>The DFD element this threat is anchored to.
evidence: Option<Vec<ThreatEvidenceShape>>The source code files supporting the threat.
recommendation: Option<String>The recommended mitigation guidance for this threat.
Implementations
Sourceimpl CreateThreatInput
impl CreateThreatInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn threat_job_id(&self) -> Option<&str>
pub fn threat_job_id(&self) -> Option<&str>
The unique identifier of the threat model job the threat belongs to.
Sourcepub fn severity(&self) -> Option<&ThreatSeverity>
pub fn severity(&self) -> Option<&ThreatSeverity>
The severity level of the threat.
Sourcepub fn stride(&self) -> &[StrideCategory]
pub fn stride(&self) -> &[StrideCategory]
The STRIDE categories applicable to this threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .stride.is_none().
Sourcepub fn threat_source(&self) -> Option<&str>
pub fn threat_source(&self) -> Option<&str>
The actor or origin of the threat.
Sourcepub fn prerequisites(&self) -> Option<&str>
pub fn prerequisites(&self) -> Option<&str>
The conditions required for the threat to be exploitable.
Sourcepub fn threat_action(&self) -> Option<&str>
pub fn threat_action(&self) -> Option<&str>
What the threat source can do.
Sourcepub fn threat_impact(&self) -> Option<&str>
pub fn threat_impact(&self) -> Option<&str>
The direct consequence of the threat action.
Sourcepub fn impacted_goal(&self) -> &[String]
pub fn impacted_goal(&self) -> &[String]
The security goals affected by the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_goal.is_none().
Sourcepub fn impacted_assets(&self) -> &[String]
pub fn impacted_assets(&self) -> &[String]
The specific assets affected by the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_assets.is_none().
Sourcepub fn anchor(&self) -> Option<&ThreatAnchorShape>
pub fn anchor(&self) -> Option<&ThreatAnchorShape>
The DFD element this threat is anchored to.
Sourcepub fn evidence(&self) -> &[ThreatEvidenceShape]
pub fn evidence(&self) -> &[ThreatEvidenceShape]
The source code files supporting the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .evidence.is_none().
Sourcepub fn recommendation(&self) -> Option<&str>
pub fn recommendation(&self) -> Option<&str>
The recommended mitigation guidance for this threat.
Sourceimpl CreateThreatInput
impl CreateThreatInput
Sourcepub fn builder() -> CreateThreatInputBuilder
pub fn builder() -> CreateThreatInputBuilder
Creates a new builder-style object to manufacture CreateThreatInput.