CreateThreatOutput

Struct CreateThreatOutput 

#[non_exhaustive]
pub struct CreateThreatOutput {
Show 21 fields pub threat_id: String, pub threat_job_id: String, pub title: Option<String>, pub statement: Option<String>, pub severity: Option<ThreatSeverity>, pub status: Option<ThreatStatus>, pub comments: Option<String>, pub stride: Option<Vec<StrideCategory>>, pub threat_source: Option<String>, pub prerequisites: Option<String>, pub threat_action: Option<String>, pub threat_impact: Option<String>, pub impacted_goal: Option<Vec<String>>, pub impacted_assets: Option<Vec<String>>, pub anchor: Option<ThreatAnchorShape>, pub evidence: Option<Vec<ThreatEvidenceShape>>, pub recommendation: Option<String>, pub created_by: Option<ThreatActor>, pub updated_by: Option<ThreatActor>, pub created_at: Option<DateTime>, pub updated_at: Option<DateTime>, /* private fields */
}
Output for the CreateThreat operation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
threat_id: String

The unique identifier of the created threat.

threat_job_id: String

The unique identifier of the threat model job the threat belongs to.

title: Option<String>

A short title summarizing the threat.

statement: Option<String>

The natural-language threat statement.

severity: Option<ThreatSeverity>

The severity level of the threat.

status: Option<ThreatStatus>

The current status of the threat.

comments: Option<String>

Optional customer comment on the threat.

stride: Option<Vec<StrideCategory>>

The STRIDE categories applicable to this threat.

threat_source: Option<String>

The actor or origin of the threat.

prerequisites: Option<String>

The conditions required for the threat to be exploitable.

threat_action: Option<String>

What the threat source can do.

threat_impact: Option<String>

The direct consequence of the threat action.

impacted_goal: Option<Vec<String>>

The security goals affected by the threat.

impacted_assets: Option<Vec<String>>

The specific assets affected by the threat.

anchor: Option<ThreatAnchorShape>

The DFD element this threat is anchored to.

evidence: Option<Vec<ThreatEvidenceShape>>

The source code files supporting the threat.

recommendation: Option<String>

The recommended mitigation guidance for this threat.

created_by: Option<ThreatActor>

Who created this threat.

updated_by: Option<ThreatActor>

Who last updated this threat.

created_at: Option<DateTime>

The date and time the threat was created, in UTC format.

updated_at: Option<DateTime>

The date and time the threat was last updated, in UTC format.

Implementations

Source

impl CreateThreatOutput

pub fn threat_id(&self) -> &str

The unique identifier of the created threat.

pub fn threat_job_id(&self) -> &str

The unique identifier of the threat model job the threat belongs to.

pub fn title(&self) -> Option<&str>

A short title summarizing the threat.

pub fn statement(&self) -> Option<&str>

The natural-language threat statement.

pub fn severity(&self) -> Option<&ThreatSeverity>

The severity level of the threat.

pub fn status(&self) -> Option<&ThreatStatus>

The current status of the threat.

pub fn comments(&self) -> Option<&str>

Optional customer comment on the threat.

pub fn stride(&self) -> &[StrideCategory]

The STRIDE categories applicable to this threat.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .stride.is_none().

pub fn threat_source(&self) -> Option<&str>

The actor or origin of the threat.

pub fn prerequisites(&self) -> Option<&str>

The conditions required for the threat to be exploitable.

pub fn threat_action(&self) -> Option<&str>

What the threat source can do.

pub fn threat_impact(&self) -> Option<&str>

The direct consequence of the threat action.

pub fn impacted_goal(&self) -> &[String]

The security goals affected by the threat.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_goal.is_none().

pub fn impacted_assets(&self) -> &[String]

The specific assets affected by the threat.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_assets.is_none().

pub fn anchor(&self) -> Option<&ThreatAnchorShape>

The DFD element this threat is anchored to.

pub fn evidence(&self) -> &[ThreatEvidenceShape]

The source code files supporting the threat.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .evidence.is_none().

pub fn recommendation(&self) -> Option<&str>

The recommended mitigation guidance for this threat.

pub fn created_by(&self) -> Option<&ThreatActor>

Who created this threat.

pub fn updated_by(&self) -> Option<&ThreatActor>

Who last updated this threat.

pub fn created_at(&self) -> Option<&DateTime>

The date and time the threat was created, in UTC format.

pub fn updated_at(&self) -> Option<&DateTime>

The date and time the threat was last updated, in UTC format.

Source

impl CreateThreatOutput

pub fn builder() -> CreateThreatOutputBuilder

Creates a new builder-style object to manufacture CreateThreatOutput.