#[non_exhaustive]pub struct CreateThreatModelInput {
pub title: Option<String>,
pub agent_space_id: Option<String>,
pub description: Option<String>,
pub assets: Option<Assets>,
pub scope_docs: Option<Vec<DocumentInfo>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub report_destination: Option<ReportDestination>,
}Expand description
Input for creating a new threat model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the threat model.
agent_space_id: Option<String>The unique identifier of the agent space to create the threat model in.
description: Option<String>A description of the application or system being threat modeled.
assets: Option<Assets>The assets to include in the threat model.
scope_docs: Option<Vec<DocumentInfo>>The scoped documents for the agent to focus on during threat modeling.
service_role: Option<String>The IAM service role to use for the threat model.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the threat model.
report_destination: Option<ReportDestination>The destination for publishing scan reports to an integrated document provider.
Implementations
Sourceimpl CreateThreatModelInput
impl CreateThreatModelInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to create the threat model in.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the application or system being threat modeled.
Sourcepub fn scope_docs(&self) -> &[DocumentInfo]
pub fn scope_docs(&self) -> &[DocumentInfo]
The scoped documents for the agent to focus on during threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scope_docs.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role to use for the threat model.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the threat model.
Sourcepub fn report_destination(&self) -> Option<&ReportDestination>
pub fn report_destination(&self) -> Option<&ReportDestination>
The destination for publishing scan reports to an integrated document provider.
Sourceimpl CreateThreatModelInput
impl CreateThreatModelInput
Sourcepub fn builder() -> CreateThreatModelInputBuilder
pub fn builder() -> CreateThreatModelInputBuilder
Creates a new builder-style object to manufacture CreateThreatModelInput.