#[non_exhaustive]pub struct CreateThreatModelOutput {
pub threat_model_id: String,
pub title: Option<String>,
pub agent_space_id: Option<String>,
pub description: Option<String>,
pub assets: Option<Assets>,
pub scope_docs: Option<Vec<DocumentInfo>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
/* private fields */
}Expand description
Output for the CreateThreatModel operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_id: StringThe unique identifier of the created threat model.
title: Option<String>The title of the threat model.
agent_space_id: Option<String>The unique identifier of the agent space that contains the threat model.
description: Option<String>A description of the application or system being threat modeled.
assets: Option<Assets>The assets included in the threat model.
scope_docs: Option<Vec<DocumentInfo>>The scoped documents for the agent to focus on during threat modeling.
service_role: Option<String>The IAM service role used for the threat model.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the threat model.
created_at: Option<DateTime>The date and time the threat model was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat model was last updated, in UTC format.
Implementations
Sourceimpl CreateThreatModelOutput
impl CreateThreatModelOutput
Sourcepub fn threat_model_id(&self) -> &str
pub fn threat_model_id(&self) -> &str
The unique identifier of the created threat model.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the threat model.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the application or system being threat modeled.
Sourcepub fn scope_docs(&self) -> &[DocumentInfo]
pub fn scope_docs(&self) -> &[DocumentInfo]
The scoped documents for the agent to focus on during threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scope_docs.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the threat model.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the threat model.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat model was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat model was last updated, in UTC format.
Sourceimpl CreateThreatModelOutput
impl CreateThreatModelOutput
Sourcepub fn builder() -> CreateThreatModelOutputBuilder
pub fn builder() -> CreateThreatModelOutputBuilder
Creates a new builder-style object to manufacture CreateThreatModelOutput.