#[non_exhaustive]pub struct GetApplicationOutputBuilder { /* private fields */ }Expand description
A builder for GetApplicationOutput.
Implementations
Sourceimpl GetApplicationOutputBuilder
impl GetApplicationOutputBuilder
Sourcepub fn application_id(self, input: impl Into<String>) -> Self
pub fn application_id(self, input: impl Into<String>) -> Self
The unique identifier of the application.
This field is required.Sourcepub fn set_application_id(self, input: Option<String>) -> Self
pub fn set_application_id(self, input: Option<String>) -> Self
The unique identifier of the application.
Sourcepub fn get_application_id(&self) -> &Option<String>
pub fn get_application_id(&self) -> &Option<String>
The unique identifier of the application.
Sourcepub fn domain(self, input: impl Into<String>) -> Self
pub fn domain(self, input: impl Into<String>) -> Self
The domain associated with the application.
This field is required.Sourcepub fn set_domain(self, input: Option<String>) -> Self
pub fn set_domain(self, input: Option<String>) -> Self
The domain associated with the application.
Sourcepub fn get_domain(&self) -> &Option<String>
pub fn get_domain(&self) -> &Option<String>
The domain associated with the application.
Sourcepub fn application_name(self, input: impl Into<String>) -> Self
pub fn application_name(self, input: impl Into<String>) -> Self
The name of the application.
Sourcepub fn set_application_name(self, input: Option<String>) -> Self
pub fn set_application_name(self, input: Option<String>) -> Self
The name of the application.
Sourcepub fn get_application_name(&self) -> &Option<String>
pub fn get_application_name(&self) -> &Option<String>
The name of the application.
Sourcepub fn idc_configuration(self, input: IdCConfiguration) -> Self
pub fn idc_configuration(self, input: IdCConfiguration) -> Self
The IAM Identity Center configuration for the application.
Sourcepub fn set_idc_configuration(self, input: Option<IdCConfiguration>) -> Self
pub fn set_idc_configuration(self, input: Option<IdCConfiguration>) -> Self
The IAM Identity Center configuration for the application.
Sourcepub fn get_idc_configuration(&self) -> &Option<IdCConfiguration>
pub fn get_idc_configuration(&self) -> &Option<IdCConfiguration>
The IAM Identity Center configuration for the application.
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role associated with the application.
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role associated with the application.
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the IAM role associated with the application.
Sourcepub fn default_kms_key_id(self, input: impl Into<String>) -> Self
pub fn default_kms_key_id(self, input: impl Into<String>) -> Self
The identifier of the default AWS KMS key used to encrypt data for the application.
Sourcepub fn set_default_kms_key_id(self, input: Option<String>) -> Self
pub fn set_default_kms_key_id(self, input: Option<String>) -> Self
The identifier of the default AWS KMS key used to encrypt data for the application.
Sourcepub fn get_default_kms_key_id(&self) -> &Option<String>
pub fn get_default_kms_key_id(&self) -> &Option<String>
The identifier of the default AWS KMS key used to encrypt data for the application.
Sourcepub fn build(self) -> Result<GetApplicationOutput, BuildError>
pub fn build(self) -> Result<GetApplicationOutput, BuildError>
Consumes the builder and constructs a GetApplicationOutput.
This method will fail if any of the following fields are not set: