#[non_exhaustive]pub struct GetIntegrationOutputBuilder { /* private fields */ }Expand description
A builder for GetIntegrationOutput.
Implementations
Sourceimpl GetIntegrationOutputBuilder
impl GetIntegrationOutputBuilder
Sourcepub fn integration_id(self, input: impl Into<String>) -> Self
pub fn integration_id(self, input: impl Into<String>) -> Self
Unique identifier of the integration This field is required.
Sourcepub fn set_integration_id(self, input: Option<String>) -> Self
pub fn set_integration_id(self, input: Option<String>) -> Self
Unique identifier of the integration
Sourcepub fn get_integration_id(&self) -> &Option<String>
pub fn get_integration_id(&self) -> &Option<String>
Unique identifier of the integration
Sourcepub fn installation_id(self, input: impl Into<String>) -> Self
pub fn installation_id(self, input: impl Into<String>) -> Self
Installation identifier from the provider This field is required.
Sourcepub fn set_installation_id(self, input: Option<String>) -> Self
pub fn set_installation_id(self, input: Option<String>) -> Self
Installation identifier from the provider
Sourcepub fn get_installation_id(&self) -> &Option<String>
pub fn get_installation_id(&self) -> &Option<String>
Installation identifier from the provider
Sourcepub fn set_provider(self, input: Option<Provider>) -> Self
pub fn set_provider(self, input: Option<Provider>) -> Self
Provider type
Sourcepub fn get_provider(&self) -> &Option<Provider>
pub fn get_provider(&self) -> &Option<Provider>
Provider type
Sourcepub fn provider_type(self, input: ProviderType) -> Self
pub fn provider_type(self, input: ProviderType) -> Self
Type of provider integration This field is required.
Sourcepub fn set_provider_type(self, input: Option<ProviderType>) -> Self
pub fn set_provider_type(self, input: Option<ProviderType>) -> Self
Type of provider integration
Sourcepub fn get_provider_type(&self) -> &Option<ProviderType>
pub fn get_provider_type(&self) -> &Option<ProviderType>
Type of provider integration
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
Display name for the integration
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
Display name for the integration
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
Display name for the integration
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
KMS key ID for encrypting integration details
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
KMS key ID for encrypting integration details
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
KMS key ID for encrypting integration details
Sourcepub fn build(self) -> Result<GetIntegrationOutput, BuildError>
pub fn build(self) -> Result<GetIntegrationOutput, BuildError>
Consumes the builder and constructs a GetIntegrationOutput.
This method will fail if any of the following fields are not set: