#[non_exhaustive]pub struct GetSecurityRequirementPackOutput {
pub pack_id: String,
pub name: String,
pub description: Option<String>,
pub vendor_name: Option<String>,
pub management_type: ManagementType,
pub status: SecurityRequirementPackStatus,
pub import_status: Option<SecurityRequirementPackImportStatus>,
pub created_at: DateTime,
pub updated_at: DateTime,
pub kms_key_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pack_id: StringThe unique identifier of the security requirement pack.
name: StringThe name of the security requirement pack.
description: Option<String>A description of the security requirement pack.
vendor_name: Option<String>The vendor name for AWS managed packs, such as ISO or NIST.
management_type: ManagementTypeThe management type of the pack. Valid values are AWS_MANAGED and CUSTOMER_MANAGED.
status: SecurityRequirementPackStatusThe status of the security requirement pack.
import_status: Option<SecurityRequirementPackImportStatus>The status of the security requirements import workflow for this pack.
created_at: DateTimeThe date and time the security requirement pack was created, in UTC format.
updated_at: DateTimeThe date and time the security requirement pack was last updated, in UTC format.
kms_key_id: Option<String>The identifier of the AWS KMS key used to encrypt pack contents.
Implementations
Sourceimpl GetSecurityRequirementPackOutput
impl GetSecurityRequirementPackOutput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the security requirement pack.
Sourcepub fn vendor_name(&self) -> Option<&str>
pub fn vendor_name(&self) -> Option<&str>
The vendor name for AWS managed packs, such as ISO or NIST.
Sourcepub fn management_type(&self) -> &ManagementType
pub fn management_type(&self) -> &ManagementType
The management type of the pack. Valid values are AWS_MANAGED and CUSTOMER_MANAGED.
Sourcepub fn status(&self) -> &SecurityRequirementPackStatus
pub fn status(&self) -> &SecurityRequirementPackStatus
The status of the security requirement pack.
Sourcepub fn import_status(&self) -> Option<&SecurityRequirementPackImportStatus>
pub fn import_status(&self) -> Option<&SecurityRequirementPackImportStatus>
The status of the security requirements import workflow for this pack.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the security requirement pack was created, in UTC format.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The date and time the security requirement pack was last updated, in UTC format.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The identifier of the AWS KMS key used to encrypt pack contents.
Sourceimpl GetSecurityRequirementPackOutput
impl GetSecurityRequirementPackOutput
Sourcepub fn builder() -> GetSecurityRequirementPackOutputBuilder
pub fn builder() -> GetSecurityRequirementPackOutputBuilder
Creates a new builder-style object to manufacture GetSecurityRequirementPackOutput.