#[non_exhaustive]pub struct ListCodeReviewJobTasksInput {
pub agent_space_id: Option<String>,
pub max_results: Option<i32>,
pub code_review_job_id: Option<String>,
pub step_name: Option<StepName>,
pub category_name: Option<String>,
pub next_token: Option<String>,
}Expand description
Input for listing tasks associated with a code review job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space.
max_results: Option<i32>The maximum number of results to return in a single call.
code_review_job_id: Option<String>The unique identifier of the code review job to list tasks for.
step_name: Option<StepName>Filter tasks by step name.
category_name: Option<String>Filter tasks by category name.
next_token: Option<String>A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Implementations
Sourceimpl ListCodeReviewJobTasksInput
impl ListCodeReviewJobTasksInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single call.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job to list tasks for.
Sourcepub fn category_name(&self) -> Option<&str>
pub fn category_name(&self) -> Option<&str>
Filter tasks by category name.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Sourceimpl ListCodeReviewJobTasksInput
impl ListCodeReviewJobTasksInput
Sourcepub fn builder() -> ListCodeReviewJobTasksInputBuilder
pub fn builder() -> ListCodeReviewJobTasksInputBuilder
Creates a new builder-style object to manufacture ListCodeReviewJobTasksInput.