#[non_exhaustive]pub struct ListDiscoveredEndpointsInput {
pub max_results: Option<i32>,
pub pentest_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub prefix: Option<String>,
pub next_token: Option<String>,
}Expand description
Input for ListDiscoveredEndpoints operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum number of results to return in a single call.
pentest_job_id: Option<String>The unique identifier of the pentest job to list discovered endpoints for.
agent_space_id: Option<String>The unique identifier of the agent space.
prefix: Option<String>A prefix to filter discovered endpoints by URI.
next_token: Option<String>A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Implementations
Sourceimpl ListDiscoveredEndpointsInput
impl ListDiscoveredEndpointsInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single call.
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
The unique identifier of the pentest job to list discovered endpoints for.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Sourceimpl ListDiscoveredEndpointsInput
impl ListDiscoveredEndpointsInput
Sourcepub fn builder() -> ListDiscoveredEndpointsInputBuilder
pub fn builder() -> ListDiscoveredEndpointsInputBuilder
Creates a new builder-style object to manufacture ListDiscoveredEndpointsInput.