#[non_exhaustive]pub struct ListIntegratedResourcesInput {
pub agent_space_id: Option<String>,
pub integration_id: Option<String>,
pub resource_type: Option<ResourceType>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space to list integrated resources for.
integration_id: Option<String>The unique identifier of the integration to filter by.
resource_type: Option<ResourceType>The type of resource to filter by.
next_token: Option<String>A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
max_results: Option<i32>The maximum number of results to return in a single call.
Implementations
Sourceimpl ListIntegratedResourcesInput
impl ListIntegratedResourcesInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to list integrated resources for.
Sourcepub fn integration_id(&self) -> Option<&str>
pub fn integration_id(&self) -> Option<&str>
The unique identifier of the integration to filter by.
Sourcepub fn resource_type(&self) -> Option<&ResourceType>
pub fn resource_type(&self) -> Option<&ResourceType>
The type of resource to filter by.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single call.
Sourceimpl ListIntegratedResourcesInput
impl ListIntegratedResourcesInput
Sourcepub fn builder() -> ListIntegratedResourcesInputBuilder
pub fn builder() -> ListIntegratedResourcesInputBuilder
Creates a new builder-style object to manufacture ListIntegratedResourcesInput.