#[non_exhaustive]pub struct ListPentestsInput {
pub max_results: Option<i32>,
pub next_token: Option<String>,
pub agent_space_id: Option<String>,
}Expand description
Input for listing pentests with optional filtering.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum number of results to return in a single call.
next_token: Option<String>A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
agent_space_id: Option<String>The unique identifier of the agent space to list pentests for.
Implementations
Sourceimpl ListPentestsInput
impl ListPentestsInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single call.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space to list pentests for.
Sourceimpl ListPentestsInput
impl ListPentestsInput
Sourcepub fn builder() -> ListPentestsInputBuilder
pub fn builder() -> ListPentestsInputBuilder
Creates a new builder-style object to manufacture ListPentestsInput.