#[non_exhaustive]pub struct ListSecurityRequirementsInput {
pub pack_id: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pack_id: Option<String>The unique identifier of the security requirement pack to list requirements for.
next_token: Option<String>The pagination token from a previous request to retrieve the next page of results.
max_results: Option<i32>The maximum number of results to return in a single request.
Implementations
Sourceimpl ListSecurityRequirementsInput
impl ListSecurityRequirementsInput
Sourcepub fn pack_id(&self) -> Option<&str>
pub fn pack_id(&self) -> Option<&str>
The unique identifier of the security requirement pack to list requirements for.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token from a previous request to retrieve the next page of results.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single request.
Sourceimpl ListSecurityRequirementsInput
impl ListSecurityRequirementsInput
Sourcepub fn builder() -> ListSecurityRequirementsInputBuilder
pub fn builder() -> ListSecurityRequirementsInputBuilder
Creates a new builder-style object to manufacture ListSecurityRequirementsInput.