pub struct StartCodeRemediationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartCodeRemediation.
Starts code remediation for the specified findings
Implementations
Sourceimpl StartCodeRemediationFluentBuilder
impl StartCodeRemediationFluentBuilder
Sourcepub fn as_input(&self) -> &StartCodeRemediationInputBuilder
pub fn as_input(&self) -> &StartCodeRemediationInputBuilder
Access the StartCodeRemediation as a reference.
Sourcepub async fn send(
self,
) -> Result<StartCodeRemediationOutput, SdkError<StartCodeRemediationError, HttpResponse>>
pub async fn send( self, ) -> Result<StartCodeRemediationOutput, SdkError<StartCodeRemediationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StartCodeRemediationOutput, StartCodeRemediationError, Self>
pub fn customize( self, ) -> CustomizableOperation<StartCodeRemediationOutput, StartCodeRemediationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
ID of the agent space where the pentest job exists
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
ID of the agent space where the pentest job exists
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
ID of the agent space where the pentest job exists
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
Identifier of the pentest job to start code remediation for
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
Identifier of the pentest job to start code remediation for
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
Identifier of the pentest job to start code remediation for
Sourcepub fn finding_ids(self, input: impl Into<String>) -> Self
pub fn finding_ids(self, input: impl Into<String>) -> Self
Appends an item to findingIds.
To override the contents of this collection use set_finding_ids.
Identifiers of the findings to start code remediation for
Sourcepub fn set_finding_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_finding_ids(self, input: Option<Vec<String>>) -> Self
Identifiers of the findings to start code remediation for
Sourcepub fn get_finding_ids(&self) -> &Option<Vec<String>>
pub fn get_finding_ids(&self) -> &Option<Vec<String>>
Identifiers of the findings to start code remediation for