#[non_exhaustive]pub struct StartCodeRemediationInputBuilder { /* private fields */ }Expand description
A builder for StartCodeRemediationInput.
Implementations
Sourceimpl StartCodeRemediationInputBuilder
impl StartCodeRemediationInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest job that produced the findings. Mutually exclusive with codeReviewJobId.
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
The unique identifier of the pentest job that produced the findings. Mutually exclusive with codeReviewJobId.
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
The unique identifier of the pentest job that produced the findings. Mutually exclusive with codeReviewJobId.
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job that produced the findings. Mutually exclusive with pentestJobId.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job that produced the findings. Mutually exclusive with pentestJobId.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job that produced the findings. Mutually exclusive with pentestJobId.
Sourcepub fn finding_ids(self, input: impl Into<String>) -> Self
pub fn finding_ids(self, input: impl Into<String>) -> Self
Appends an item to finding_ids.
To override the contents of this collection use set_finding_ids.
The list of finding identifiers to initiate code remediation for.
Sourcepub fn set_finding_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_finding_ids(self, input: Option<Vec<String>>) -> Self
The list of finding identifiers to initiate code remediation for.
Sourcepub fn get_finding_ids(&self) -> &Option<Vec<String>>
pub fn get_finding_ids(&self) -> &Option<Vec<String>>
The list of finding identifiers to initiate code remediation for.
Sourcepub fn build(self) -> Result<StartCodeRemediationInput, BuildError>
pub fn build(self) -> Result<StartCodeRemediationInput, BuildError>
Consumes the builder and constructs a StartCodeRemediationInput.
Sourceimpl StartCodeRemediationInputBuilder
impl StartCodeRemediationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartCodeRemediationOutput, SdkError<StartCodeRemediationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartCodeRemediationOutput, SdkError<StartCodeRemediationError, HttpResponse>>
Sends a request with this input using the given client.