#[non_exhaustive]pub struct StartCodeRemediationInput {
pub agent_space_id: Option<String>,
pub pentest_job_id: Option<String>,
pub code_review_job_id: Option<String>,
pub finding_ids: Option<Vec<String>>,
}Expand description
Input for the StartCodeRemediation operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space.
pentest_job_id: Option<String>The unique identifier of the pentest job that produced the findings. Mutually exclusive with codeReviewJobId.
code_review_job_id: Option<String>The unique identifier of the code review job that produced the findings. Mutually exclusive with pentestJobId.
finding_ids: Option<Vec<String>>The list of finding identifiers to initiate code remediation for.
Implementations
Sourceimpl StartCodeRemediationInput
impl StartCodeRemediationInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
The unique identifier of the pentest job that produced the findings. Mutually exclusive with codeReviewJobId.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job that produced the findings. Mutually exclusive with pentestJobId.
Sourcepub fn finding_ids(&self) -> &[String]
pub fn finding_ids(&self) -> &[String]
The list of finding identifiers to initiate code remediation for.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .finding_ids.is_none().
Sourceimpl StartCodeRemediationInput
impl StartCodeRemediationInput
Sourcepub fn builder() -> StartCodeRemediationInputBuilder
pub fn builder() -> StartCodeRemediationInputBuilder
Creates a new builder-style object to manufacture StartCodeRemediationInput.