#[non_exhaustive]pub struct StartCodeReviewJobInputBuilder { /* private fields */ }Expand description
A builder for StartCodeReviewJobInput.
Implementations
Sourceimpl StartCodeReviewJobInputBuilder
impl StartCodeReviewJobInputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review to start a job for.
This field is required.Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review to start a job for.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review to start a job for.
Sourcepub fn build(self) -> Result<StartCodeReviewJobInput, BuildError>
pub fn build(self) -> Result<StartCodeReviewJobInput, BuildError>
Consumes the builder and constructs a StartCodeReviewJobInput.
Sourceimpl StartCodeReviewJobInputBuilder
impl StartCodeReviewJobInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartCodeReviewJobOutput, SdkError<StartCodeReviewJobError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartCodeReviewJobOutput, SdkError<StartCodeReviewJobError, HttpResponse>>
Sends a request with this input using the given client.