#[non_exhaustive]pub struct StartCodeReviewJobOutput {
pub title: Option<String>,
pub status: Option<JobStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub code_review_id: String,
pub code_review_job_id: String,
pub agent_space_id: Option<String>,
/* private fields */
}Expand description
Output for the StartCodeReviewJob operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the code review job.
status: Option<JobStatus>The current status of the code review job.
created_at: Option<DateTime>The date and time the code review job was created, in UTC format.
updated_at: Option<DateTime>The date and time the code review job was last updated, in UTC format.
code_review_id: StringThe unique identifier of the code review.
code_review_job_id: StringThe unique identifier of the started code review job.
agent_space_id: Option<String>The unique identifier of the agent space.
Implementations
Sourceimpl StartCodeReviewJobOutput
impl StartCodeReviewJobOutput
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the code review job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the code review job was last updated, in UTC format.
Sourcepub fn code_review_id(&self) -> &str
pub fn code_review_id(&self) -> &str
The unique identifier of the code review.
Sourcepub fn code_review_job_id(&self) -> &str
pub fn code_review_job_id(&self) -> &str
The unique identifier of the started code review job.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourceimpl StartCodeReviewJobOutput
impl StartCodeReviewJobOutput
Sourcepub fn builder() -> StartCodeReviewJobOutputBuilder
pub fn builder() -> StartCodeReviewJobOutputBuilder
Creates a new builder-style object to manufacture StartCodeReviewJobOutput.