#[non_exhaustive]pub struct StopCodeReviewJobInput {
pub agent_space_id: Option<String>,
pub code_review_job_id: Option<String>,
}Expand description
Input for stopping the execution of a code review job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>The unique identifier of the agent space.
code_review_job_id: Option<String>The unique identifier of the code review job to stop.
Implementations
Sourceimpl StopCodeReviewJobInput
impl StopCodeReviewJobInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job to stop.
Sourceimpl StopCodeReviewJobInput
impl StopCodeReviewJobInput
Sourcepub fn builder() -> StopCodeReviewJobInputBuilder
pub fn builder() -> StopCodeReviewJobInputBuilder
Creates a new builder-style object to manufacture StopCodeReviewJobInput.