#[non_exhaustive]pub struct UpdateAgentSpaceInput {
pub agent_space_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub aws_resources: Option<AwsResources>,
pub target_domain_ids: Option<Vec<String>>,
pub code_review_settings: Option<CodeReviewSettings>,
}Expand description
Input for updating an agent space
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: Option<String>ID of the agent space to update
name: Option<String>Name of the agent space
description: Option<String>Description of the agent space
aws_resources: Option<AwsResources>AWS resource configurations associated with the agent space
target_domain_ids: Option<Vec<String>>Target domain IDs to associate with the agent space
code_review_settings: Option<CodeReviewSettings>Configuration for code review analysis, including controls scanning and general purpose scanning settings
Implementations
Sourceimpl UpdateAgentSpaceInput
impl UpdateAgentSpaceInput
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
ID of the agent space to update
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Description of the agent space
Sourcepub fn aws_resources(&self) -> Option<&AwsResources>
pub fn aws_resources(&self) -> Option<&AwsResources>
AWS resource configurations associated with the agent space
Sourcepub fn target_domain_ids(&self) -> &[String]
pub fn target_domain_ids(&self) -> &[String]
Target domain IDs to associate with the agent space
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .target_domain_ids.is_none().
Sourcepub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
pub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourceimpl UpdateAgentSpaceInput
impl UpdateAgentSpaceInput
Sourcepub fn builder() -> UpdateAgentSpaceInputBuilder
pub fn builder() -> UpdateAgentSpaceInputBuilder
Creates a new builder-style object to manufacture UpdateAgentSpaceInput.