#[non_exhaustive]pub struct UpdateCodeReviewInputBuilder { /* private fields */ }Expand description
A builder for UpdateCodeReviewInput.
Implementations
Sourceimpl UpdateCodeReviewInputBuilder
impl UpdateCodeReviewInputBuilder
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review to update.
This field is required.Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review to update.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review to update.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the code review.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the code review.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the code review.
Sourcepub fn set_assets(self, input: Option<Assets>) -> Self
pub fn set_assets(self, input: Option<Assets>) -> Self
The updated assets for the code review.
Sourcepub fn get_assets(&self) -> &Option<Assets>
pub fn get_assets(&self) -> &Option<Assets>
The updated assets for the code review.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The updated IAM service role for the code review.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The updated IAM service role for the code review.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The updated IAM service role for the code review.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The updated CloudWatch Logs configuration for the code review.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The updated CloudWatch Logs configuration for the code review.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The updated CloudWatch Logs configuration for the code review.
Sourcepub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
The updated code remediation strategy for the code review.
Sourcepub fn set_code_remediation_strategy(
self,
input: Option<CodeRemediationStrategy>,
) -> Self
pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self
The updated code remediation strategy for the code review.
Sourcepub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
The updated code remediation strategy for the code review.
Sourcepub fn build(self) -> Result<UpdateCodeReviewInput, BuildError>
pub fn build(self) -> Result<UpdateCodeReviewInput, BuildError>
Consumes the builder and constructs a UpdateCodeReviewInput.
Sourceimpl UpdateCodeReviewInputBuilder
impl UpdateCodeReviewInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateCodeReviewOutput, SdkError<UpdateCodeReviewError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateCodeReviewOutput, SdkError<UpdateCodeReviewError, HttpResponse>>
Sends a request with this input using the given client.