pub struct UpdateFindingFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateFinding.
Updates an existing security finding with new details or status
Implementations
Sourceimpl UpdateFindingFluentBuilder
impl UpdateFindingFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateFindingInputBuilder
pub fn as_input(&self) -> &UpdateFindingInputBuilder
Access the UpdateFinding as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateFindingOutput, SdkError<UpdateFindingError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateFindingOutput, SdkError<UpdateFindingError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateFindingOutput, UpdateFindingError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateFindingOutput, UpdateFindingError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn finding_id(self, input: impl Into<String>) -> Self
pub fn finding_id(self, input: impl Into<String>) -> Self
Identifier of the finding to update
Sourcepub fn set_finding_id(self, input: Option<String>) -> Self
pub fn set_finding_id(self, input: Option<String>) -> Self
Identifier of the finding to update
Sourcepub fn get_finding_id(&self) -> &Option<String>
pub fn get_finding_id(&self) -> &Option<String>
Identifier of the finding to update
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
ID of the agent space where the finding exists
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
ID of the agent space where the finding exists
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
ID of the agent space where the finding exists
Sourcepub fn risk_level(self, input: RiskLevel) -> Self
pub fn risk_level(self, input: RiskLevel) -> Self
Updated severity level of the identified risk
Sourcepub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
pub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
Updated severity level of the identified risk
Sourcepub fn get_risk_level(&self) -> &Option<RiskLevel>
pub fn get_risk_level(&self) -> &Option<RiskLevel>
Updated severity level of the identified risk
Sourcepub fn status(self, input: FindingStatus) -> Self
pub fn status(self, input: FindingStatus) -> Self
Updated status of the finding
Sourcepub fn set_status(self, input: Option<FindingStatus>) -> Self
pub fn set_status(self, input: Option<FindingStatus>) -> Self
Updated status of the finding
Sourcepub fn get_status(&self) -> &Option<FindingStatus>
pub fn get_status(&self) -> &Option<FindingStatus>
Updated status of the finding