#[non_exhaustive]pub struct UpdateFindingInputBuilder { /* private fields */ }Expand description
A builder for UpdateFindingInput.
Implementations
Sourceimpl UpdateFindingInputBuilder
impl UpdateFindingInputBuilder
Sourcepub fn finding_id(self, input: impl Into<String>) -> Self
pub fn finding_id(self, input: impl Into<String>) -> Self
Identifier of the finding to update This field is required.
Sourcepub fn set_finding_id(self, input: Option<String>) -> Self
pub fn set_finding_id(self, input: Option<String>) -> Self
Identifier of the finding to update
Sourcepub fn get_finding_id(&self) -> &Option<String>
pub fn get_finding_id(&self) -> &Option<String>
Identifier of the finding to update
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
ID of the agent space where the finding exists This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
ID of the agent space where the finding exists
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
ID of the agent space where the finding exists
Sourcepub fn risk_level(self, input: RiskLevel) -> Self
pub fn risk_level(self, input: RiskLevel) -> Self
Updated severity level of the identified risk
Sourcepub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
pub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
Updated severity level of the identified risk
Sourcepub fn get_risk_level(&self) -> &Option<RiskLevel>
pub fn get_risk_level(&self) -> &Option<RiskLevel>
Updated severity level of the identified risk
Sourcepub fn status(self, input: FindingStatus) -> Self
pub fn status(self, input: FindingStatus) -> Self
Updated status of the finding
Sourcepub fn set_status(self, input: Option<FindingStatus>) -> Self
pub fn set_status(self, input: Option<FindingStatus>) -> Self
Updated status of the finding
Sourcepub fn get_status(&self) -> &Option<FindingStatus>
pub fn get_status(&self) -> &Option<FindingStatus>
Updated status of the finding
Sourcepub fn build(self) -> Result<UpdateFindingInput, BuildError>
pub fn build(self) -> Result<UpdateFindingInput, BuildError>
Consumes the builder and constructs a UpdateFindingInput.
Sourceimpl UpdateFindingInputBuilder
impl UpdateFindingInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateFindingOutput, SdkError<UpdateFindingError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateFindingOutput, SdkError<UpdateFindingError, HttpResponse>>
Sends a request with this input using the given client.