#[non_exhaustive]pub struct UpdateFindingInput {
pub finding_id: Option<String>,
pub agent_space_id: Option<String>,
pub risk_level: Option<RiskLevel>,
pub status: Option<FindingStatus>,
}Expand description
Input for updating an existing security finding
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding_id: Option<String>Identifier of the finding to update
agent_space_id: Option<String>ID of the agent space where the finding exists
risk_level: Option<RiskLevel>Updated severity level of the identified risk
status: Option<FindingStatus>Updated status of the finding
Implementations
Sourceimpl UpdateFindingInput
impl UpdateFindingInput
Sourcepub fn finding_id(&self) -> Option<&str>
pub fn finding_id(&self) -> Option<&str>
Identifier of the finding to update
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
ID of the agent space where the finding exists
Sourcepub fn risk_level(&self) -> Option<&RiskLevel>
pub fn risk_level(&self) -> Option<&RiskLevel>
Updated severity level of the identified risk
Sourcepub fn status(&self) -> Option<&FindingStatus>
pub fn status(&self) -> Option<&FindingStatus>
Updated status of the finding
Sourceimpl UpdateFindingInput
impl UpdateFindingInput
Sourcepub fn builder() -> UpdateFindingInputBuilder
pub fn builder() -> UpdateFindingInputBuilder
Creates a new builder-style object to manufacture UpdateFindingInput.