#[non_exhaustive]pub struct UpdatePentestInput {
pub pentest_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub disable_managed_skills: Option<Vec<SkillType>>,
}Expand description
Input for updating an existing pentest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: Option<String>The unique identifier of the pentest to update.
agent_space_id: Option<String>The unique identifier of the agent space that contains the pentest.
title: Option<String>The updated title of the pentest.
assets: Option<Assets>The updated assets for the pentest.
exclude_risk_types: Option<Vec<RiskType>>The updated list of risk types to exclude from the pentest.
service_role: Option<String>The updated IAM service role for the pentest.
log_config: Option<CloudWatchLog>The updated CloudWatch Logs configuration for the pentest.
vpc_config: Option<VpcConfig>The updated VPC configuration for the pentest.
network_traffic_config: Option<NetworkTrafficConfig>The updated network traffic configuration for the pentest.
code_remediation_strategy: Option<CodeRemediationStrategy>The updated code remediation strategy for the pentest.
disable_managed_skills: Option<Vec<SkillType>>The updated list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
Implementations
Sourceimpl UpdatePentestInput
impl UpdatePentestInput
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
The unique identifier of the pentest to update.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the pentest.
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
The updated list of risk types to exclude from the pentest.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The updated IAM service role for the pentest.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The updated CloudWatch Logs configuration for the pentest.
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
The updated VPC configuration for the pentest.
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
The updated network traffic configuration for the pentest.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The updated code remediation strategy for the pentest.
Sourcepub fn disable_managed_skills(&self) -> &[SkillType]
pub fn disable_managed_skills(&self) -> &[SkillType]
The updated list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .disable_managed_skills.is_none().
Sourceimpl UpdatePentestInput
impl UpdatePentestInput
Sourcepub fn builder() -> UpdatePentestInputBuilder
pub fn builder() -> UpdatePentestInputBuilder
Creates a new builder-style object to manufacture UpdatePentestInput.