#[non_exhaustive]pub struct UpdateThreatModelInput {
pub threat_model_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub assets: Option<Assets>,
pub scope_docs: Option<Vec<DocumentInfo>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
}Expand description
Input for updating an existing threat model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_id: Option<String>The unique identifier of the threat model to update.
agent_space_id: Option<String>The unique identifier of the agent space that contains the threat model.
title: Option<String>The updated title of the threat model.
description: Option<String>The updated description of the application or system being threat modeled.
assets: Option<Assets>The updated assets for the threat model.
scope_docs: Option<Vec<DocumentInfo>>The updated scoped documents for the agent to focus on during threat modeling.
service_role: Option<String>The updated IAM service role for the threat model.
log_config: Option<CloudWatchLog>The updated CloudWatch Logs configuration for the threat model.
Implementations
Sourceimpl UpdateThreatModelInput
impl UpdateThreatModelInput
Sourcepub fn threat_model_id(&self) -> Option<&str>
pub fn threat_model_id(&self) -> Option<&str>
The unique identifier of the threat model to update.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space that contains the threat model.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The updated description of the application or system being threat modeled.
Sourcepub fn scope_docs(&self) -> &[DocumentInfo]
pub fn scope_docs(&self) -> &[DocumentInfo]
The updated scoped documents for the agent to focus on during threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scope_docs.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The updated IAM service role for the threat model.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The updated CloudWatch Logs configuration for the threat model.
Sourceimpl UpdateThreatModelInput
impl UpdateThreatModelInput
Sourcepub fn builder() -> UpdateThreatModelInputBuilder
pub fn builder() -> UpdateThreatModelInputBuilder
Creates a new builder-style object to manufacture UpdateThreatModelInput.