#[non_exhaustive]pub struct VerifyTargetDomainInputBuilder { /* private fields */ }Expand description
A builder for VerifyTargetDomainInput.
Implementations
Sourceimpl VerifyTargetDomainInputBuilder
impl VerifyTargetDomainInputBuilder
Sourcepub fn target_domain_id(self, input: impl Into<String>) -> Self
pub fn target_domain_id(self, input: impl Into<String>) -> Self
The unique identifier of the target domain to verify.
This field is required.Sourcepub fn set_target_domain_id(self, input: Option<String>) -> Self
pub fn set_target_domain_id(self, input: Option<String>) -> Self
The unique identifier of the target domain to verify.
Sourcepub fn get_target_domain_id(&self) -> &Option<String>
pub fn get_target_domain_id(&self) -> &Option<String>
The unique identifier of the target domain to verify.
Sourcepub fn build(self) -> Result<VerifyTargetDomainInput, BuildError>
pub fn build(self) -> Result<VerifyTargetDomainInput, BuildError>
Consumes the builder and constructs a VerifyTargetDomainInput.
Sourceimpl VerifyTargetDomainInputBuilder
impl VerifyTargetDomainInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<VerifyTargetDomainOutput, SdkError<VerifyTargetDomainError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<VerifyTargetDomainOutput, SdkError<VerifyTargetDomainError, HttpResponse>>
Sends a request with this input using the given client.