#[non_exhaustive]pub struct VerifyTargetDomainOutputBuilder { /* private fields */ }Expand description
A builder for VerifyTargetDomainOutput.
Implementations
Sourceimpl VerifyTargetDomainOutputBuilder
impl VerifyTargetDomainOutputBuilder
Sourcepub fn target_domain_id(self, input: impl Into<String>) -> Self
pub fn target_domain_id(self, input: impl Into<String>) -> Self
The unique identifier of the target domain.
Sourcepub fn set_target_domain_id(self, input: Option<String>) -> Self
pub fn set_target_domain_id(self, input: Option<String>) -> Self
The unique identifier of the target domain.
Sourcepub fn get_target_domain_id(&self) -> &Option<String>
pub fn get_target_domain_id(&self) -> &Option<String>
The unique identifier of the target domain.
Sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The domain name of the target domain.
Sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The domain name of the target domain.
Sourcepub fn get_domain_name(&self) -> &Option<String>
pub fn get_domain_name(&self) -> &Option<String>
The domain name of the target domain.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the target domain was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the target domain was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the target domain was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the target domain was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the target domain was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the target domain was last updated, in UTC format.
Sourcepub fn verified_at(self, input: DateTime) -> Self
pub fn verified_at(self, input: DateTime) -> Self
The date and time the target domain was verified, in UTC format.
Sourcepub fn set_verified_at(self, input: Option<DateTime>) -> Self
pub fn set_verified_at(self, input: Option<DateTime>) -> Self
The date and time the target domain was verified, in UTC format.
Sourcepub fn get_verified_at(&self) -> &Option<DateTime>
pub fn get_verified_at(&self) -> &Option<DateTime>
The date and time the target domain was verified, in UTC format.
Sourcepub fn status(self, input: TargetDomainStatus) -> Self
pub fn status(self, input: TargetDomainStatus) -> Self
The verification status of the target domain.
Sourcepub fn set_status(self, input: Option<TargetDomainStatus>) -> Self
pub fn set_status(self, input: Option<TargetDomainStatus>) -> Self
The verification status of the target domain.
Sourcepub fn get_status(&self) -> &Option<TargetDomainStatus>
pub fn get_status(&self) -> &Option<TargetDomainStatus>
The verification status of the target domain.
Sourcepub fn verification_status_reason(self, input: impl Into<String>) -> Self
pub fn verification_status_reason(self, input: impl Into<String>) -> Self
The reason for the current target domain verification status.
Sourcepub fn set_verification_status_reason(self, input: Option<String>) -> Self
pub fn set_verification_status_reason(self, input: Option<String>) -> Self
The reason for the current target domain verification status.
Sourcepub fn get_verification_status_reason(&self) -> &Option<String>
pub fn get_verification_status_reason(&self) -> &Option<String>
The reason for the current target domain verification status.
Sourcepub fn build(self) -> VerifyTargetDomainOutput
pub fn build(self) -> VerifyTargetDomainOutput
Consumes the builder and constructs a VerifyTargetDomainOutput.