#[non_exhaustive]pub struct VerifyTargetDomainOutput {
pub target_domain_id: Option<String>,
pub domain_name: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub verified_at: Option<DateTime>,
pub status: Option<TargetDomainStatus>,
/* private fields */
}Expand description
Output for verifying ownership for a registered target domain in an agent space
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_domain_id: Option<String>Unique identifier of the target domain
domain_name: Option<String>Name of the registered target domain
created_at: Option<DateTime>Timestamp when the target domain was registered
updated_at: Option<DateTime>Timestamp when the target domain was last updated
verified_at: Option<DateTime>Timestamp when the target domain was last successfully verified
status: Option<TargetDomainStatus>Current verification status of the registered target domain
Implementations
Sourceimpl VerifyTargetDomainOutput
impl VerifyTargetDomainOutput
Sourcepub fn target_domain_id(&self) -> Option<&str>
pub fn target_domain_id(&self) -> Option<&str>
Unique identifier of the target domain
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
Name of the registered target domain
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the target domain was registered
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the target domain was last updated
Sourcepub fn verified_at(&self) -> Option<&DateTime>
pub fn verified_at(&self) -> Option<&DateTime>
Timestamp when the target domain was last successfully verified
Sourcepub fn status(&self) -> Option<&TargetDomainStatus>
pub fn status(&self) -> Option<&TargetDomainStatus>
Current verification status of the registered target domain
Sourceimpl VerifyTargetDomainOutput
impl VerifyTargetDomainOutput
Sourcepub fn builder() -> VerifyTargetDomainOutputBuilder
pub fn builder() -> VerifyTargetDomainOutputBuilder
Creates a new builder-style object to manufacture VerifyTargetDomainOutput.