pub struct Client { /* private fields */ }Expand description
Client for AWS Security Agent
Client for invoking operations on AWS Security Agent. Each operation on AWS Security Agent is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_securityagent::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_securityagent::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the AddArtifact operation has
a Client::add_artifact, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.add_artifact()
.agent_space_id("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn add_artifact(&self) -> AddArtifactFluentBuilder
pub fn add_artifact(&self) -> AddArtifactFluentBuilder
Constructs a fluent builder for the AddArtifact operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceartifact_content(Blob)/set_artifact_content(Option<Blob>):
required: true
Binary content of the artifactartifact_type(ArtifactType)/set_artifact_type(Option<ArtifactType>):
required: true
Type of the artifact filefile_name(impl Into<String>)/set_file_name(Option<String>):
required: true
Name of the artifact file
- On success, responds with
AddArtifactOutputwith field(s):artifact_id(String): Unique identifier of the created artifact
- On failure, responds with
SdkError<AddArtifactError>
Sourceimpl Client
impl Client
Sourcepub fn batch_delete_pentests(&self) -> BatchDeletePentestsFluentBuilder
pub fn batch_delete_pentests(&self) -> BatchDeletePentestsFluentBuilder
Constructs a fluent builder for the BatchDeletePentests operation.
- The fluent builder is configurable:
pentest_ids(impl Into<String>)/set_pentest_ids(Option<Vec::<String>>):
required: true
List of pentest IDs to deleteagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentests exist
- On success, responds with
BatchDeletePentestsOutputwith field(s):deleted(Option<Vec::<Pentest>>): List of successfully deleted pentestsfailed(Option<Vec::<DeletePentestFailure>>): List of pentests that could not be deleted and the reasons for failure
- On failure, responds with
SdkError<BatchDeletePentestsError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_agent_spaces(&self) -> BatchGetAgentSpacesFluentBuilder
pub fn batch_get_agent_spaces(&self) -> BatchGetAgentSpacesFluentBuilder
Constructs a fluent builder for the BatchGetAgentSpaces operation.
- The fluent builder is configurable:
agent_space_ids(impl Into<String>)/set_agent_space_ids(Option<Vec::<String>>):
required: true
List of agent space IDs to retrieve
- On success, responds with
BatchGetAgentSpacesOutputwith field(s):agent_spaces(Option<Vec::<AgentSpace>>): List of agent spaces that were successfully retrievednot_found(Option<Vec::<String>>): List of agent space IDs that could not be found
- On failure, responds with
SdkError<BatchGetAgentSpacesError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_artifact_metadata(
&self,
) -> BatchGetArtifactMetadataFluentBuilder
pub fn batch_get_artifact_metadata( &self, ) -> BatchGetArtifactMetadataFluentBuilder
Constructs a fluent builder for the BatchGetArtifactMetadata operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceartifact_ids(impl Into<String>)/set_artifact_ids(Option<Vec::<String>>):
required: true
List of artifact identifiers
- On success, responds with
BatchGetArtifactMetadataOutputwith field(s):artifact_metadata_list(Vec::<ArtifactMetadataItem>): List of artifact metadata
- On failure, responds with
SdkError<BatchGetArtifactMetadataError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_findings(&self) -> BatchGetFindingsFluentBuilder
pub fn batch_get_findings(&self) -> BatchGetFindingsFluentBuilder
Constructs a fluent builder for the BatchGetFindings operation.
- The fluent builder is configurable:
finding_ids(impl Into<String>)/set_finding_ids(Option<Vec::<String>>):
required: true
List of finding IDs to retrieveagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the findings exist
- On success, responds with
BatchGetFindingsOutputwith field(s):findings(Option<Vec::<Finding>>): List of successfully retrieved findingsnot_found(Option<Vec::<String>>): List of finding IDs that could not be found
- On failure, responds with
SdkError<BatchGetFindingsError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_pentest_job_tasks(
&self,
) -> BatchGetPentestJobTasksFluentBuilder
pub fn batch_get_pentest_job_tasks( &self, ) -> BatchGetPentestJobTasksFluentBuilder
Constructs a fluent builder for the BatchGetPentestJobTasks operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existstask_ids(impl Into<String>)/set_task_ids(Option<Vec::<String>>):
required: true
List of task IDs to retrieve
- On success, responds with
BatchGetPentestJobTasksOutputwith field(s):tasks(Option<Vec::<Task>>): List of successfully retrieved tasksnot_found(Option<Vec::<String>>): List of task IDs that could not be found
- On failure, responds with
SdkError<BatchGetPentestJobTasksError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_pentest_jobs(&self) -> BatchGetPentestJobsFluentBuilder
pub fn batch_get_pentest_jobs(&self) -> BatchGetPentestJobsFluentBuilder
Constructs a fluent builder for the BatchGetPentestJobs operation.
- The fluent builder is configurable:
pentest_job_ids(impl Into<String>)/set_pentest_job_ids(Option<Vec::<String>>):
required: true
List of pentest job IDs to retrieveagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest exists
- On success, responds with
BatchGetPentestJobsOutputwith field(s):pentest_jobs(Option<Vec::<PentestJob>>): List of successfully retrieved pentest jobsnot_found(Option<Vec::<String>>): List of pentest job IDs that could not be found
- On failure, responds with
SdkError<BatchGetPentestJobsError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_pentests(&self) -> BatchGetPentestsFluentBuilder
pub fn batch_get_pentests(&self) -> BatchGetPentestsFluentBuilder
Constructs a fluent builder for the BatchGetPentests operation.
- The fluent builder is configurable:
pentest_ids(impl Into<String>)/set_pentest_ids(Option<Vec::<String>>):
required: true
List of pentest IDs to retrieveagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest exists
- On success, responds with
BatchGetPentestsOutputwith field(s):pentests(Option<Vec::<Pentest>>): List of successfully retrieved pentestsnot_found(Option<Vec::<String>>): List of pentest IDs that could not be found
- On failure, responds with
SdkError<BatchGetPentestsError>
Sourceimpl Client
impl Client
Sourcepub fn batch_get_target_domains(&self) -> BatchGetTargetDomainsFluentBuilder
pub fn batch_get_target_domains(&self) -> BatchGetTargetDomainsFluentBuilder
Constructs a fluent builder for the BatchGetTargetDomains operation.
- The fluent builder is configurable:
target_domain_ids(impl Into<String>)/set_target_domain_ids(Option<Vec::<String>>):
required: true
List of target domain IDs to retrieve
- On success, responds with
BatchGetTargetDomainsOutputwith field(s):target_domains(Option<Vec::<TargetDomain>>): List of target domains that were successfully retrievednot_found(Option<Vec::<String>>): List of target domain IDs that could not be found
- On failure, responds with
SdkError<BatchGetTargetDomainsError>
Sourceimpl Client
impl Client
Sourcepub fn create_agent_space(&self) -> CreateAgentSpaceFluentBuilder
pub fn create_agent_space(&self) -> CreateAgentSpaceFluentBuilder
Constructs a fluent builder for the CreateAgentSpace operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: true
Name of the agent spacedescription(impl Into<String>)/set_description(Option<String>):
required: false
Description of the agent spaceaws_resources(AwsResources)/set_aws_resources(Option<AwsResources>):
required: false
AWS resource configurations associated with the agent spacetarget_domain_ids(impl Into<String>)/set_target_domain_ids(Option<Vec::<String>>):
required: false
Target domain IDs to associate with the agent spacecode_review_settings(CodeReviewSettings)/set_code_review_settings(Option<CodeReviewSettings>):
required: false
Configuration for code review analysis, including controls scanning and general purpose scanning settingskms_key_id(impl Into<String>)/set_kms_key_id(Option<String>):
required: false
Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to associate with the agent space
- On success, responds with
CreateAgentSpaceOutputwith field(s):agent_space_id(String): Unique identifier of the created agent spacename(String): Name of the created agent spacedescription(Option<String>): Description of the created agent spaceaws_resources(Option<AwsResources>): AWS resource configurations associated with the agent spacetarget_domain_ids(Option<Vec::<String>>): List of target domain IDs registered with the agent spacecode_review_settings(Option<CodeReviewSettings>): Configuration for code review analysis, including controls scanning and general purpose scanning settingskms_key_id(Option<String>): Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.created_at(Option<DateTime>): Timestamp when the agent space was createdupdated_at(Option<DateTime>): Timestamp when the agent space was last updated
- On failure, responds with
SdkError<CreateAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn create_application(&self) -> CreateApplicationFluentBuilder
pub fn create_application(&self) -> CreateApplicationFluentBuilder
Constructs a fluent builder for the CreateApplication operation.
- The fluent builder is configurable:
idc_instance_arn(impl Into<String>)/set_idc_instance_arn(Option<String>):
required: false
ARN of the IAM Identity Center instance used for user authentication. Optional for non-IdC applicationsrole_arn(impl Into<String>)/set_role_arn(Option<String>):
required: false
ARN of the IAM role that the application uses to access AWS resources on your behalfdefault_kms_key_id(impl Into<String>)/set_default_kms_key_id(Option<String>):
required: false
Default KMS key identifier used to encrypt application datatags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to associate with the application
- On success, responds with
CreateApplicationOutputwith field(s):application_id(String): Application ID
- On failure, responds with
SdkError<CreateApplicationError>
Sourceimpl Client
impl Client
Sourcepub fn create_integration(&self) -> CreateIntegrationFluentBuilder
pub fn create_integration(&self) -> CreateIntegrationFluentBuilder
Constructs a fluent builder for the CreateIntegration operation.
- The fluent builder is configurable:
provider(Provider)/set_provider(Option<Provider>):
required: true
Provider to integrate withinput(ProviderInput)/set_input(Option<ProviderInput>):
required: true
Provider-specific input parametersintegration_display_name(impl Into<String>)/set_integration_display_name(Option<String>):
required: true
Display name for the integrationkms_key_id(impl Into<String>)/set_kms_key_id(Option<String>):
required: false
KMS key ID for encrypting integration detailstags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to associate with the integration
- On success, responds with
CreateIntegrationOutputwith field(s):integration_id(String): Unique identifier of the created integration
- On failure, responds with
SdkError<CreateIntegrationError>
Sourceimpl Client
impl Client
Sourcepub fn create_membership(&self) -> CreateMembershipFluentBuilder
pub fn create_membership(&self) -> CreateMembershipFluentBuilder
Constructs a fluent builder for the CreateMembership operation.
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application identifieragent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Agent space identifiermembership_id(impl Into<String>)/set_membership_id(Option<String>):
required: true
Member identifier (userId or agentSpaceId)member_type(MembershipType)/set_member_type(Option<MembershipType>):
required: true
Type of member (USER or AGENT_SPACE)config(MembershipConfig)/set_config(Option<MembershipConfig>):
required: false
Membership details (user or agent specific)
- On success, responds with
CreateMembershipOutput - On failure, responds with
SdkError<CreateMembershipError>
Sourceimpl Client
impl Client
Sourcepub fn create_pentest(&self) -> CreatePentestFluentBuilder
pub fn create_pentest(&self) -> CreatePentestFluentBuilder
Constructs a fluent builder for the CreatePentest operation.
- The fluent builder is configurable:
title(impl Into<String>)/set_title(Option<String>):
required: true
Title of the pentestagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest should be createdassets(Assets)/set_assets(Option<Assets>):
required: false
Assets to be tested during the pentestexclude_risk_types(RiskType)/set_exclude_risk_types(Option<Vec::<RiskType>>):
required: false
A list of risk types excluded from the pentest executionservice_role(impl Into<String>)/set_service_role(Option<String>):
required: false
Service role ARN for accessing customer resourceslog_config(CloudWatchLog)/set_log_config(Option<CloudWatchLog>):
required: false
CloudWatch log group and stream prefix where pentest execution logs are storedvpc_config(VpcConfig)/set_vpc_config(Option<VpcConfig>):
required: false
VPC configuration that the Security Agent accessesnetwork_traffic_config(NetworkTrafficConfig)/set_network_traffic_config(Option<NetworkTrafficConfig>):
required: false
Configuration for network traffic filteringcode_remediation_strategy(CodeRemediationStrategy)/set_code_remediation_strategy(Option<CodeRemediationStrategy>):
required: false
Strategy for code remediation on findings
- On success, responds with
CreatePentestOutputwith field(s):pentest_id(Option<String>): Unique identifier of the created pentesttitle(Option<String>): Title of the created pentestcreated_at(Option<DateTime>): Timestamp when the pentest was createdupdated_at(Option<DateTime>): Timestamp when the pentest was last updatedassets(Option<Assets>): Assets to be tested in the created pentestexclude_risk_types(Option<Vec::<RiskType>>): A list of risk types excluded from the pentest executionservice_role(Option<String>): Service role ARN for accessing customer resourceslog_config(Option<CloudWatchLog>): CloudWatch log group and stream prefix where pentest execution logs are storedagent_space_id(Option<String>): ID of the agent space where the pentest was created
- On failure, responds with
SdkError<CreatePentestError>
Sourceimpl Client
impl Client
Sourcepub fn create_target_domain(&self) -> CreateTargetDomainFluentBuilder
pub fn create_target_domain(&self) -> CreateTargetDomainFluentBuilder
Constructs a fluent builder for the CreateTargetDomain operation.
- The fluent builder is configurable:
target_domain_name(impl Into<String>)/set_target_domain_name(Option<String>):
required: true
Domain name of the target domainverification_method(DomainVerificationMethod)/set_verification_method(Option<DomainVerificationMethod>):
required: true
Verification method for the target domaintags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: false
Tags to associate with the target domain
- On success, responds with
CreateTargetDomainOutputwith field(s):target_domain_id(String): Unique identifier of the created target domaindomain_name(String): Name of the created target domainverification_status(TargetDomainStatus): Current verification status of the registered target domainverification_details(Option<VerificationDetails>): Verification details to verify registered target domaincreated_at(Option<DateTime>): Timestamp when the target domain was registeredverified_at(Option<DateTime>): Timestamp when the target domain was last successfully verified
- On failure, responds with
SdkError<CreateTargetDomainError>
Sourceimpl Client
impl Client
Sourcepub fn delete_agent_space(&self) -> DeleteAgentSpaceFluentBuilder
pub fn delete_agent_space(&self) -> DeleteAgentSpaceFluentBuilder
Constructs a fluent builder for the DeleteAgentSpace operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent space to delete
- On success, responds with
DeleteAgentSpaceOutputwith field(s):agent_space_id(Option<String>): Unique identifier of the deleted agent space
- On failure, responds with
SdkError<DeleteAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn delete_application(&self) -> DeleteApplicationFluentBuilder
pub fn delete_application(&self) -> DeleteApplicationFluentBuilder
Constructs a fluent builder for the DeleteApplication operation.
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application ID
- On success, responds with
DeleteApplicationOutput - On failure, responds with
SdkError<DeleteApplicationError>
Sourceimpl Client
impl Client
Sourcepub fn delete_artifact(&self) -> DeleteArtifactFluentBuilder
pub fn delete_artifact(&self) -> DeleteArtifactFluentBuilder
Constructs a fluent builder for the DeleteArtifact operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceartifact_id(impl Into<String>)/set_artifact_id(Option<String>):
required: true
Unique identifier of the artifact
- On success, responds with
DeleteArtifactOutput - On failure, responds with
SdkError<DeleteArtifactError>
Sourceimpl Client
impl Client
Sourcepub fn delete_integration(&self) -> DeleteIntegrationFluentBuilder
pub fn delete_integration(&self) -> DeleteIntegrationFluentBuilder
Constructs a fluent builder for the DeleteIntegration operation.
- The fluent builder is configurable:
integration_id(impl Into<String>)/set_integration_id(Option<String>):
required: true
Unique identifier of the integration
- On success, responds with
DeleteIntegrationOutput - On failure, responds with
SdkError<DeleteIntegrationError>
Sourceimpl Client
impl Client
Sourcepub fn delete_membership(&self) -> DeleteMembershipFluentBuilder
pub fn delete_membership(&self) -> DeleteMembershipFluentBuilder
Constructs a fluent builder for the DeleteMembership operation.
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application identifieragent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Agent space identifiermembership_id(impl Into<String>)/set_membership_id(Option<String>):
required: true
Member identifier (userId or agentSpaceId)member_type(MembershipType)/set_member_type(Option<MembershipType>):
required: false
Type of member (USER or AGENT_SPACE)
- On success, responds with
DeleteMembershipOutput - On failure, responds with
SdkError<DeleteMembershipError>
Sourceimpl Client
impl Client
Sourcepub fn delete_target_domain(&self) -> DeleteTargetDomainFluentBuilder
pub fn delete_target_domain(&self) -> DeleteTargetDomainFluentBuilder
Constructs a fluent builder for the DeleteTargetDomain operation.
- The fluent builder is configurable:
target_domain_id(impl Into<String>)/set_target_domain_id(Option<String>):
required: true
Unique identifier of the target domain to delete
- On success, responds with
DeleteTargetDomainOutputwith field(s):target_domain_id(Option<String>): Unique identifier of the deleted target domain
- On failure, responds with
SdkError<DeleteTargetDomainError>
Sourceimpl Client
impl Client
Sourcepub fn get_application(&self) -> GetApplicationFluentBuilder
pub fn get_application(&self) -> GetApplicationFluentBuilder
Constructs a fluent builder for the GetApplication operation.
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application ID
- On success, responds with
GetApplicationOutputwith field(s):application_id(String): Application IDdomain(String): Domain where the application is availableapplication_name(Option<String>): Name of the application, automatically assigned by the serviceidc_configuration(Option<IdCConfiguration>): IAM Identity Center configuration for the applicationrole_arn(Option<String>): ARN of the IAM role that the application uses to access AWS resources on your behalfdefault_kms_key_id(Option<String>): Default KMS key identifier used to encrypt application data
- On failure, responds with
SdkError<GetApplicationError>
Sourceimpl Client
impl Client
Sourcepub fn get_artifact(&self) -> GetArtifactFluentBuilder
pub fn get_artifact(&self) -> GetArtifactFluentBuilder
Constructs a fluent builder for the GetArtifact operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceartifact_id(impl Into<String>)/set_artifact_id(Option<String>):
required: true
Unique identifier of the artifact
- On success, responds with
GetArtifactOutputwith field(s):agent_space_id(String): Unique identifier of the agent spaceartifact_id(String): Unique identifier of the artifactartifact(Option<Artifact>): Artifact detailsfile_name(String): Name of the artifact fileupdated_at(DateTime): Timestamp when the artifact was last updated
- On failure, responds with
SdkError<GetArtifactError>
Sourceimpl Client
impl Client
Sourcepub fn get_integration(&self) -> GetIntegrationFluentBuilder
pub fn get_integration(&self) -> GetIntegrationFluentBuilder
Constructs a fluent builder for the GetIntegration operation.
- The fluent builder is configurable:
integration_id(impl Into<String>)/set_integration_id(Option<String>):
required: true
Unique identifier of the integration
- On success, responds with
GetIntegrationOutputwith field(s):integration_id(String): Unique identifier of the integrationinstallation_id(String): Installation identifier from the providerprovider(Provider): Provider typeprovider_type(ProviderType): Type of provider integrationdisplay_name(Option<String>): Display name for the integrationkms_key_id(Option<String>): KMS key ID for encrypting integration details
- On failure, responds with
SdkError<GetIntegrationError>
Sourceimpl Client
impl Client
Sourcepub fn initiate_provider_registration(
&self,
) -> InitiateProviderRegistrationFluentBuilder
pub fn initiate_provider_registration( &self, ) -> InitiateProviderRegistrationFluentBuilder
Constructs a fluent builder for the InitiateProviderRegistration operation.
- The fluent builder is configurable:
provider(Provider)/set_provider(Option<Provider>):
required: true
Provider to register with
- On success, responds with
InitiateProviderRegistrationOutputwith field(s):redirect_to(String): OAuth redirect URLcsrf_state(String): CSRF state token for OAuth security
- On failure, responds with
SdkError<InitiateProviderRegistrationError>
Sourceimpl Client
impl Client
Sourcepub fn list_agent_spaces(&self) -> ListAgentSpacesFluentBuilder
pub fn list_agent_spaces(&self) -> ListAgentSpacesFluentBuilder
Constructs a fluent builder for the ListAgentSpaces operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of agent spaces to return
- On success, responds with
ListAgentSpacesOutputwith field(s):agent_space_summaries(Option<Vec::<AgentSpaceSummary>>): List of agent space summariesnext_token(Option<String>): Token for next page of results
- On failure, responds with
SdkError<ListAgentSpacesError>
Sourceimpl Client
impl Client
Sourcepub fn list_applications(&self) -> ListApplicationsFluentBuilder
pub fn list_applications(&self) -> ListApplicationsFluentBuilder
Constructs a fluent builder for the ListApplications operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return
- On success, responds with
ListApplicationsOutputwith field(s):application_summaries(Vec::<ApplicationSummary>): List of application summariesnext_token(Option<String>): Token for next page of results
- On failure, responds with
SdkError<ListApplicationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_artifacts(&self) -> ListArtifactsFluentBuilder
pub fn list_artifacts(&self) -> ListArtifactsFluentBuilder
Constructs a fluent builder for the ListArtifacts operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spacenext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return
- On success, responds with
ListArtifactsOutputwith field(s):artifact_summaries(Vec::<ArtifactSummary>): List of artifact summariesnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListArtifactsError>
Sourceimpl Client
impl Client
Sourcepub fn list_discovered_endpoints(&self) -> ListDiscoveredEndpointsFluentBuilder
pub fn list_discovered_endpoints(&self) -> ListDiscoveredEndpointsFluentBuilder
Constructs a fluent builder for the ListDiscoveredEndpoints operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of discovered endpoints to return in a single request (default: 50)pentest_job_id(impl Into<String>)/set_pentest_job_id(Option<String>):
required: true
Identifier of the pentest job for which to retrieve discovered endpointsagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest job existsprefix(impl Into<String>)/set_prefix(Option<String>):
required: false
Optional URI prefix filter to narrow down resultsnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination
- On success, responds with
ListDiscoveredEndpointsOutputwith field(s):discovered_endpoints(Option<Vec::<DiscoveredEndpoint>>): List of discovered endpoints for the pentest jobnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListDiscoveredEndpointsError>
Sourceimpl Client
impl Client
Sourcepub fn list_findings(&self) -> ListFindingsFluentBuilder
pub fn list_findings(&self) -> ListFindingsFluentBuilder
Constructs a fluent builder for the ListFindings operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of findings to return in a single request (default: 50)pentest_job_id(impl Into<String>)/set_pentest_job_id(Option<String>):
required: true
Identifier of the pentest job for which to retrieve associated findingsagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest job existsnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationrisk_type(impl Into<String>)/set_risk_type(Option<String>):
required: false
Filter findings by risk typerisk_level(RiskLevel)/set_risk_level(Option<RiskLevel>):
required: false
Filter findings by risk levelstatus(FindingStatus)/set_status(Option<FindingStatus>):
required: false
Filter findings by statusconfidence(ConfidenceLevel)/set_confidence(Option<ConfidenceLevel>):
required: false
Filter findings by confidence levelname(impl Into<String>)/set_name(Option<String>):
required: false
Filter findings by name (case-insensitive substring search)
- On success, responds with
ListFindingsOutputwith field(s):findings_summaries(Option<Vec::<FindingSummary>>): List of finding summaries matching the filter criterianext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListFindingsError>
Sourceimpl Client
impl Client
Sourcepub fn list_integrated_resources(&self) -> ListIntegratedResourcesFluentBuilder
pub fn list_integrated_resources(&self) -> ListIntegratedResourcesFluentBuilder
Constructs a fluent builder for the ListIntegratedResources operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceintegration_id(impl Into<String>)/set_integration_id(Option<String>):
required: false
Filter integrated resources by a specific integrationresource_type(ResourceType)/set_resource_type(Option<ResourceType>):
required: false
Filter integrated resources by resource typenext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return
- On success, responds with
ListIntegratedResourcesOutputwith field(s):integrated_resource_summaries(Vec::<IntegratedResourceSummary>): List of integrated resourcesnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListIntegratedResourcesError>
Sourceimpl Client
impl Client
Sourcepub fn list_integrations(&self) -> ListIntegrationsFluentBuilder
pub fn list_integrations(&self) -> ListIntegrationsFluentBuilder
Constructs a fluent builder for the ListIntegrations operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
filter(IntegrationFilter)/set_filter(Option<IntegrationFilter>):
required: false
Filter criteria for integrationsnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to return
- On success, responds with
ListIntegrationsOutputwith field(s):integration_summaries(Vec::<IntegrationSummary>): List of integration summariesnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListIntegrationsError>
Sourceimpl Client
impl Client
Sourcepub fn list_memberships(&self) -> ListMembershipsFluentBuilder
pub fn list_memberships(&self) -> ListMembershipsFluentBuilder
Constructs a fluent builder for the ListMemberships operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application identifieragent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Agent space identifiermember_type(MembershipTypeFilter)/set_member_type(Option<MembershipTypeFilter>):
required: false
Filter by member typemax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of results to returnnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination
- On success, responds with
ListMembershipsOutputwith field(s):membership_summaries(Vec::<MembershipSummary>): List of membership summariesnext_token(Option<String>): Token for next page of results
- On failure, responds with
SdkError<ListMembershipsError>
Sourceimpl Client
impl Client
Sourcepub fn list_pentest_job_tasks(&self) -> ListPentestJobTasksFluentBuilder
pub fn list_pentest_job_tasks(&self) -> ListPentestJobTasksFluentBuilder
Constructs a fluent builder for the ListPentestJobTasks operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existsmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of tasks to return in a single requestpentest_job_id(impl Into<String>)/set_pentest_job_id(Option<String>):
required: false
Identifier of the pentest job whose tasks to liststep_name(StepName)/set_step_name(Option<StepName>):
required: false
Filter tasks by step namecategory_name(impl Into<String>)/set_category_name(Option<String>):
required: false
Filter tasks by category name.next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination to retrieve the next set of results
- On success, responds with
ListPentestJobTasksOutputwith field(s):task_summaries(Option<Vec::<TaskSummary>>): List of task summaries associated with the specified pentest jobnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListPentestJobTasksError>
Sourceimpl Client
impl Client
Sourcepub fn list_pentest_jobs_for_pentest(
&self,
) -> ListPentestJobsForPentestFluentBuilder
pub fn list_pentest_jobs_for_pentest( &self, ) -> ListPentestJobsForPentestFluentBuilder
Constructs a fluent builder for the ListPentestJobsForPentest operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of pentest jobs to return in a single requestpentest_id(impl Into<String>)/set_pentest_id(Option<String>):
required: true
Identifier of the pentest for which to retrieve associated jobsagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existsnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for pagination
- On success, responds with
ListPentestJobsForPentestOutputwith field(s):pentest_job_summaries(Option<Vec::<PentestJobSummary>>): List of pentest job summaries associated with the pentestnext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListPentestJobsForPentestError>
Sourceimpl Client
impl Client
Sourcepub fn list_pentests(&self) -> ListPentestsFluentBuilder
pub fn list_pentests(&self) -> ListPentestsFluentBuilder
Constructs a fluent builder for the ListPentests operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of pentests to return in a single requestnext_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest exists
- On success, responds with
ListPentestsOutputwith field(s):pentest_summaries(Option<Vec::<PentestSummary>>): List of pentest summaries matching the filter criterianext_token(Option<String>): Token for pagination to retrieve the next set of results
- On failure, responds with
SdkError<ListPentestsError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
ARN of the resource to list tags for
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap::<String, String>>): Tags associated with the resource
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn list_target_domains(&self) -> ListTargetDomainsFluentBuilder
pub fn list_target_domains(&self) -> ListTargetDomainsFluentBuilder
Constructs a fluent builder for the ListTargetDomains operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
Token for paginationmax_results(i32)/set_max_results(Option<i32>):
required: false
Maximum number of target domains to return
- On success, responds with
ListTargetDomainsOutputwith field(s):target_domain_summaries(Option<Vec::<TargetDomainSummary>>): List of target domain summariesnext_token(Option<String>): Token for next page of results
- On failure, responds with
SdkError<ListTargetDomainsError>
Sourceimpl Client
impl Client
Sourcepub fn start_code_remediation(&self) -> StartCodeRemediationFluentBuilder
pub fn start_code_remediation(&self) -> StartCodeRemediationFluentBuilder
Constructs a fluent builder for the StartCodeRemediation operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest job existspentest_job_id(impl Into<String>)/set_pentest_job_id(Option<String>):
required: true
Identifier of the pentest job to start code remediation forfinding_ids(impl Into<String>)/set_finding_ids(Option<Vec::<String>>):
required: true
Identifiers of the findings to start code remediation for
- On success, responds with
StartCodeRemediationOutput - On failure, responds with
SdkError<StartCodeRemediationError>
Sourceimpl Client
impl Client
Sourcepub fn start_pentest_job(&self) -> StartPentestJobFluentBuilder
pub fn start_pentest_job(&self) -> StartPentestJobFluentBuilder
Constructs a fluent builder for the StartPentestJob operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existspentest_id(impl Into<String>)/set_pentest_id(Option<String>):
required: true
Identifier of the pentest to execute
- On success, responds with
StartPentestJobOutputwith field(s):title(Option<String>): Title of the pentest jobstatus(Option<JobStatus>): Current status of the pentest jobcreated_at(Option<DateTime>): Timestamp when the pentest job was createdupdated_at(Option<DateTime>): Timestamp when the pentest job was last updatedpentest_id(Option<String>): Unique identifier of the pentestpentest_job_id(Option<String>): Unique identifier of the pentest jobagent_space_id(Option<String>): ID of the agent space where the pentest exists
- On failure, responds with
SdkError<StartPentestJobError>
Sourceimpl Client
impl Client
Sourcepub fn stop_pentest_job(&self) -> StopPentestJobFluentBuilder
pub fn stop_pentest_job(&self) -> StopPentestJobFluentBuilder
Constructs a fluent builder for the StopPentestJob operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existspentest_job_id(impl Into<String>)/set_pentest_job_id(Option<String>):
required: true
Identifier of the pentest job to stop
- On success, responds with
StopPentestJobOutput - On failure, responds with
SdkError<StopPentestJobError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
ARN of the resource to tagtags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: true
Tags to add to the resource
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: true
ARN of the resource to untagtag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: true
List of tag keys to remove from the resource
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn update_agent_space(&self) -> UpdateAgentSpaceFluentBuilder
pub fn update_agent_space(&self) -> UpdateAgentSpaceFluentBuilder
Constructs a fluent builder for the UpdateAgentSpace operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space to updatename(impl Into<String>)/set_name(Option<String>):
required: false
Name of the agent spacedescription(impl Into<String>)/set_description(Option<String>):
required: false
Description of the agent spaceaws_resources(AwsResources)/set_aws_resources(Option<AwsResources>):
required: false
AWS resource configurations associated with the agent spacetarget_domain_ids(impl Into<String>)/set_target_domain_ids(Option<Vec::<String>>):
required: false
Target domain IDs to associate with the agent spacecode_review_settings(CodeReviewSettings)/set_code_review_settings(Option<CodeReviewSettings>):
required: false
Configuration for code review analysis, including controls scanning and general purpose scanning settings
- On success, responds with
UpdateAgentSpaceOutputwith field(s):agent_space_id(String): Unique identifier of the agent spacename(String): Name of the agent spacedescription(Option<String>): Description of the agent spaceaws_resources(Option<AwsResources>): AWS resource configurations associated with the agent spacetarget_domain_ids(Option<Vec::<String>>): List of target domain IDs registered with the agent spacecode_review_settings(Option<CodeReviewSettings>): Configuration for code review analysis, including controls scanning and general purpose scanning settingscreated_at(Option<DateTime>): Timestamp when the agent space was createdupdated_at(Option<DateTime>): Timestamp when the agent space was last updated
- On failure, responds with
SdkError<UpdateAgentSpaceError>
Sourceimpl Client
impl Client
Sourcepub fn update_application(&self) -> UpdateApplicationFluentBuilder
pub fn update_application(&self) -> UpdateApplicationFluentBuilder
Constructs a fluent builder for the UpdateApplication operation.
- The fluent builder is configurable:
application_id(impl Into<String>)/set_application_id(Option<String>):
required: true
Application IDrole_arn(impl Into<String>)/set_role_arn(Option<String>):
required: false
ARN of the IAM role that the application uses to access AWS resources on your behalfdefault_kms_key_id(impl Into<String>)/set_default_kms_key_id(Option<String>):
required: false
Default KMS key identifier. Use an empty string to remove the default KMS key.
- On success, responds with
UpdateApplicationOutputwith field(s):application_id(String): Application ID
- On failure, responds with
SdkError<UpdateApplicationError>
Sourceimpl Client
impl Client
Sourcepub fn update_finding(&self) -> UpdateFindingFluentBuilder
pub fn update_finding(&self) -> UpdateFindingFluentBuilder
Constructs a fluent builder for the UpdateFinding operation.
- The fluent builder is configurable:
finding_id(impl Into<String>)/set_finding_id(Option<String>):
required: true
Identifier of the finding to updateagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the finding existsrisk_level(RiskLevel)/set_risk_level(Option<RiskLevel>):
required: false
Updated severity level of the identified riskstatus(FindingStatus)/set_status(Option<FindingStatus>):
required: false
Updated status of the finding
- On success, responds with
UpdateFindingOutput - On failure, responds with
SdkError<UpdateFindingError>
Sourceimpl Client
impl Client
Sourcepub fn update_integrated_resources(
&self,
) -> UpdateIntegratedResourcesFluentBuilder
pub fn update_integrated_resources( &self, ) -> UpdateIntegratedResourcesFluentBuilder
Constructs a fluent builder for the UpdateIntegratedResources operation.
- The fluent builder is configurable:
agent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
Unique identifier of the agent spaceintegration_id(impl Into<String>)/set_integration_id(Option<String>):
required: true
Unique identifier of the integrationitems(IntegratedResourceInputItem)/set_items(Option<Vec::<IntegratedResourceInputItem>>):
required: true
List of integrated resources to update
- On success, responds with
UpdateIntegratedResourcesOutput - On failure, responds with
SdkError<UpdateIntegratedResourcesError>
Sourceimpl Client
impl Client
Sourcepub fn update_pentest(&self) -> UpdatePentestFluentBuilder
pub fn update_pentest(&self) -> UpdatePentestFluentBuilder
Constructs a fluent builder for the UpdatePentest operation.
- The fluent builder is configurable:
pentest_id(impl Into<String>)/set_pentest_id(Option<String>):
required: true
Identifier of the pentest to updateagent_space_id(impl Into<String>)/set_agent_space_id(Option<String>):
required: true
ID of the agent space where the pentest existstitle(impl Into<String>)/set_title(Option<String>):
required: false
New title for the pentestassets(Assets)/set_assets(Option<Assets>):
required: false
Updated assets to be testedexclude_risk_types(RiskType)/set_exclude_risk_types(Option<Vec::<RiskType>>):
required: false
A list of risk types excluded from the pentest executionservice_role(impl Into<String>)/set_service_role(Option<String>):
required: false
Updated service role ARN for accessing customer resourceslog_config(CloudWatchLog)/set_log_config(Option<CloudWatchLog>):
required: false
CloudWatch log group and stream prefix where pentest execution logs are storedvpc_config(VpcConfig)/set_vpc_config(Option<VpcConfig>):
required: false
VPC configuration that the Security Agent accessesnetwork_traffic_config(NetworkTrafficConfig)/set_network_traffic_config(Option<NetworkTrafficConfig>):
required: false
Configuration for network traffic filteringcode_remediation_strategy(CodeRemediationStrategy)/set_code_remediation_strategy(Option<CodeRemediationStrategy>):
required: false
Strategy for code remediation on findings
- On success, responds with
UpdatePentestOutputwith field(s):pentest_id(Option<String>): Unique identifier of the updated pentesttitle(Option<String>): Title of the updated pentestcreated_at(Option<DateTime>): Timestamp when the pentest was createdupdated_at(Option<DateTime>): Timestamp when the pentest was last updatedassets(Option<Assets>): Assets to be tested in the updated pentestexclude_risk_types(Option<Vec::<RiskType>>): A list of risk types excluded from the pentest executionservice_role(Option<String>): Service role ARN for accessing customer resourceslog_config(Option<CloudWatchLog>): CloudWatch log group and stream prefix where pentest execution logs are storedagent_space_id(Option<String>): ID of the agent space where the pentest exists
- On failure, responds with
SdkError<UpdatePentestError>
Sourceimpl Client
impl Client
Sourcepub fn update_target_domain(&self) -> UpdateTargetDomainFluentBuilder
pub fn update_target_domain(&self) -> UpdateTargetDomainFluentBuilder
Constructs a fluent builder for the UpdateTargetDomain operation.
- The fluent builder is configurable:
target_domain_id(impl Into<String>)/set_target_domain_id(Option<String>):
required: true
Unique identifier of the target domain to updateverification_method(DomainVerificationMethod)/set_verification_method(Option<DomainVerificationMethod>):
required: true
Verification method for the target domain
- On success, responds with
UpdateTargetDomainOutputwith field(s):target_domain_id(String): Unique identifier of the target domaindomain_name(String): Name of the target domainverification_status(TargetDomainStatus): Current verification status of the registered target domainverification_details(Option<VerificationDetails>): Verification details to verify registered target domaincreated_at(Option<DateTime>): Timestamp when the target domain was registeredverified_at(Option<DateTime>): Timestamp when the target domain was last successfully verified
- On failure, responds with
SdkError<UpdateTargetDomainError>
Sourceimpl Client
impl Client
Sourcepub fn verify_target_domain(&self) -> VerifyTargetDomainFluentBuilder
pub fn verify_target_domain(&self) -> VerifyTargetDomainFluentBuilder
Constructs a fluent builder for the VerifyTargetDomain operation.
- The fluent builder is configurable:
target_domain_id(impl Into<String>)/set_target_domain_id(Option<String>):
required: true
Unique identifier of the target domain
- On success, responds with
VerifyTargetDomainOutputwith field(s):target_domain_id(Option<String>): Unique identifier of the target domaindomain_name(Option<String>): Name of the registered target domaincreated_at(Option<DateTime>): Timestamp when the target domain was registeredupdated_at(Option<DateTime>): Timestamp when the target domain was last updatedverified_at(Option<DateTime>): Timestamp when the target domain was last successfully verifiedstatus(Option<TargetDomainStatus>): Current verification status of the registered target domain
- On failure, responds with
SdkError<VerifyTargetDomainError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.