#[non_exhaustive]pub struct ArtifactMetadataItemBuilder { /* private fields */ }Expand description
A builder for ArtifactMetadataItem.
Implementations
Sourceimpl ArtifactMetadataItemBuilder
impl ArtifactMetadataItemBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the artifact.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the artifact.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the artifact.
Sourcepub fn artifact_id(self, input: impl Into<String>) -> Self
pub fn artifact_id(self, input: impl Into<String>) -> Self
The unique identifier of the artifact.
This field is required.Sourcepub fn set_artifact_id(self, input: Option<String>) -> Self
pub fn set_artifact_id(self, input: Option<String>) -> Self
The unique identifier of the artifact.
Sourcepub fn get_artifact_id(&self) -> &Option<String>
pub fn get_artifact_id(&self) -> &Option<String>
The unique identifier of the artifact.
Sourcepub fn file_name(self, input: impl Into<String>) -> Self
pub fn file_name(self, input: impl Into<String>) -> Self
The file name of the artifact.
This field is required.Sourcepub fn set_file_name(self, input: Option<String>) -> Self
pub fn set_file_name(self, input: Option<String>) -> Self
The file name of the artifact.
Sourcepub fn get_file_name(&self) -> &Option<String>
pub fn get_file_name(&self) -> &Option<String>
The file name of the artifact.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the artifact was last updated, in UTC format.
This field is required.Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the artifact was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the artifact was last updated, in UTC format.
Sourcepub fn build(self) -> Result<ArtifactMetadataItem, BuildError>
pub fn build(self) -> Result<ArtifactMetadataItem, BuildError>
Consumes the builder and constructs a ArtifactMetadataItem.
This method will fail if any of the following fields are not set: