#[non_exhaustive]pub struct AssetsBuilder { /* private fields */ }Expand description
A builder for Assets.
Implementations
Sourceimpl AssetsBuilder
impl AssetsBuilder
Sourcepub fn endpoints(self, input: Endpoint) -> Self
pub fn endpoints(self, input: Endpoint) -> Self
Appends an item to endpoints.
To override the contents of this collection use set_endpoints.
The list of endpoints to test during the pentest.
Sourcepub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
The list of endpoints to test during the pentest.
Sourcepub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
pub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
The list of endpoints to test during the pentest.
Sourcepub fn actors(self, input: Actor) -> Self
pub fn actors(self, input: Actor) -> Self
Appends an item to actors.
To override the contents of this collection use set_actors.
The list of actors used during penetration testing.
Sourcepub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
pub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
The list of actors used during penetration testing.
Sourcepub fn get_actors(&self) -> &Option<Vec<Actor>>
pub fn get_actors(&self) -> &Option<Vec<Actor>>
The list of actors used during penetration testing.
Sourcepub fn documents(self, input: DocumentInfo) -> Self
pub fn documents(self, input: DocumentInfo) -> Self
Appends an item to documents.
To override the contents of this collection use set_documents.
The list of documents that provide context for the pentest.
Sourcepub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
The list of documents that provide context for the pentest.
Sourcepub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
The list of documents that provide context for the pentest.
Sourcepub fn source_code(self, input: SourceCodeRepository) -> Self
pub fn source_code(self, input: SourceCodeRepository) -> Self
Appends an item to source_code.
To override the contents of this collection use set_source_code.
The list of source code repositories to analyze during the pentest.
Sourcepub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
The list of source code repositories to analyze during the pentest.
Sourcepub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
The list of source code repositories to analyze during the pentest.
Sourcepub fn integrated_repositories(self, input: IntegratedRepository) -> Self
pub fn integrated_repositories(self, input: IntegratedRepository) -> Self
Appends an item to integrated_repositories.
To override the contents of this collection use set_integrated_repositories.
The list of integrated repositories associated with the pentest.
Sourcepub fn set_integrated_repositories(
self,
input: Option<Vec<IntegratedRepository>>,
) -> Self
pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self
The list of integrated repositories associated with the pentest.
Sourcepub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
The list of integrated repositories associated with the pentest.