#[non_exhaustive]pub struct BitbucketIntegrationInputBuilder { /* private fields */ }Expand description
A builder for BitbucketIntegrationInput.
Implementations
Sourceimpl BitbucketIntegrationInputBuilder
impl BitbucketIntegrationInputBuilder
Sourcepub fn installation_id(self, input: impl Into<String>) -> Self
pub fn installation_id(self, input: impl Into<String>) -> Self
The Atlassian installation identifier, available from the Atlassian administration console.
This field is required.Sourcepub fn set_installation_id(self, input: Option<String>) -> Self
pub fn set_installation_id(self, input: Option<String>) -> Self
The Atlassian installation identifier, available from the Atlassian administration console.
Sourcepub fn get_installation_id(&self) -> &Option<String>
pub fn get_installation_id(&self) -> &Option<String>
The Atlassian installation identifier, available from the Atlassian administration console.
Sourcepub fn workspace(self, input: impl Into<String>) -> Self
pub fn workspace(self, input: impl Into<String>) -> Self
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
This field is required.Sourcepub fn set_workspace(self, input: Option<String>) -> Self
pub fn set_workspace(self, input: Option<String>) -> Self
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
Sourcepub fn get_workspace(&self) -> &Option<String>
pub fn get_workspace(&self) -> &Option<String>
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
Sourcepub fn code(self, input: impl Into<String>) -> Self
pub fn code(self, input: impl Into<String>) -> Self
The OAuth 2.0 authorization code returned from the consent redirect.
This field is required.Sourcepub fn set_code(self, input: Option<String>) -> Self
pub fn set_code(self, input: Option<String>) -> Self
The OAuth 2.0 authorization code returned from the consent redirect.
Sourcepub fn get_code(&self) -> &Option<String>
pub fn get_code(&self) -> &Option<String>
The OAuth 2.0 authorization code returned from the consent redirect.
Sourcepub fn state(self, input: impl Into<String>) -> Self
pub fn state(self, input: impl Into<String>) -> Self
The CSRF state token echoed back from the OAuth redirect.
This field is required.Sourcepub fn set_state(self, input: Option<String>) -> Self
pub fn set_state(self, input: Option<String>) -> Self
The CSRF state token echoed back from the OAuth redirect.
Sourcepub fn get_state(&self) -> &Option<String>
pub fn get_state(&self) -> &Option<String>
The CSRF state token echoed back from the OAuth redirect.
Sourcepub fn build(self) -> Result<BitbucketIntegrationInput, BuildError>
pub fn build(self) -> Result<BitbucketIntegrationInput, BuildError>
Consumes the builder and constructs a BitbucketIntegrationInput.
This method will fail if any of the following fields are not set: