#[non_exhaustive]pub struct BitbucketResourceCapabilitiesBuilder { /* private fields */ }Expand description
A builder for BitbucketResourceCapabilities.
Implementations
Sourceimpl BitbucketResourceCapabilitiesBuilder
impl BitbucketResourceCapabilitiesBuilder
Sourcepub fn leave_comments(self, input: bool) -> Self
pub fn leave_comments(self, input: bool) -> Self
Whether to post code review comments on pull requests.
Sourcepub fn set_leave_comments(self, input: Option<bool>) -> Self
pub fn set_leave_comments(self, input: Option<bool>) -> Self
Whether to post code review comments on pull requests.
Sourcepub fn get_leave_comments(&self) -> &Option<bool>
pub fn get_leave_comments(&self) -> &Option<bool>
Whether to post code review comments on pull requests.
Sourcepub fn remediate_code(self, input: bool) -> Self
pub fn remediate_code(self, input: bool) -> Self
Whether to create pull requests with automated fixes.
Sourcepub fn set_remediate_code(self, input: Option<bool>) -> Self
pub fn set_remediate_code(self, input: Option<bool>) -> Self
Whether to create pull requests with automated fixes.
Sourcepub fn get_remediate_code(&self) -> &Option<bool>
pub fn get_remediate_code(&self) -> &Option<bool>
Whether to create pull requests with automated fixes.
Sourcepub fn build(self) -> BitbucketResourceCapabilities
pub fn build(self) -> BitbucketResourceCapabilities
Consumes the builder and constructs a BitbucketResourceCapabilities.