#[non_exhaustive]pub struct CodeLocationBuilder { /* private fields */ }Expand description
A builder for CodeLocation.
Implementations
Sourceimpl CodeLocationBuilder
impl CodeLocationBuilder
Sourcepub fn file_path(self, input: impl Into<String>) -> Self
pub fn file_path(self, input: impl Into<String>) -> Self
The absolute path to the file containing the code location.
This field is required.Sourcepub fn set_file_path(self, input: Option<String>) -> Self
pub fn set_file_path(self, input: Option<String>) -> Self
The absolute path to the file containing the code location.
Sourcepub fn get_file_path(&self) -> &Option<String>
pub fn get_file_path(&self) -> &Option<String>
The absolute path to the file containing the code location.
Sourcepub fn line_start(self, input: i32) -> Self
pub fn line_start(self, input: i32) -> Self
The starting line number of the code location.
Sourcepub fn set_line_start(self, input: Option<i32>) -> Self
pub fn set_line_start(self, input: Option<i32>) -> Self
The starting line number of the code location.
Sourcepub fn get_line_start(&self) -> &Option<i32>
pub fn get_line_start(&self) -> &Option<i32>
The starting line number of the code location.
Sourcepub fn set_line_end(self, input: Option<i32>) -> Self
pub fn set_line_end(self, input: Option<i32>) -> Self
The ending line number of the code location.
Sourcepub fn get_line_end(&self) -> &Option<i32>
pub fn get_line_end(&self) -> &Option<i32>
The ending line number of the code location.
Sourcepub fn label(self, input: impl Into<String>) -> Self
pub fn label(self, input: impl Into<String>) -> Self
The role of this location in the vulnerability, such as source or sink.
Sourcepub fn set_label(self, input: Option<String>) -> Self
pub fn set_label(self, input: Option<String>) -> Self
The role of this location in the vulnerability, such as source or sink.
Sourcepub fn get_label(&self) -> &Option<String>
pub fn get_label(&self) -> &Option<String>
The role of this location in the vulnerability, such as source or sink.
Sourcepub fn build(self) -> Result<CodeLocation, BuildError>
pub fn build(self) -> Result<CodeLocation, BuildError>
Consumes the builder and constructs a CodeLocation.
This method will fail if any of the following fields are not set: