#[non_exhaustive]pub struct CodeRemediationTaskBuilder { /* private fields */ }Expand description
A builder for CodeRemediationTask.
Implementations
Sourceimpl CodeRemediationTaskBuilder
impl CodeRemediationTaskBuilder
Sourcepub fn status(self, input: CodeRemediationTaskStatus) -> Self
pub fn status(self, input: CodeRemediationTaskStatus) -> Self
Current status of the code remediation task This field is required.
Sourcepub fn set_status(self, input: Option<CodeRemediationTaskStatus>) -> Self
pub fn set_status(self, input: Option<CodeRemediationTaskStatus>) -> Self
Current status of the code remediation task
Sourcepub fn get_status(&self) -> &Option<CodeRemediationTaskStatus>
pub fn get_status(&self) -> &Option<CodeRemediationTaskStatus>
Current status of the code remediation task
Sourcepub fn status_reason(self, input: impl Into<String>) -> Self
pub fn status_reason(self, input: impl Into<String>) -> Self
Reason for the current code remediation task status
Sourcepub fn set_status_reason(self, input: Option<String>) -> Self
pub fn set_status_reason(self, input: Option<String>) -> Self
Reason for the current code remediation task status
Sourcepub fn get_status_reason(&self) -> &Option<String>
pub fn get_status_reason(&self) -> &Option<String>
Reason for the current code remediation task status
Sourcepub fn task_details(self, input: CodeRemediationTaskDetails) -> Self
pub fn task_details(self, input: CodeRemediationTaskDetails) -> Self
Appends an item to task_details.
To override the contents of this collection use set_task_details.
Details of the code remediation for each repository
Sourcepub fn set_task_details(
self,
input: Option<Vec<CodeRemediationTaskDetails>>,
) -> Self
pub fn set_task_details( self, input: Option<Vec<CodeRemediationTaskDetails>>, ) -> Self
Details of the code remediation for each repository
Sourcepub fn get_task_details(&self) -> &Option<Vec<CodeRemediationTaskDetails>>
pub fn get_task_details(&self) -> &Option<Vec<CodeRemediationTaskDetails>>
Details of the code remediation for each repository
Sourcepub fn build(self) -> Result<CodeRemediationTask, BuildError>
pub fn build(self) -> Result<CodeRemediationTask, BuildError>
Consumes the builder and constructs a CodeRemediationTask.
This method will fail if any of the following fields are not set: