#[non_exhaustive]pub struct CodeReviewJobBuilder { /* private fields */ }Expand description
A builder for CodeReviewJob.
Implementations
Sourceimpl CodeReviewJobBuilder
impl CodeReviewJobBuilder
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the job.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the job.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the job.
Sourcepub fn overview(self, input: impl Into<String>) -> Self
pub fn overview(self, input: impl Into<String>) -> Self
An overview of the code review job results.
Sourcepub fn set_overview(self, input: Option<String>) -> Self
pub fn set_overview(self, input: Option<String>) -> Self
An overview of the code review job results.
Sourcepub fn get_overview(&self) -> &Option<String>
pub fn get_overview(&self) -> &Option<String>
An overview of the code review job results.
Sourcepub fn set_status(self, input: Option<JobStatus>) -> Self
pub fn set_status(self, input: Option<JobStatus>) -> Self
The current status of the code review job.
Sourcepub fn get_status(&self) -> &Option<JobStatus>
pub fn get_status(&self) -> &Option<JobStatus>
The current status of the code review job.
Sourcepub fn documents(self, input: DocumentInfo) -> Self
pub fn documents(self, input: DocumentInfo) -> Self
Appends an item to documents.
To override the contents of this collection use set_documents.
The list of documents providing context for the code review job.
Sourcepub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
The list of documents providing context for the code review job.
Sourcepub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
The list of documents providing context for the code review job.
Sourcepub fn source_code(self, input: SourceCodeRepository) -> Self
pub fn source_code(self, input: SourceCodeRepository) -> Self
Appends an item to source_code.
To override the contents of this collection use set_source_code.
The list of source code repositories analyzed during the code review job.
Sourcepub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
The list of source code repositories analyzed during the code review job.
Sourcepub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
The list of source code repositories analyzed during the code review job.
Sourcepub fn steps(self, input: Step) -> Self
pub fn steps(self, input: Step) -> Self
Appends an item to steps.
To override the contents of this collection use set_steps.
The list of steps in the code review job execution.
Sourcepub fn set_steps(self, input: Option<Vec<Step>>) -> Self
pub fn set_steps(self, input: Option<Vec<Step>>) -> Self
The list of steps in the code review job execution.
Sourcepub fn get_steps(&self) -> &Option<Vec<Step>>
pub fn get_steps(&self) -> &Option<Vec<Step>>
The list of steps in the code review job execution.
Sourcepub fn execution_context(self, input: ExecutionContext) -> Self
pub fn execution_context(self, input: ExecutionContext) -> Self
Appends an item to execution_context.
To override the contents of this collection use set_execution_context.
The execution context messages for the code review job.
Sourcepub fn set_execution_context(self, input: Option<Vec<ExecutionContext>>) -> Self
pub fn set_execution_context(self, input: Option<Vec<ExecutionContext>>) -> Self
The execution context messages for the code review job.
Sourcepub fn get_execution_context(&self) -> &Option<Vec<ExecutionContext>>
pub fn get_execution_context(&self) -> &Option<Vec<ExecutionContext>>
The execution context messages for the code review job.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The IAM service role used for the code review job.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The IAM service role used for the code review job.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The IAM service role used for the code review job.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The CloudWatch Logs configuration for the code review job.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The CloudWatch Logs configuration for the code review job.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The CloudWatch Logs configuration for the code review job.
Sourcepub fn error_information(self, input: ErrorInformation) -> Self
pub fn error_information(self, input: ErrorInformation) -> Self
Error information if the code review job encountered an error.
Sourcepub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
pub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
Error information if the code review job encountered an error.
Sourcepub fn get_error_information(&self) -> &Option<ErrorInformation>
pub fn get_error_information(&self) -> &Option<ErrorInformation>
Error information if the code review job encountered an error.
Sourcepub fn integrated_repositories(self, input: IntegratedRepository) -> Self
pub fn integrated_repositories(self, input: IntegratedRepository) -> Self
Appends an item to integrated_repositories.
To override the contents of this collection use set_integrated_repositories.
The list of integrated repositories associated with the code review job.
Sourcepub fn set_integrated_repositories(
self,
input: Option<Vec<IntegratedRepository>>,
) -> Self
pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self
The list of integrated repositories associated with the code review job.
Sourcepub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
The list of integrated repositories associated with the code review job.
Sourcepub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
The code remediation strategy for the code review job.
Sourcepub fn set_code_remediation_strategy(
self,
input: Option<CodeRemediationStrategy>,
) -> Self
pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self
The code remediation strategy for the code review job.
Sourcepub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
The code remediation strategy for the code review job.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the code review job was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the code review job was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the code review job was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the code review job was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the code review job was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the code review job was last updated, in UTC format.
Sourcepub fn build(self) -> CodeReviewJob
pub fn build(self) -> CodeReviewJob
Consumes the builder and constructs a CodeReviewJob.