#[non_exhaustive]pub struct CodeReviewJobSummaryBuilder { /* private fields */ }Expand description
A builder for CodeReviewJobSummary.
Implementations
Sourceimpl CodeReviewJobSummaryBuilder
impl CodeReviewJobSummaryBuilder
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job.
This field is required.Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the job.
This field is required.Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the job.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the job.
Sourcepub fn set_status(self, input: Option<JobStatus>) -> Self
pub fn set_status(self, input: Option<JobStatus>) -> Self
The current status of the code review job.
Sourcepub fn get_status(&self) -> &Option<JobStatus>
pub fn get_status(&self) -> &Option<JobStatus>
The current status of the code review job.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the code review job was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the code review job was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the code review job was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the code review job was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the code review job was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the code review job was last updated, in UTC format.
Sourcepub fn build(self) -> Result<CodeReviewJobSummary, BuildError>
pub fn build(self) -> Result<CodeReviewJobSummary, BuildError>
Consumes the builder and constructs a CodeReviewJobSummary.
This method will fail if any of the following fields are not set: