#[non_exhaustive]pub struct CodeReviewJobTaskBuilder { /* private fields */ }Expand description
A builder for CodeReviewJobTask.
Implementations
Sourceimpl CodeReviewJobTaskBuilder
impl CodeReviewJobTaskBuilder
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
The unique identifier of the task.
This field is required.Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
The unique identifier of the task.
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
The unique identifier of the task.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the task.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the task.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the task.
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job that contains the task.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job that contains the task.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job that contains the task.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the task.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the task.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the task.
Sourcepub fn categories(self, input: Category) -> Self
pub fn categories(self, input: Category) -> Self
Appends an item to categories.
To override the contents of this collection use set_categories.
The list of categories assigned to the task.
Sourcepub fn set_categories(self, input: Option<Vec<Category>>) -> Self
pub fn set_categories(self, input: Option<Vec<Category>>) -> Self
The list of categories assigned to the task.
Sourcepub fn get_categories(&self) -> &Option<Vec<Category>>
pub fn get_categories(&self) -> &Option<Vec<Category>>
The list of categories assigned to the task.
Sourcepub fn risk_type(self, input: RiskType) -> Self
pub fn risk_type(self, input: RiskType) -> Self
The type of security risk the task is testing for.
Sourcepub fn set_risk_type(self, input: Option<RiskType>) -> Self
pub fn set_risk_type(self, input: Option<RiskType>) -> Self
The type of security risk the task is testing for.
Sourcepub fn get_risk_type(&self) -> &Option<RiskType>
pub fn get_risk_type(&self) -> &Option<RiskType>
The type of security risk the task is testing for.
Sourcepub fn execution_status(self, input: TaskExecutionStatus) -> Self
pub fn execution_status(self, input: TaskExecutionStatus) -> Self
The current execution status of the task.
Sourcepub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
pub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
The current execution status of the task.
Sourcepub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
pub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn logs_location(self, input: LogLocation) -> Self
pub fn logs_location(self, input: LogLocation) -> Self
The location of the task execution logs.
Sourcepub fn set_logs_location(self, input: Option<LogLocation>) -> Self
pub fn set_logs_location(self, input: Option<LogLocation>) -> Self
The location of the task execution logs.
Sourcepub fn get_logs_location(&self) -> &Option<LogLocation>
pub fn get_logs_location(&self) -> &Option<LogLocation>
The location of the task execution logs.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the task was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the task was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the task was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the task was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the task was last updated, in UTC format.
Sourcepub fn build(self) -> Result<CodeReviewJobTask, BuildError>
pub fn build(self) -> Result<CodeReviewJobTask, BuildError>
Consumes the builder and constructs a CodeReviewJobTask.
This method will fail if any of the following fields are not set: