#[non_exhaustive]pub struct CodeReviewJobTaskSummaryBuilder { /* private fields */ }Expand description
A builder for CodeReviewJobTaskSummary.
Implementations
Sourceimpl CodeReviewJobTaskSummaryBuilder
impl CodeReviewJobTaskSummaryBuilder
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
The unique identifier of the task.
This field is required.Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
The unique identifier of the task.
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
The unique identifier of the task.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the task.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the task.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the task.
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job that contains the task.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job that contains the task.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job that contains the task.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn risk_type(self, input: RiskType) -> Self
pub fn risk_type(self, input: RiskType) -> Self
The type of security risk the task is testing for.
Sourcepub fn set_risk_type(self, input: Option<RiskType>) -> Self
pub fn set_risk_type(self, input: Option<RiskType>) -> Self
The type of security risk the task is testing for.
Sourcepub fn get_risk_type(&self) -> &Option<RiskType>
pub fn get_risk_type(&self) -> &Option<RiskType>
The type of security risk the task is testing for.
Sourcepub fn execution_status(self, input: TaskExecutionStatus) -> Self
pub fn execution_status(self, input: TaskExecutionStatus) -> Self
The current execution status of the task.
Sourcepub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
pub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
The current execution status of the task.
Sourcepub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
pub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the task was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the task was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the task was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the task was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the task was last updated, in UTC format.
Sourcepub fn build(self) -> Result<CodeReviewJobTaskSummary, BuildError>
pub fn build(self) -> Result<CodeReviewJobTaskSummary, BuildError>
Consumes the builder and constructs a CodeReviewJobTaskSummary.
This method will fail if any of the following fields are not set: