#[non_exhaustive]pub struct CodeReviewSummaryBuilder { /* private fields */ }Expand description
A builder for CodeReviewSummary.
Implementations
Sourceimpl CodeReviewSummaryBuilder
impl CodeReviewSummaryBuilder
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review.
This field is required.Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the code review.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the code review.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the code review.
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the code review.
This field is required.Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the code review was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the code review was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the code review was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the code review was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the code review was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the code review was last updated, in UTC format.
Sourcepub fn build(self) -> Result<CodeReviewSummary, BuildError>
pub fn build(self) -> Result<CodeReviewSummary, BuildError>
Consumes the builder and constructs a CodeReviewSummary.
This method will fail if any of the following fields are not set: