#[non_exhaustive]pub struct DeleteCodeReviewFailureBuilder { /* private fields */ }Expand description
A builder for DeleteCodeReviewFailure.
Implementations
Sourceimpl DeleteCodeReviewFailureBuilder
impl DeleteCodeReviewFailureBuilder
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review that failed to delete.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review that failed to delete.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review that failed to delete.
Sourcepub fn reason(self, input: impl Into<String>) -> Self
pub fn reason(self, input: impl Into<String>) -> Self
The reason the code review failed to delete.
Sourcepub fn set_reason(self, input: Option<String>) -> Self
pub fn set_reason(self, input: Option<String>) -> Self
The reason the code review failed to delete.
Sourcepub fn get_reason(&self) -> &Option<String>
pub fn get_reason(&self) -> &Option<String>
The reason the code review failed to delete.
Sourcepub fn build(self) -> DeleteCodeReviewFailure
pub fn build(self) -> DeleteCodeReviewFailure
Consumes the builder and constructs a DeleteCodeReviewFailure.