#[non_exhaustive]pub struct DeleteThreatModelFailureBuilder { /* private fields */ }Expand description
A builder for DeleteThreatModelFailure.
Implementations
Sourceimpl DeleteThreatModelFailureBuilder
impl DeleteThreatModelFailureBuilder
Sourcepub fn threat_model_id(self, input: impl Into<String>) -> Self
pub fn threat_model_id(self, input: impl Into<String>) -> Self
The unique identifier of the threat model that failed to delete.
Sourcepub fn set_threat_model_id(self, input: Option<String>) -> Self
pub fn set_threat_model_id(self, input: Option<String>) -> Self
The unique identifier of the threat model that failed to delete.
Sourcepub fn get_threat_model_id(&self) -> &Option<String>
pub fn get_threat_model_id(&self) -> &Option<String>
The unique identifier of the threat model that failed to delete.
Sourcepub fn reason(self, input: impl Into<String>) -> Self
pub fn reason(self, input: impl Into<String>) -> Self
The reason the threat model failed to delete.
Sourcepub fn set_reason(self, input: Option<String>) -> Self
pub fn set_reason(self, input: Option<String>) -> Self
The reason the threat model failed to delete.
Sourcepub fn get_reason(&self) -> &Option<String>
pub fn get_reason(&self) -> &Option<String>
The reason the threat model failed to delete.
Sourcepub fn build(self) -> DeleteThreatModelFailure
pub fn build(self) -> DeleteThreatModelFailure
Consumes the builder and constructs a DeleteThreatModelFailure.