#[non_exhaustive]pub struct DiscoveredEndpointBuilder { /* private fields */ }Expand description
A builder for DiscoveredEndpoint.
Implementations
Sourceimpl DiscoveredEndpointBuilder
impl DiscoveredEndpointBuilder
Sourcepub fn uri(self, input: impl Into<String>) -> Self
pub fn uri(self, input: impl Into<String>) -> Self
The URI of the discovered endpoint This field is required.
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
Identifier of the pentest job that discovered this endpoint This field is required.
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
Identifier of the pentest job that discovered this endpoint
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
Identifier of the pentest job that discovered this endpoint
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
Identifier of the task that discovered this endpoint This field is required.
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
Identifier of the task that discovered this endpoint
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
Identifier of the task that discovered this endpoint
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Identifier of the agent space where the endpoint was discovered This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Identifier of the agent space where the endpoint was discovered
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Identifier of the agent space where the endpoint was discovered
Sourcepub fn evidence(self, input: impl Into<String>) -> Self
pub fn evidence(self, input: impl Into<String>) -> Self
Optional evidence or additional information about the endpoint
Sourcepub fn set_evidence(self, input: Option<String>) -> Self
pub fn set_evidence(self, input: Option<String>) -> Self
Optional evidence or additional information about the endpoint
Sourcepub fn get_evidence(&self) -> &Option<String>
pub fn get_evidence(&self) -> &Option<String>
Optional evidence or additional information about the endpoint
Sourcepub fn operation(self, input: impl Into<String>) -> Self
pub fn operation(self, input: impl Into<String>) -> Self
Operation or action associated with the endpoint
Sourcepub fn set_operation(self, input: Option<String>) -> Self
pub fn set_operation(self, input: Option<String>) -> Self
Operation or action associated with the endpoint
Sourcepub fn get_operation(&self) -> &Option<String>
pub fn get_operation(&self) -> &Option<String>
Operation or action associated with the endpoint
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Additional description of the endpoint
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Additional description of the endpoint
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Additional description of the endpoint
Sourcepub fn build(self) -> Result<DiscoveredEndpoint, BuildError>
pub fn build(self) -> Result<DiscoveredEndpoint, BuildError>
Consumes the builder and constructs a DiscoveredEndpoint.
This method will fail if any of the following fields are not set: