#[non_exhaustive]pub struct FindingBuilder { /* private fields */ }Expand description
A builder for Finding.
Implementations
Sourceimpl FindingBuilder
impl FindingBuilder
Sourcepub fn finding_id(self, input: impl Into<String>) -> Self
pub fn finding_id(self, input: impl Into<String>) -> Self
The unique identifier of the finding.
This field is required.Sourcepub fn set_finding_id(self, input: Option<String>) -> Self
pub fn set_finding_id(self, input: Option<String>) -> Self
The unique identifier of the finding.
Sourcepub fn get_finding_id(&self) -> &Option<String>
pub fn get_finding_id(&self) -> &Option<String>
The unique identifier of the finding.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space associated with the finding.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space associated with the finding.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space associated with the finding.
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest associated with the finding.
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
The unique identifier of the pentest associated with the finding.
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
The unique identifier of the pentest associated with the finding.
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest job that produced the finding.
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
The unique identifier of the pentest job that produced the finding.
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
The unique identifier of the pentest job that produced the finding.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the finding.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the finding.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the finding.
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job that produced the finding.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job that produced the finding.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job that produced the finding.
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
The unique identifier of the task that produced the finding.
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
The unique identifier of the task that produced the finding.
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
The unique identifier of the task that produced the finding.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the finding.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the finding.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the finding.
Sourcepub fn status(self, input: FindingStatus) -> Self
pub fn status(self, input: FindingStatus) -> Self
The current status of the finding. Valid values include ACTIVE, RESOLVED, ACCEPTED, and FALSE_POSITIVE.
Sourcepub fn set_status(self, input: Option<FindingStatus>) -> Self
pub fn set_status(self, input: Option<FindingStatus>) -> Self
The current status of the finding. Valid values include ACTIVE, RESOLVED, ACCEPTED, and FALSE_POSITIVE.
Sourcepub fn get_status(&self) -> &Option<FindingStatus>
pub fn get_status(&self) -> &Option<FindingStatus>
The current status of the finding. Valid values include ACTIVE, RESOLVED, ACCEPTED, and FALSE_POSITIVE.
Sourcepub fn risk_type(self, input: impl Into<String>) -> Self
pub fn risk_type(self, input: impl Into<String>) -> Self
The type of security risk identified by the finding.
Sourcepub fn set_risk_type(self, input: Option<String>) -> Self
pub fn set_risk_type(self, input: Option<String>) -> Self
The type of security risk identified by the finding.
Sourcepub fn get_risk_type(&self) -> &Option<String>
pub fn get_risk_type(&self) -> &Option<String>
The type of security risk identified by the finding.
Sourcepub fn risk_level(self, input: RiskLevel) -> Self
pub fn risk_level(self, input: RiskLevel) -> Self
The risk level of the finding. Valid values include UNKNOWN, INFORMATIONAL, LOW, MEDIUM, HIGH, and CRITICAL.
Sourcepub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
pub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
The risk level of the finding. Valid values include UNKNOWN, INFORMATIONAL, LOW, MEDIUM, HIGH, and CRITICAL.
Sourcepub fn get_risk_level(&self) -> &Option<RiskLevel>
pub fn get_risk_level(&self) -> &Option<RiskLevel>
The risk level of the finding. Valid values include UNKNOWN, INFORMATIONAL, LOW, MEDIUM, HIGH, and CRITICAL.
Sourcepub fn risk_score(self, input: impl Into<String>) -> Self
pub fn risk_score(self, input: impl Into<String>) -> Self
The numerical risk score of the finding.
Sourcepub fn set_risk_score(self, input: Option<String>) -> Self
pub fn set_risk_score(self, input: Option<String>) -> Self
The numerical risk score of the finding.
Sourcepub fn get_risk_score(&self) -> &Option<String>
pub fn get_risk_score(&self) -> &Option<String>
The numerical risk score of the finding.
Sourcepub fn reasoning(self, input: impl Into<String>) -> Self
pub fn reasoning(self, input: impl Into<String>) -> Self
The reasoning behind the finding, explaining why it was identified as a vulnerability.
Sourcepub fn set_reasoning(self, input: Option<String>) -> Self
pub fn set_reasoning(self, input: Option<String>) -> Self
The reasoning behind the finding, explaining why it was identified as a vulnerability.
Sourcepub fn get_reasoning(&self) -> &Option<String>
pub fn get_reasoning(&self) -> &Option<String>
The reasoning behind the finding, explaining why it was identified as a vulnerability.
Sourcepub fn confidence(self, input: ConfidenceLevel) -> Self
pub fn confidence(self, input: ConfidenceLevel) -> Self
The confidence level of the finding. Valid values include FALSE_POSITIVE, UNCONFIRMED, LOW, MEDIUM, and HIGH.
Sourcepub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
pub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
The confidence level of the finding. Valid values include FALSE_POSITIVE, UNCONFIRMED, LOW, MEDIUM, and HIGH.
Sourcepub fn get_confidence(&self) -> &Option<ConfidenceLevel>
pub fn get_confidence(&self) -> &Option<ConfidenceLevel>
The confidence level of the finding. Valid values include FALSE_POSITIVE, UNCONFIRMED, LOW, MEDIUM, and HIGH.
Sourcepub fn attack_script(self, input: impl Into<String>) -> Self
pub fn attack_script(self, input: impl Into<String>) -> Self
The attack script used to reproduce the finding.
Sourcepub fn set_attack_script(self, input: Option<String>) -> Self
pub fn set_attack_script(self, input: Option<String>) -> Self
The attack script used to reproduce the finding.
Sourcepub fn get_attack_script(&self) -> &Option<String>
pub fn get_attack_script(&self) -> &Option<String>
The attack script used to reproduce the finding.
Sourcepub fn code_remediation_task(self, input: CodeRemediationTask) -> Self
pub fn code_remediation_task(self, input: CodeRemediationTask) -> Self
The code remediation task associated with the finding, if code remediation was initiated.
Sourcepub fn set_code_remediation_task(
self,
input: Option<CodeRemediationTask>,
) -> Self
pub fn set_code_remediation_task( self, input: Option<CodeRemediationTask>, ) -> Self
The code remediation task associated with the finding, if code remediation was initiated.
Sourcepub fn get_code_remediation_task(&self) -> &Option<CodeRemediationTask>
pub fn get_code_remediation_task(&self) -> &Option<CodeRemediationTask>
The code remediation task associated with the finding, if code remediation was initiated.
Sourcepub fn last_updated_by(self, input: impl Into<String>) -> Self
pub fn last_updated_by(self, input: impl Into<String>) -> Self
The identifier of the entity that last updated the finding.
Sourcepub fn set_last_updated_by(self, input: Option<String>) -> Self
pub fn set_last_updated_by(self, input: Option<String>) -> Self
The identifier of the entity that last updated the finding.
Sourcepub fn get_last_updated_by(&self) -> &Option<String>
pub fn get_last_updated_by(&self) -> &Option<String>
The identifier of the entity that last updated the finding.
Sourcepub fn code_locations(self, input: CodeLocation) -> Self
pub fn code_locations(self, input: CodeLocation) -> Self
Appends an item to code_locations.
To override the contents of this collection use set_code_locations.
The file locations involved in the vulnerability, as reported by the code scanner.
Sourcepub fn set_code_locations(self, input: Option<Vec<CodeLocation>>) -> Self
pub fn set_code_locations(self, input: Option<Vec<CodeLocation>>) -> Self
The file locations involved in the vulnerability, as reported by the code scanner.
Sourcepub fn get_code_locations(&self) -> &Option<Vec<CodeLocation>>
pub fn get_code_locations(&self) -> &Option<Vec<CodeLocation>>
The file locations involved in the vulnerability, as reported by the code scanner.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the finding was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the finding was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the finding was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the finding was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the finding was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the finding was last updated, in UTC format.