#[non_exhaustive]pub struct FindingSummaryBuilder { /* private fields */ }Expand description
A builder for FindingSummary.
Implementations
Sourceimpl FindingSummaryBuilder
impl FindingSummaryBuilder
Sourcepub fn finding_id(self, input: impl Into<String>) -> Self
pub fn finding_id(self, input: impl Into<String>) -> Self
The unique identifier of the finding.
This field is required.Sourcepub fn set_finding_id(self, input: Option<String>) -> Self
pub fn set_finding_id(self, input: Option<String>) -> Self
The unique identifier of the finding.
Sourcepub fn get_finding_id(&self) -> &Option<String>
pub fn get_finding_id(&self) -> &Option<String>
The unique identifier of the finding.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space associated with the finding.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space associated with the finding.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space associated with the finding.
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest associated with the finding.
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
The unique identifier of the pentest associated with the finding.
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
The unique identifier of the pentest associated with the finding.
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest job that produced the finding.
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
The unique identifier of the pentest job that produced the finding.
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
The unique identifier of the pentest job that produced the finding.
Sourcepub fn code_review_id(self, input: impl Into<String>) -> Self
pub fn code_review_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review associated with the finding.
Sourcepub fn set_code_review_id(self, input: Option<String>) -> Self
pub fn set_code_review_id(self, input: Option<String>) -> Self
The unique identifier of the code review associated with the finding.
Sourcepub fn get_code_review_id(&self) -> &Option<String>
pub fn get_code_review_id(&self) -> &Option<String>
The unique identifier of the code review associated with the finding.
Sourcepub fn code_review_job_id(self, input: impl Into<String>) -> Self
pub fn code_review_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the code review job that produced the finding.
Sourcepub fn set_code_review_job_id(self, input: Option<String>) -> Self
pub fn set_code_review_job_id(self, input: Option<String>) -> Self
The unique identifier of the code review job that produced the finding.
Sourcepub fn get_code_review_job_id(&self) -> &Option<String>
pub fn get_code_review_job_id(&self) -> &Option<String>
The unique identifier of the code review job that produced the finding.
Sourcepub fn status(self, input: FindingStatus) -> Self
pub fn status(self, input: FindingStatus) -> Self
The current status of the finding.
Sourcepub fn set_status(self, input: Option<FindingStatus>) -> Self
pub fn set_status(self, input: Option<FindingStatus>) -> Self
The current status of the finding.
Sourcepub fn get_status(&self) -> &Option<FindingStatus>
pub fn get_status(&self) -> &Option<FindingStatus>
The current status of the finding.
Sourcepub fn risk_type(self, input: impl Into<String>) -> Self
pub fn risk_type(self, input: impl Into<String>) -> Self
The type of security risk identified by the finding.
Sourcepub fn set_risk_type(self, input: Option<String>) -> Self
pub fn set_risk_type(self, input: Option<String>) -> Self
The type of security risk identified by the finding.
Sourcepub fn get_risk_type(&self) -> &Option<String>
pub fn get_risk_type(&self) -> &Option<String>
The type of security risk identified by the finding.
Sourcepub fn risk_level(self, input: RiskLevel) -> Self
pub fn risk_level(self, input: RiskLevel) -> Self
The risk level of the finding.
Sourcepub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
pub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
The risk level of the finding.
Sourcepub fn get_risk_level(&self) -> &Option<RiskLevel>
pub fn get_risk_level(&self) -> &Option<RiskLevel>
The risk level of the finding.
Sourcepub fn confidence(self, input: ConfidenceLevel) -> Self
pub fn confidence(self, input: ConfidenceLevel) -> Self
The confidence level of the finding.
Sourcepub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
pub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
The confidence level of the finding.
Sourcepub fn get_confidence(&self) -> &Option<ConfidenceLevel>
pub fn get_confidence(&self) -> &Option<ConfidenceLevel>
The confidence level of the finding.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the finding was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the finding was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the finding was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the finding was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the finding was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the finding was last updated, in UTC format.
Sourcepub fn build(self) -> Result<FindingSummary, BuildError>
pub fn build(self) -> Result<FindingSummary, BuildError>
Consumes the builder and constructs a FindingSummary.
This method will fail if any of the following fields are not set: