#[non_exhaustive]pub struct GitLabIntegrationInputBuilder { /* private fields */ }Expand description
A builder for GitLabIntegrationInput.
Implementations
Sourceimpl GitLabIntegrationInputBuilder
impl GitLabIntegrationInputBuilder
Sourcepub fn access_token(self, input: impl Into<String>) -> Self
pub fn access_token(self, input: impl Into<String>) -> Self
The GitLab access token used to authenticate. This can be a personal access token or a group access token.
This field is required.Sourcepub fn set_access_token(self, input: Option<String>) -> Self
pub fn set_access_token(self, input: Option<String>) -> Self
The GitLab access token used to authenticate. This can be a personal access token or a group access token.
Sourcepub fn get_access_token(&self) -> &Option<String>
pub fn get_access_token(&self) -> &Option<String>
The GitLab access token used to authenticate. This can be a personal access token or a group access token.
Sourcepub fn target_url(self, input: impl Into<String>) -> Self
pub fn target_url(self, input: impl Into<String>) -> Self
The HTTPS URL of a self-managed GitLab instance. Omit this value for GitLab SaaS (gitlab.com).
Sourcepub fn set_target_url(self, input: Option<String>) -> Self
pub fn set_target_url(self, input: Option<String>) -> Self
The HTTPS URL of a self-managed GitLab instance. Omit this value for GitLab SaaS (gitlab.com).
Sourcepub fn get_target_url(&self) -> &Option<String>
pub fn get_target_url(&self) -> &Option<String>
The HTTPS URL of a self-managed GitLab instance. Omit this value for GitLab SaaS (gitlab.com).
Sourcepub fn token_type(self, input: GitLabTokenType) -> Self
pub fn token_type(self, input: GitLabTokenType) -> Self
The type of GitLab access token provided in accessToken.
This field is required.Sourcepub fn set_token_type(self, input: Option<GitLabTokenType>) -> Self
pub fn set_token_type(self, input: Option<GitLabTokenType>) -> Self
The type of GitLab access token provided in accessToken.
Sourcepub fn get_token_type(&self) -> &Option<GitLabTokenType>
pub fn get_token_type(&self) -> &Option<GitLabTokenType>
The type of GitLab access token provided in accessToken.
Sourcepub fn group_id(self, input: impl Into<String>) -> Self
pub fn group_id(self, input: impl Into<String>) -> Self
The identifier of the GitLab group. Required when tokenType is group and ignored for personal tokens.
Sourcepub fn set_group_id(self, input: Option<String>) -> Self
pub fn set_group_id(self, input: Option<String>) -> Self
The identifier of the GitLab group. Required when tokenType is group and ignored for personal tokens.
Sourcepub fn get_group_id(&self) -> &Option<String>
pub fn get_group_id(&self) -> &Option<String>
The identifier of the GitLab group. Required when tokenType is group and ignored for personal tokens.
Sourcepub fn build(self) -> Result<GitLabIntegrationInput, BuildError>
pub fn build(self) -> Result<GitLabIntegrationInput, BuildError>
Consumes the builder and constructs a GitLabIntegrationInput.
This method will fail if any of the following fields are not set: