GitLabResourceCapabilitiesBuilder

Struct GitLabResourceCapabilitiesBuilder 

#[non_exhaustive]
pub struct GitLabResourceCapabilitiesBuilder { /* private fields */ }
Implementations

Source

impl GitLabResourceCapabilitiesBuilder

pub fn leave_comments(self, input: bool) -> Self

Whether to post code review comments on merge request discussions.

pub fn set_leave_comments(self, input: Option<bool>) -> Self

Whether to post code review comments on merge request discussions.

pub fn get_leave_comments(&self) -> &Option<bool>

Whether to post code review comments on merge request discussions.

pub fn remediate_code(self, input: bool) -> Self

Whether to create merge requests with automated fixes.

pub fn set_remediate_code(self, input: Option<bool>) -> Self

Whether to create merge requests with automated fixes.

pub fn get_remediate_code(&self) -> &Option<bool>

Whether to create merge requests with automated fixes.

pub fn build(self) -> GitLabResourceCapabilities

Consumes the builder and constructs a GitLabResourceCapabilities.