#[non_exhaustive]pub struct IntegratedResourceSummaryBuilder { /* private fields */ }Expand description
A builder for IntegratedResourceSummary.
Implementations
Sourceimpl IntegratedResourceSummaryBuilder
impl IntegratedResourceSummaryBuilder
Sourcepub fn integration_id(self, input: impl Into<String>) -> Self
pub fn integration_id(self, input: impl Into<String>) -> Self
Unique identifier of the integration This field is required.
Sourcepub fn set_integration_id(self, input: Option<String>) -> Self
pub fn set_integration_id(self, input: Option<String>) -> Self
Unique identifier of the integration
Sourcepub fn get_integration_id(&self) -> &Option<String>
pub fn get_integration_id(&self) -> &Option<String>
Unique identifier of the integration
Sourcepub fn resource(self, input: IntegratedResourceMetadata) -> Self
pub fn resource(self, input: IntegratedResourceMetadata) -> Self
The integrated resource details This field is required.
Sourcepub fn set_resource(self, input: Option<IntegratedResourceMetadata>) -> Self
pub fn set_resource(self, input: Option<IntegratedResourceMetadata>) -> Self
The integrated resource details
Sourcepub fn get_resource(&self) -> &Option<IntegratedResourceMetadata>
pub fn get_resource(&self) -> &Option<IntegratedResourceMetadata>
The integrated resource details
Sourcepub fn capabilities(self, input: ProviderResourceCapabilities) -> Self
pub fn capabilities(self, input: ProviderResourceCapabilities) -> Self
Capabilities of the integrated resource
Sourcepub fn set_capabilities(
self,
input: Option<ProviderResourceCapabilities>,
) -> Self
pub fn set_capabilities( self, input: Option<ProviderResourceCapabilities>, ) -> Self
Capabilities of the integrated resource
Sourcepub fn get_capabilities(&self) -> &Option<ProviderResourceCapabilities>
pub fn get_capabilities(&self) -> &Option<ProviderResourceCapabilities>
Capabilities of the integrated resource
Sourcepub fn build(self) -> Result<IntegratedResourceSummary, BuildError>
pub fn build(self) -> Result<IntegratedResourceSummary, BuildError>
Consumes the builder and constructs a IntegratedResourceSummary.
This method will fail if any of the following fields are not set: