#[non_exhaustive]pub struct MembershipSummaryBuilder { /* private fields */ }Expand description
A builder for MembershipSummary.
Implementations
Sourceimpl MembershipSummaryBuilder
impl MembershipSummaryBuilder
Sourcepub fn membership_id(self, input: impl Into<String>) -> Self
pub fn membership_id(self, input: impl Into<String>) -> Self
The unique identifier of the membership.
This field is required.Sourcepub fn set_membership_id(self, input: Option<String>) -> Self
pub fn set_membership_id(self, input: Option<String>) -> Self
The unique identifier of the membership.
Sourcepub fn get_membership_id(&self) -> &Option<String>
pub fn get_membership_id(&self) -> &Option<String>
The unique identifier of the membership.
Sourcepub fn application_id(self, input: impl Into<String>) -> Self
pub fn application_id(self, input: impl Into<String>) -> Self
The unique identifier of the application.
This field is required.Sourcepub fn set_application_id(self, input: Option<String>) -> Self
pub fn set_application_id(self, input: Option<String>) -> Self
The unique identifier of the application.
Sourcepub fn get_application_id(&self) -> &Option<String>
pub fn get_application_id(&self) -> &Option<String>
The unique identifier of the application.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn member_type(self, input: MembershipType) -> Self
pub fn member_type(self, input: MembershipType) -> Self
The type of member.
This field is required.Sourcepub fn set_member_type(self, input: Option<MembershipType>) -> Self
pub fn set_member_type(self, input: Option<MembershipType>) -> Self
The type of member.
Sourcepub fn get_member_type(&self) -> &Option<MembershipType>
pub fn get_member_type(&self) -> &Option<MembershipType>
The type of member.
Sourcepub fn config(self, input: MembershipConfig) -> Self
pub fn config(self, input: MembershipConfig) -> Self
The configuration for the membership.
Sourcepub fn set_config(self, input: Option<MembershipConfig>) -> Self
pub fn set_config(self, input: Option<MembershipConfig>) -> Self
The configuration for the membership.
Sourcepub fn get_config(&self) -> &Option<MembershipConfig>
pub fn get_config(&self) -> &Option<MembershipConfig>
The configuration for the membership.
Sourcepub fn metadata(self, input: MemberMetadata) -> Self
pub fn metadata(self, input: MemberMetadata) -> Self
The metadata for the member.
Sourcepub fn set_metadata(self, input: Option<MemberMetadata>) -> Self
pub fn set_metadata(self, input: Option<MemberMetadata>) -> Self
The metadata for the member.
Sourcepub fn get_metadata(&self) -> &Option<MemberMetadata>
pub fn get_metadata(&self) -> &Option<MemberMetadata>
The metadata for the member.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the membership was created, in UTC format.
This field is required.Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the membership was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the membership was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the membership was last updated, in UTC format.
This field is required.Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the membership was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the membership was last updated, in UTC format.
Sourcepub fn created_by(self, input: impl Into<String>) -> Self
pub fn created_by(self, input: impl Into<String>) -> Self
The identifier of the entity that created the membership.
This field is required.Sourcepub fn set_created_by(self, input: Option<String>) -> Self
pub fn set_created_by(self, input: Option<String>) -> Self
The identifier of the entity that created the membership.
Sourcepub fn get_created_by(&self) -> &Option<String>
pub fn get_created_by(&self) -> &Option<String>
The identifier of the entity that created the membership.
Sourcepub fn updated_by(self, input: impl Into<String>) -> Self
pub fn updated_by(self, input: impl Into<String>) -> Self
The identifier of the entity that last updated the membership.
This field is required.Sourcepub fn set_updated_by(self, input: Option<String>) -> Self
pub fn set_updated_by(self, input: Option<String>) -> Self
The identifier of the entity that last updated the membership.
Sourcepub fn get_updated_by(&self) -> &Option<String>
pub fn get_updated_by(&self) -> &Option<String>
The identifier of the entity that last updated the membership.
Sourcepub fn build(self) -> Result<MembershipSummary, BuildError>
pub fn build(self) -> Result<MembershipSummary, BuildError>
Consumes the builder and constructs a MembershipSummary.
This method will fail if any of the following fields are not set: