#[non_exhaustive]pub struct PentestJobBuilder { /* private fields */ }Expand description
A builder for PentestJob.
Implementations
Sourceimpl PentestJobBuilder
impl PentestJobBuilder
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest job.
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
The unique identifier of the pentest job.
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
The unique identifier of the pentest job.
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
The unique identifier of the pentest associated with the job.
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
The unique identifier of the pentest associated with the job.
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
The unique identifier of the pentest associated with the job.
Sourcepub fn overview(self, input: impl Into<String>) -> Self
pub fn overview(self, input: impl Into<String>) -> Self
An overview of the pentest job results.
Sourcepub fn set_overview(self, input: Option<String>) -> Self
pub fn set_overview(self, input: Option<String>) -> Self
An overview of the pentest job results.
Sourcepub fn get_overview(&self) -> &Option<String>
pub fn get_overview(&self) -> &Option<String>
An overview of the pentest job results.
Sourcepub fn set_status(self, input: Option<JobStatus>) -> Self
pub fn set_status(self, input: Option<JobStatus>) -> Self
The current status of the pentest job.
Sourcepub fn get_status(&self) -> &Option<JobStatus>
pub fn get_status(&self) -> &Option<JobStatus>
The current status of the pentest job.
Sourcepub fn endpoints(self, input: Endpoint) -> Self
pub fn endpoints(self, input: Endpoint) -> Self
Appends an item to endpoints.
To override the contents of this collection use set_endpoints.
The list of endpoints being tested in the pentest job.
Sourcepub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
The list of endpoints being tested in the pentest job.
Sourcepub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
pub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
The list of endpoints being tested in the pentest job.
Sourcepub fn actors(self, input: Actor) -> Self
pub fn actors(self, input: Actor) -> Self
Appends an item to actors.
To override the contents of this collection use set_actors.
The list of actors used during the pentest job.
Sourcepub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
pub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
The list of actors used during the pentest job.
Sourcepub fn get_actors(&self) -> &Option<Vec<Actor>>
pub fn get_actors(&self) -> &Option<Vec<Actor>>
The list of actors used during the pentest job.
Sourcepub fn documents(self, input: DocumentInfo) -> Self
pub fn documents(self, input: DocumentInfo) -> Self
Appends an item to documents.
To override the contents of this collection use set_documents.
The list of documents providing context for the pentest job.
Sourcepub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
The list of documents providing context for the pentest job.
Sourcepub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
The list of documents providing context for the pentest job.
Sourcepub fn source_code(self, input: SourceCodeRepository) -> Self
pub fn source_code(self, input: SourceCodeRepository) -> Self
Appends an item to source_code.
To override the contents of this collection use set_source_code.
The list of source code repositories analyzed during the pentest job.
Sourcepub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
The list of source code repositories analyzed during the pentest job.
Sourcepub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
The list of source code repositories analyzed during the pentest job.
Sourcepub fn exclude_paths(self, input: Endpoint) -> Self
pub fn exclude_paths(self, input: Endpoint) -> Self
Appends an item to exclude_paths.
To override the contents of this collection use set_exclude_paths.
The list of paths excluded from the pentest job.
Sourcepub fn set_exclude_paths(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_exclude_paths(self, input: Option<Vec<Endpoint>>) -> Self
The list of paths excluded from the pentest job.
Sourcepub fn get_exclude_paths(&self) -> &Option<Vec<Endpoint>>
pub fn get_exclude_paths(&self) -> &Option<Vec<Endpoint>>
The list of paths excluded from the pentest job.
Sourcepub fn allowed_domains(self, input: Endpoint) -> Self
pub fn allowed_domains(self, input: Endpoint) -> Self
Appends an item to allowed_domains.
To override the contents of this collection use set_allowed_domains.
The list of domains allowed during the pentest job.
Sourcepub fn set_allowed_domains(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_allowed_domains(self, input: Option<Vec<Endpoint>>) -> Self
The list of domains allowed during the pentest job.
Sourcepub fn get_allowed_domains(&self) -> &Option<Vec<Endpoint>>
pub fn get_allowed_domains(&self) -> &Option<Vec<Endpoint>>
The list of domains allowed during the pentest job.
Sourcepub fn exclude_risk_types(self, input: RiskType) -> Self
pub fn exclude_risk_types(self, input: RiskType) -> Self
Appends an item to exclude_risk_types.
To override the contents of this collection use set_exclude_risk_types.
The list of risk types excluded from the pentest job.
Sourcepub fn set_exclude_risk_types(self, input: Option<Vec<RiskType>>) -> Self
pub fn set_exclude_risk_types(self, input: Option<Vec<RiskType>>) -> Self
The list of risk types excluded from the pentest job.
Sourcepub fn get_exclude_risk_types(&self) -> &Option<Vec<RiskType>>
pub fn get_exclude_risk_types(&self) -> &Option<Vec<RiskType>>
The list of risk types excluded from the pentest job.
Sourcepub fn steps(self, input: Step) -> Self
pub fn steps(self, input: Step) -> Self
Appends an item to steps.
To override the contents of this collection use set_steps.
The list of steps in the pentest job execution.
Sourcepub fn set_steps(self, input: Option<Vec<Step>>) -> Self
pub fn set_steps(self, input: Option<Vec<Step>>) -> Self
The list of steps in the pentest job execution.
Sourcepub fn execution_context(self, input: ExecutionContext) -> Self
pub fn execution_context(self, input: ExecutionContext) -> Self
Appends an item to execution_context.
To override the contents of this collection use set_execution_context.
The execution context messages for the pentest job.
Sourcepub fn set_execution_context(self, input: Option<Vec<ExecutionContext>>) -> Self
pub fn set_execution_context(self, input: Option<Vec<ExecutionContext>>) -> Self
The execution context messages for the pentest job.
Sourcepub fn get_execution_context(&self) -> &Option<Vec<ExecutionContext>>
pub fn get_execution_context(&self) -> &Option<Vec<ExecutionContext>>
The execution context messages for the pentest job.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The IAM service role used for the pentest job.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The IAM service role used for the pentest job.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The IAM service role used for the pentest job.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The CloudWatch Logs configuration for the pentest job.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The CloudWatch Logs configuration for the pentest job.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The CloudWatch Logs configuration for the pentest job.
Sourcepub fn vpc_config(self, input: VpcConfig) -> Self
pub fn vpc_config(self, input: VpcConfig) -> Self
The VPC configuration for the pentest job.
Sourcepub fn set_vpc_config(self, input: Option<VpcConfig>) -> Self
pub fn set_vpc_config(self, input: Option<VpcConfig>) -> Self
The VPC configuration for the pentest job.
Sourcepub fn get_vpc_config(&self) -> &Option<VpcConfig>
pub fn get_vpc_config(&self) -> &Option<VpcConfig>
The VPC configuration for the pentest job.
Sourcepub fn network_traffic_config(self, input: NetworkTrafficConfig) -> Self
pub fn network_traffic_config(self, input: NetworkTrafficConfig) -> Self
The network traffic configuration for the pentest job.
Sourcepub fn set_network_traffic_config(
self,
input: Option<NetworkTrafficConfig>,
) -> Self
pub fn set_network_traffic_config( self, input: Option<NetworkTrafficConfig>, ) -> Self
The network traffic configuration for the pentest job.
Sourcepub fn get_network_traffic_config(&self) -> &Option<NetworkTrafficConfig>
pub fn get_network_traffic_config(&self) -> &Option<NetworkTrafficConfig>
The network traffic configuration for the pentest job.
Sourcepub fn error_information(self, input: ErrorInformation) -> Self
pub fn error_information(self, input: ErrorInformation) -> Self
Error information if the pentest job encountered an error.
Sourcepub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
pub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
Error information if the pentest job encountered an error.
Sourcepub fn get_error_information(&self) -> &Option<ErrorInformation>
pub fn get_error_information(&self) -> &Option<ErrorInformation>
Error information if the pentest job encountered an error.
Sourcepub fn integrated_repositories(self, input: IntegratedRepository) -> Self
pub fn integrated_repositories(self, input: IntegratedRepository) -> Self
Appends an item to integrated_repositories.
To override the contents of this collection use set_integrated_repositories.
The list of integrated repositories associated with the pentest job.
Sourcepub fn set_integrated_repositories(
self,
input: Option<Vec<IntegratedRepository>>,
) -> Self
pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self
The list of integrated repositories associated with the pentest job.
Sourcepub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
The list of integrated repositories associated with the pentest job.
Sourcepub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self
The code remediation strategy for the pentest job.
Sourcepub fn set_code_remediation_strategy(
self,
input: Option<CodeRemediationStrategy>,
) -> Self
pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self
The code remediation strategy for the pentest job.
Sourcepub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>
The code remediation strategy for the pentest job.
Sourcepub fn clean_up_strategy(self, input: CleanUpStrategy) -> Self
pub fn clean_up_strategy(self, input: CleanUpStrategy) -> Self
Strategy for cleaning up resources after pentest job completion.
Sourcepub fn set_clean_up_strategy(self, input: Option<CleanUpStrategy>) -> Self
pub fn set_clean_up_strategy(self, input: Option<CleanUpStrategy>) -> Self
Strategy for cleaning up resources after pentest job completion.
Sourcepub fn get_clean_up_strategy(&self) -> &Option<CleanUpStrategy>
pub fn get_clean_up_strategy(&self) -> &Option<CleanUpStrategy>
Strategy for cleaning up resources after pentest job completion.
Sourcepub fn disable_managed_skills(self, input: SkillType) -> Self
pub fn disable_managed_skills(self, input: SkillType) -> Self
Appends an item to disable_managed_skills.
To override the contents of this collection use set_disable_managed_skills.
A list of managed skills disabled for this pentest job. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
Sourcepub fn set_disable_managed_skills(self, input: Option<Vec<SkillType>>) -> Self
pub fn set_disable_managed_skills(self, input: Option<Vec<SkillType>>) -> Self
A list of managed skills disabled for this pentest job. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
Sourcepub fn get_disable_managed_skills(&self) -> &Option<Vec<SkillType>>
pub fn get_disable_managed_skills(&self) -> &Option<Vec<SkillType>>
A list of managed skills disabled for this pentest job. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the pentest job was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the pentest job was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the pentest job was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the pentest job was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the pentest job was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the pentest job was last updated, in UTC format.
Sourcepub fn build(self) -> PentestJob
pub fn build(self) -> PentestJob
Consumes the builder and constructs a PentestJob.