#[non_exhaustive]pub struct SecurityRequirementPackSummaryBuilder { /* private fields */ }Expand description
A builder for SecurityRequirementPackSummary.
Implementations
Sourceimpl SecurityRequirementPackSummaryBuilder
impl SecurityRequirementPackSummaryBuilder
Sourcepub fn pack_id(self, input: impl Into<String>) -> Self
pub fn pack_id(self, input: impl Into<String>) -> Self
The unique identifier of the security requirement pack.
This field is required.Sourcepub fn set_pack_id(self, input: Option<String>) -> Self
pub fn set_pack_id(self, input: Option<String>) -> Self
The unique identifier of the security requirement pack.
Sourcepub fn get_pack_id(&self) -> &Option<String>
pub fn get_pack_id(&self) -> &Option<String>
The unique identifier of the security requirement pack.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the security requirement pack.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the security requirement pack.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the security requirement pack.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the security requirement pack.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the security requirement pack.
Sourcepub fn vendor_name(self, input: impl Into<String>) -> Self
pub fn vendor_name(self, input: impl Into<String>) -> Self
The vendor name for AWS managed packs.
Sourcepub fn set_vendor_name(self, input: Option<String>) -> Self
pub fn set_vendor_name(self, input: Option<String>) -> Self
The vendor name for AWS managed packs.
Sourcepub fn get_vendor_name(&self) -> &Option<String>
pub fn get_vendor_name(&self) -> &Option<String>
The vendor name for AWS managed packs.
Sourcepub fn management_type(self, input: ManagementType) -> Self
pub fn management_type(self, input: ManagementType) -> Self
The management type of the pack.
This field is required.Sourcepub fn set_management_type(self, input: Option<ManagementType>) -> Self
pub fn set_management_type(self, input: Option<ManagementType>) -> Self
The management type of the pack.
Sourcepub fn get_management_type(&self) -> &Option<ManagementType>
pub fn get_management_type(&self) -> &Option<ManagementType>
The management type of the pack.
Sourcepub fn status(self, input: SecurityRequirementPackStatus) -> Self
pub fn status(self, input: SecurityRequirementPackStatus) -> Self
The status of the security requirement pack.
This field is required.Sourcepub fn set_status(self, input: Option<SecurityRequirementPackStatus>) -> Self
pub fn set_status(self, input: Option<SecurityRequirementPackStatus>) -> Self
The status of the security requirement pack.
Sourcepub fn get_status(&self) -> &Option<SecurityRequirementPackStatus>
pub fn get_status(&self) -> &Option<SecurityRequirementPackStatus>
The status of the security requirement pack.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the security requirement pack was created, in UTC format.
This field is required.Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the security requirement pack was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the security requirement pack was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the security requirement pack was last updated, in UTC format.
This field is required.Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the security requirement pack was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the security requirement pack was last updated, in UTC format.
Sourcepub fn build(self) -> Result<SecurityRequirementPackSummary, BuildError>
pub fn build(self) -> Result<SecurityRequirementPackSummary, BuildError>
Consumes the builder and constructs a SecurityRequirementPackSummary.
This method will fail if any of the following fields are not set: