#[non_exhaustive]pub struct TargetDomainBuilder { /* private fields */ }Expand description
A builder for TargetDomain.
Implementations
Sourceimpl TargetDomainBuilder
impl TargetDomainBuilder
Sourcepub fn target_domain_id(self, input: impl Into<String>) -> Self
pub fn target_domain_id(self, input: impl Into<String>) -> Self
Unique identifier of the target domain This field is required.
Sourcepub fn set_target_domain_id(self, input: Option<String>) -> Self
pub fn set_target_domain_id(self, input: Option<String>) -> Self
Unique identifier of the target domain
Sourcepub fn get_target_domain_id(&self) -> &Option<String>
pub fn get_target_domain_id(&self) -> &Option<String>
Unique identifier of the target domain
Sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
Name of the registered target domain This field is required.
Sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
Name of the registered target domain
Sourcepub fn get_domain_name(&self) -> &Option<String>
pub fn get_domain_name(&self) -> &Option<String>
Name of the registered target domain
Sourcepub fn verification_status(self, input: TargetDomainStatus) -> Self
pub fn verification_status(self, input: TargetDomainStatus) -> Self
Current verification status of the registered target domain
Sourcepub fn set_verification_status(self, input: Option<TargetDomainStatus>) -> Self
pub fn set_verification_status(self, input: Option<TargetDomainStatus>) -> Self
Current verification status of the registered target domain
Sourcepub fn get_verification_status(&self) -> &Option<TargetDomainStatus>
pub fn get_verification_status(&self) -> &Option<TargetDomainStatus>
Current verification status of the registered target domain
Sourcepub fn verification_details(self, input: VerificationDetails) -> Self
pub fn verification_details(self, input: VerificationDetails) -> Self
Verification details to verify registered target domain
Sourcepub fn set_verification_details(
self,
input: Option<VerificationDetails>,
) -> Self
pub fn set_verification_details( self, input: Option<VerificationDetails>, ) -> Self
Verification details to verify registered target domain
Sourcepub fn get_verification_details(&self) -> &Option<VerificationDetails>
pub fn get_verification_details(&self) -> &Option<VerificationDetails>
Verification details to verify registered target domain
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the target domain was registered
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the target domain was registered
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the target domain was registered
Sourcepub fn verified_at(self, input: DateTime) -> Self
pub fn verified_at(self, input: DateTime) -> Self
Timestamp when the target domain was last successfully verified
Sourcepub fn set_verified_at(self, input: Option<DateTime>) -> Self
pub fn set_verified_at(self, input: Option<DateTime>) -> Self
Timestamp when the target domain was last successfully verified
Sourcepub fn get_verified_at(&self) -> &Option<DateTime>
pub fn get_verified_at(&self) -> &Option<DateTime>
Timestamp when the target domain was last successfully verified
Sourcepub fn build(self) -> Result<TargetDomain, BuildError>
pub fn build(self) -> Result<TargetDomain, BuildError>
Consumes the builder and constructs a TargetDomain.
This method will fail if any of the following fields are not set: