#[non_exhaustive]pub struct TargetDomainSummaryBuilder { /* private fields */ }Expand description
A builder for TargetDomainSummary.
Implementations
Sourceimpl TargetDomainSummaryBuilder
impl TargetDomainSummaryBuilder
Sourcepub fn target_domain_id(self, input: impl Into<String>) -> Self
pub fn target_domain_id(self, input: impl Into<String>) -> Self
Unique identifier of the target domain This field is required.
Sourcepub fn set_target_domain_id(self, input: Option<String>) -> Self
pub fn set_target_domain_id(self, input: Option<String>) -> Self
Unique identifier of the target domain
Sourcepub fn get_target_domain_id(&self) -> &Option<String>
pub fn get_target_domain_id(&self) -> &Option<String>
Unique identifier of the target domain
Sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
Name of the registered target domain This field is required.
Sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
Name of the registered target domain
Sourcepub fn get_domain_name(&self) -> &Option<String>
pub fn get_domain_name(&self) -> &Option<String>
Name of the registered target domain
Sourcepub fn verification_status(self, input: TargetDomainStatus) -> Self
pub fn verification_status(self, input: TargetDomainStatus) -> Self
Current verification status of the registered target domain
Sourcepub fn set_verification_status(self, input: Option<TargetDomainStatus>) -> Self
pub fn set_verification_status(self, input: Option<TargetDomainStatus>) -> Self
Current verification status of the registered target domain
Sourcepub fn get_verification_status(&self) -> &Option<TargetDomainStatus>
pub fn get_verification_status(&self) -> &Option<TargetDomainStatus>
Current verification status of the registered target domain
Sourcepub fn build(self) -> Result<TargetDomainSummary, BuildError>
pub fn build(self) -> Result<TargetDomainSummary, BuildError>
Consumes the builder and constructs a TargetDomainSummary.
This method will fail if any of the following fields are not set: