#[non_exhaustive]pub struct TaskBuilder { /* private fields */ }Expand description
A builder for Task.
Implementations
Sourceimpl TaskBuilder
impl TaskBuilder
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
Unique identifier for the task This field is required.
Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
Unique identifier for the task
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
Unique identifier for the task
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
Identifier of the parent pentest
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
Identifier of the parent pentest
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
Identifier of the parent pentest
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
Identifier of the pentest job this task belongs to
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
Identifier of the pentest job this task belongs to
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
Identifier of the pentest job this task belongs to
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Identifier of the agent space this task belongs to
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Identifier of the agent space this task belongs to
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Identifier of the agent space this task belongs to
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Detailed description of the task’s purpose and scope
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Detailed description of the task’s purpose and scope
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Detailed description of the task’s purpose and scope
Sourcepub fn categories(self, input: Category) -> Self
pub fn categories(self, input: Category) -> Self
Appends an item to categories.
To override the contents of this collection use set_categories.
List of categories associated with this task
Sourcepub fn set_categories(self, input: Option<Vec<Category>>) -> Self
pub fn set_categories(self, input: Option<Vec<Category>>) -> Self
List of categories associated with this task
Sourcepub fn get_categories(&self) -> &Option<Vec<Category>>
pub fn get_categories(&self) -> &Option<Vec<Category>>
List of categories associated with this task
Sourcepub fn risk_type(self, input: RiskType) -> Self
pub fn risk_type(self, input: RiskType) -> Self
Type of security risk this task is designed to test
Sourcepub fn set_risk_type(self, input: Option<RiskType>) -> Self
pub fn set_risk_type(self, input: Option<RiskType>) -> Self
Type of security risk this task is designed to test
Sourcepub fn get_risk_type(&self) -> &Option<RiskType>
pub fn get_risk_type(&self) -> &Option<RiskType>
Type of security risk this task is designed to test
Sourcepub fn target_endpoint(self, input: Endpoint) -> Self
pub fn target_endpoint(self, input: Endpoint) -> Self
Target endpoint for this security test
Sourcepub fn set_target_endpoint(self, input: Option<Endpoint>) -> Self
pub fn set_target_endpoint(self, input: Option<Endpoint>) -> Self
Target endpoint for this security test
Sourcepub fn get_target_endpoint(&self) -> &Option<Endpoint>
pub fn get_target_endpoint(&self) -> &Option<Endpoint>
Target endpoint for this security test
Sourcepub fn execution_status(self, input: TaskExecutionStatus) -> Self
pub fn execution_status(self, input: TaskExecutionStatus) -> Self
Current status of the task execution
Sourcepub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
pub fn set_execution_status(self, input: Option<TaskExecutionStatus>) -> Self
Current status of the task execution
Sourcepub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
pub fn get_execution_status(&self) -> &Option<TaskExecutionStatus>
Current status of the task execution
Sourcepub fn logs_location(self, input: LogLocation) -> Self
pub fn logs_location(self, input: LogLocation) -> Self
Location of execution logs for auditing and review
Sourcepub fn set_logs_location(self, input: Option<LogLocation>) -> Self
pub fn set_logs_location(self, input: Option<LogLocation>) -> Self
Location of execution logs for auditing and review
Sourcepub fn get_logs_location(&self) -> &Option<LogLocation>
pub fn get_logs_location(&self) -> &Option<LogLocation>
Location of execution logs for auditing and review
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the task was created
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the task was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the task was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when the task was last updated
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when the task was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when the task was last updated