#[non_exhaustive]pub struct ThreatModelBuilder { /* private fields */ }Expand description
A builder for ThreatModel.
Implementations
Sourceimpl ThreatModelBuilder
impl ThreatModelBuilder
Sourcepub fn threat_model_id(self, input: impl Into<String>) -> Self
pub fn threat_model_id(self, input: impl Into<String>) -> Self
The unique identifier of the threat model.
This field is required.Sourcepub fn set_threat_model_id(self, input: Option<String>) -> Self
pub fn set_threat_model_id(self, input: Option<String>) -> Self
The unique identifier of the threat model.
Sourcepub fn get_threat_model_id(&self) -> &Option<String>
pub fn get_threat_model_id(&self) -> &Option<String>
The unique identifier of the threat model.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space that contains the threat model.
This field is required.Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space that contains the threat model.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space that contains the threat model.
Sourcepub fn title(self, input: impl Into<String>) -> Self
pub fn title(self, input: impl Into<String>) -> Self
The title of the threat model.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the application or system being threat modeled.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the application or system being threat modeled.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the application or system being threat modeled.
Sourcepub fn assets(self, input: Assets) -> Self
pub fn assets(self, input: Assets) -> Self
The assets included in the threat model.
This field is required.Sourcepub fn set_assets(self, input: Option<Assets>) -> Self
pub fn set_assets(self, input: Option<Assets>) -> Self
The assets included in the threat model.
Sourcepub fn get_assets(&self) -> &Option<Assets>
pub fn get_assets(&self) -> &Option<Assets>
The assets included in the threat model.
Sourcepub fn scope_docs(self, input: DocumentInfo) -> Self
pub fn scope_docs(self, input: DocumentInfo) -> Self
Appends an item to scope_docs.
To override the contents of this collection use set_scope_docs.
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn set_scope_docs(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_scope_docs(self, input: Option<Vec<DocumentInfo>>) -> Self
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn get_scope_docs(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_scope_docs(&self) -> &Option<Vec<DocumentInfo>>
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn service_role(self, input: impl Into<String>) -> Self
pub fn service_role(self, input: impl Into<String>) -> Self
The IAM service role used for the threat model.
Sourcepub fn set_service_role(self, input: Option<String>) -> Self
pub fn set_service_role(self, input: Option<String>) -> Self
The IAM service role used for the threat model.
Sourcepub fn get_service_role(&self) -> &Option<String>
pub fn get_service_role(&self) -> &Option<String>
The IAM service role used for the threat model.
Sourcepub fn log_config(self, input: CloudWatchLog) -> Self
pub fn log_config(self, input: CloudWatchLog) -> Self
The CloudWatch Logs configuration for the threat model.
Sourcepub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self
The CloudWatch Logs configuration for the threat model.
Sourcepub fn get_log_config(&self) -> &Option<CloudWatchLog>
pub fn get_log_config(&self) -> &Option<CloudWatchLog>
The CloudWatch Logs configuration for the threat model.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the threat model was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the threat model was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the threat model was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the threat model was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the threat model was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the threat model was last updated, in UTC format.
Sourcepub fn build(self) -> Result<ThreatModel, BuildError>
pub fn build(self) -> Result<ThreatModel, BuildError>
Consumes the builder and constructs a ThreatModel.
This method will fail if any of the following fields are not set: