#[non_exhaustive]pub struct UpdateSecurityRequirementEntryBuilder { /* private fields */ }Expand description
A builder for UpdateSecurityRequirementEntry.
Implementations
Sourceimpl UpdateSecurityRequirementEntryBuilder
impl UpdateSecurityRequirementEntryBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The updated description of the security requirement.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The updated description of the security requirement.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The updated description of the security requirement.
Sourcepub fn domain(self, input: impl Into<String>) -> Self
pub fn domain(self, input: impl Into<String>) -> Self
The updated security domain the requirement belongs to.
Sourcepub fn set_domain(self, input: Option<String>) -> Self
pub fn set_domain(self, input: Option<String>) -> Self
The updated security domain the requirement belongs to.
Sourcepub fn get_domain(&self) -> &Option<String>
pub fn get_domain(&self) -> &Option<String>
The updated security domain the requirement belongs to.
Sourcepub fn evaluation(self, input: impl Into<String>) -> Self
pub fn evaluation(self, input: impl Into<String>) -> Self
The updated evaluation criteria used to assess compliance with this requirement.
Sourcepub fn set_evaluation(self, input: Option<String>) -> Self
pub fn set_evaluation(self, input: Option<String>) -> Self
The updated evaluation criteria used to assess compliance with this requirement.
Sourcepub fn get_evaluation(&self) -> &Option<String>
pub fn get_evaluation(&self) -> &Option<String>
The updated evaluation criteria used to assess compliance with this requirement.
Sourcepub fn remediation(self, input: impl Into<String>) -> Self
pub fn remediation(self, input: impl Into<String>) -> Self
The updated remediation steps when the requirement is not met.
Sourcepub fn set_remediation(self, input: Option<String>) -> Self
pub fn set_remediation(self, input: Option<String>) -> Self
The updated remediation steps when the requirement is not met.
Sourcepub fn get_remediation(&self) -> &Option<String>
pub fn get_remediation(&self) -> &Option<String>
The updated remediation steps when the requirement is not met.
Sourcepub fn build(self) -> Result<UpdateSecurityRequirementEntry, BuildError>
pub fn build(self) -> Result<UpdateSecurityRequirementEntry, BuildError>
Consumes the builder and constructs a UpdateSecurityRequirementEntry.
This method will fail if any of the following fields are not set: