#[non_exhaustive]pub struct VerificationScriptBuilder { /* private fields */ }Expand description
A builder for VerificationScript.
Implementations
Sourceimpl VerificationScriptBuilder
impl VerificationScriptBuilder
Sourcepub fn script_type(self, input: impl Into<String>) -> Self
pub fn script_type(self, input: impl Into<String>) -> Self
The type of script. Valid values are python and bash.
Sourcepub fn set_script_type(self, input: Option<String>) -> Self
pub fn set_script_type(self, input: Option<String>) -> Self
The type of script. Valid values are python and bash.
Sourcepub fn get_script_type(&self) -> &Option<String>
pub fn get_script_type(&self) -> &Option<String>
The type of script. Valid values are python and bash.
Sourcepub fn script_url(self, input: impl Into<String>) -> Self
pub fn script_url(self, input: impl Into<String>) -> Self
URL to download the verification script.
Sourcepub fn set_script_url(self, input: Option<String>) -> Self
pub fn set_script_url(self, input: Option<String>) -> Self
URL to download the verification script.
Sourcepub fn get_script_url(&self) -> &Option<String>
pub fn get_script_url(&self) -> &Option<String>
URL to download the verification script.
Sourcepub fn instructions(self, input: impl Into<String>) -> Self
pub fn instructions(self, input: impl Into<String>) -> Self
Instructions for running the verification script, including prerequisites and how to interpret results.
Sourcepub fn set_instructions(self, input: Option<String>) -> Self
pub fn set_instructions(self, input: Option<String>) -> Self
Instructions for running the verification script, including prerequisites and how to interpret results.
Sourcepub fn get_instructions(&self) -> &Option<String>
pub fn get_instructions(&self) -> &Option<String>
Instructions for running the verification script, including prerequisites and how to interpret results.
Sourcepub fn env_vars(self, input: VerificationScriptEnvVar) -> Self
pub fn env_vars(self, input: VerificationScriptEnvVar) -> Self
Appends an item to env_vars.
To override the contents of this collection use set_env_vars.
The list of environment variables required to run the verification script.
Sourcepub fn set_env_vars(self, input: Option<Vec<VerificationScriptEnvVar>>) -> Self
pub fn set_env_vars(self, input: Option<Vec<VerificationScriptEnvVar>>) -> Self
The list of environment variables required to run the verification script.
Sourcepub fn get_env_vars(&self) -> &Option<Vec<VerificationScriptEnvVar>>
pub fn get_env_vars(&self) -> &Option<Vec<VerificationScriptEnvVar>>
The list of environment variables required to run the verification script.
Sourcepub fn build(self) -> VerificationScript
pub fn build(self) -> VerificationScript
Consumes the builder and constructs a VerificationScript.