#[non_exhaustive]pub enum DiffSource {
S3Uri(String),
#[non_exhaustive] Unknown,
}Expand description
Source of the diff for a differential code scan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
S3Uri(String)
S3 URI pointing to a unified diff file. The file must be in standard unified diff format and stored in an S3 bucket connected to your Agent Space.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl DiffSource
impl DiffSource