#[non_exhaustive]pub enum MembershipConfig {
User(UserConfig),
#[non_exhaustive] Unknown,
}Expand description
Member-specific configuration
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
User(UserConfig)
Configuration for user members
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl MembershipConfig
impl MembershipConfig
Sourcepub fn as_user(&self) -> Result<&UserConfig, &Self>
pub fn as_user(&self) -> Result<&UserConfig, &Self>
Tries to convert the enum instance into User, extracting the inner UserConfig.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.