#[non_exhaustive]pub enum RiskType {
Show 29 variants
ArbitraryFileUpload,
BusinessLogicVulnerabilities,
CodeInjection,
CommandInjection,
CrossSiteScripting,
CryptographicVulnerabilities,
DatabaseAccess,
DatabaseModification,
DefaultCredentials,
DenialOfService,
FileAccess,
FileCreation,
FileDeletion,
GraphqlVulnerabilities,
InformationDisclosure,
InsecureDeserialization,
InsecureDirectObjectReference,
JsonWebTokenVulnerabilities,
LocalFileInclusion,
Other,
OutboundServiceRequest,
PathTraversal,
PrivilegeEscalation,
ServerSideRequestForgery,
ServerSideTemplateInjection,
SqlInjection,
UnknownValue,
XmlExternalEntity,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against RiskType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let risktype = unimplemented!();
match risktype {
RiskType::ArbitraryFileUpload => { /* ... */ },
RiskType::BusinessLogicVulnerabilities => { /* ... */ },
RiskType::CodeInjection => { /* ... */ },
RiskType::CommandInjection => { /* ... */ },
RiskType::CrossSiteScripting => { /* ... */ },
RiskType::CryptographicVulnerabilities => { /* ... */ },
RiskType::DatabaseAccess => { /* ... */ },
RiskType::DatabaseModification => { /* ... */ },
RiskType::DefaultCredentials => { /* ... */ },
RiskType::DenialOfService => { /* ... */ },
RiskType::FileAccess => { /* ... */ },
RiskType::FileCreation => { /* ... */ },
RiskType::FileDeletion => { /* ... */ },
RiskType::GraphqlVulnerabilities => { /* ... */ },
RiskType::InformationDisclosure => { /* ... */ },
RiskType::InsecureDeserialization => { /* ... */ },
RiskType::InsecureDirectObjectReference => { /* ... */ },
RiskType::JsonWebTokenVulnerabilities => { /* ... */ },
RiskType::LocalFileInclusion => { /* ... */ },
RiskType::Other => { /* ... */ },
RiskType::OutboundServiceRequest => { /* ... */ },
RiskType::PathTraversal => { /* ... */ },
RiskType::PrivilegeEscalation => { /* ... */ },
RiskType::ServerSideRequestForgery => { /* ... */ },
RiskType::ServerSideTemplateInjection => { /* ... */ },
RiskType::SqlInjection => { /* ... */ },
RiskType::UnknownValue => { /* ... */ },
RiskType::XmlExternalEntity => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when risktype represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant RiskType::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
RiskType::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant RiskType::NewFeature is defined.
Specifically, when risktype represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on RiskType::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Type of security risk
Note: RiskType::Unknown has been renamed to ::UnknownValue.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ArbitraryFileUpload
Arbitrary file upload vulnerability
BusinessLogicVulnerabilities
Business logic vulnerability
CodeInjection
Code injection vulnerability
CommandInjection
Command injection vulnerability
CrossSiteScripting
Cross-site scripting vulnerability
CryptographicVulnerabilities
Cryptographic vulnerability
DatabaseAccess
Unauthorized database access
DatabaseModification
Unauthorized database modification
DefaultCredentials
Default or weak credentials detected
DenialOfService
Denial of service vulnerability
FileAccess
Unauthorized file access vulnerability
FileCreation
Unauthorized file creation vulnerability
FileDeletion
File deletion vulnerability
GraphqlVulnerabilities
GraphQL-specific vulnerability
InformationDisclosure
Information disclosure vulnerability
InsecureDeserialization
Insecure deserialization vulnerability
InsecureDirectObjectReference
Insecure direct object reference vulnerability
JsonWebTokenVulnerabilities
JSON Web Token vulnerability
LocalFileInclusion
Local file inclusion vulnerability
Other
Other risk type not covered by specific categories
OutboundServiceRequest
Outbound service request vulnerability
PathTraversal
Path traversal vulnerability
PrivilegeEscalation
Privilege escalation vulnerability
ServerSideRequestForgery
Server-side request forgery vulnerability
ServerSideTemplateInjection
Server-side template injection vulnerability
SqlInjection
SQL injection vulnerability
UnknownValue
Unknown risk type
Note: ::Unknown has been renamed to ::UnknownValue.
XmlExternalEntity
XML external entity vulnerability
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations