#[non_exhaustive]pub struct Actor {
pub identifier: Option<String>,
pub uris: Option<Vec<String>>,
pub authentication: Option<Authentication>,
pub description: Option<String>,
}Expand description
Represents an entity that interacts with the system during security testing
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: Option<String>Unique identifier for the actor (case-insensitive)
uris: Option<Vec<String>>List of URIs accessible with the actor’s credentials
authentication: Option<Authentication>Authentication information used by the actor to access resources
description: Option<String>Additional description or details about the actor
Implementations
Sourceimpl Actor
impl Actor
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
Unique identifier for the actor (case-insensitive)
Sourcepub fn uris(&self) -> &[String]
pub fn uris(&self) -> &[String]
List of URIs accessible with the actor’s credentials
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .uris.is_none().
Sourcepub fn authentication(&self) -> Option<&Authentication>
pub fn authentication(&self) -> Option<&Authentication>
Authentication information used by the actor to access resources
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Additional description or details about the actor