#[non_exhaustive]pub struct Assets {
pub endpoints: Option<Vec<Endpoint>>,
pub actors: Option<Vec<Actor>>,
pub documents: Option<Vec<DocumentInfo>>,
pub source_code: Option<Vec<SourceCodeRepository>>,
pub integrated_repositories: Option<Vec<IntegratedRepository>>,
}Expand description
Collection of assets to be tested or used during a pentest
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoints: Option<Vec<Endpoint>>List of web application endpoints to test
actors: Option<Vec<Actor>>List of actors that interact with the system
documents: Option<Vec<DocumentInfo>>List of documents providing context for testing
source_code: Option<Vec<SourceCodeRepository>>List of source code repositories for static analysis
integrated_repositories: Option<Vec<IntegratedRepository>>List of integrated code repositories
Implementations
Sourceimpl Assets
impl Assets
Sourcepub fn endpoints(&self) -> &[Endpoint]
pub fn endpoints(&self) -> &[Endpoint]
List of web application endpoints to test
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .endpoints.is_none().
Sourcepub fn actors(&self) -> &[Actor]
pub fn actors(&self) -> &[Actor]
List of actors that interact with the system
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actors.is_none().
Sourcepub fn documents(&self) -> &[DocumentInfo]
pub fn documents(&self) -> &[DocumentInfo]
List of documents providing context for testing
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .documents.is_none().
Sourcepub fn source_code(&self) -> &[SourceCodeRepository]
pub fn source_code(&self) -> &[SourceCodeRepository]
List of source code repositories for static analysis
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_code.is_none().
Sourcepub fn integrated_repositories(&self) -> &[IntegratedRepository]
pub fn integrated_repositories(&self) -> &[IntegratedRepository]
List of integrated code repositories
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrated_repositories.is_none().