#[non_exhaustive]pub struct AwsResources {
pub vpcs: Option<Vec<VpcConfig>>,
pub log_groups: Option<Vec<String>>,
pub s3_buckets: Option<Vec<String>>,
pub secret_arns: Option<Vec<String>>,
pub lambda_function_arns: Option<Vec<String>>,
pub iam_roles: Option<Vec<String>>,
}Expand description
AWS resource configurations associated with the agent space
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vpcs: Option<Vec<VpcConfig>>VPC configurations that the Security Agent accesses in the customer environment
log_groups: Option<Vec<String>>CloudWatch log group ARNs or names used to store Security Agent logs
s3_buckets: Option<Vec<String>>S3 bucket ARNs or names used to store Security Agent artifacts
secret_arns: Option<Vec<String>>SecretsManager secret ARNs or names used to store tester credentials for pentests
lambda_function_arns: Option<Vec<String>>Lambda function ARNs or names used to retrieve tester credentials for pentests
iam_roles: Option<Vec<String>>IAM role ARNs that the Security Agent can assume to access customer resources
Implementations
Sourceimpl AwsResources
impl AwsResources
Sourcepub fn vpcs(&self) -> &[VpcConfig]
pub fn vpcs(&self) -> &[VpcConfig]
VPC configurations that the Security Agent accesses in the customer environment
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .vpcs.is_none().
Sourcepub fn log_groups(&self) -> &[String]
pub fn log_groups(&self) -> &[String]
CloudWatch log group ARNs or names used to store Security Agent logs
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .log_groups.is_none().
Sourcepub fn s3_buckets(&self) -> &[String]
pub fn s3_buckets(&self) -> &[String]
S3 bucket ARNs or names used to store Security Agent artifacts
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .s3_buckets.is_none().
Sourcepub fn secret_arns(&self) -> &[String]
pub fn secret_arns(&self) -> &[String]
SecretsManager secret ARNs or names used to store tester credentials for pentests
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .secret_arns.is_none().
Sourcepub fn lambda_function_arns(&self) -> &[String]
pub fn lambda_function_arns(&self) -> &[String]
Lambda function ARNs or names used to retrieve tester credentials for pentests
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .lambda_function_arns.is_none().
Sourceimpl AwsResources
impl AwsResources
Sourcepub fn builder() -> AwsResourcesBuilder
pub fn builder() -> AwsResourcesBuilder
Creates a new builder-style object to manufacture AwsResources.