#[non_exhaustive]pub struct BatchCreateSecurityRequirementResult {
pub pack_id: String,
pub name: String,
pub description: String,
pub domain: String,
pub evaluation: String,
pub remediation: Option<String>,
pub created_at: DateTime,
pub updated_at: DateTime,
}Expand description
Contains information about a successfully created security requirement.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pack_id: StringThe unique identifier of the pack containing the security requirement.
name: StringThe name of the security requirement.
description: StringA description of the security requirement.
domain: StringThe security domain the requirement belongs to.
evaluation: StringThe evaluation criteria used to assess compliance with this requirement.
remediation: Option<String>The recommended remediation steps when the requirement is not met.
created_at: DateTimeThe date and time the security requirement was created, in UTC format.
updated_at: DateTimeThe date and time the security requirement was last updated, in UTC format.
Implementations
Sourceimpl BatchCreateSecurityRequirementResult
impl BatchCreateSecurityRequirementResult
Sourcepub fn pack_id(&self) -> &str
pub fn pack_id(&self) -> &str
The unique identifier of the pack containing the security requirement.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A description of the security requirement.
Sourcepub fn evaluation(&self) -> &str
pub fn evaluation(&self) -> &str
The evaluation criteria used to assess compliance with this requirement.
Sourcepub fn remediation(&self) -> Option<&str>
pub fn remediation(&self) -> Option<&str>
The recommended remediation steps when the requirement is not met.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the security requirement was created, in UTC format.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The date and time the security requirement was last updated, in UTC format.
Sourceimpl BatchCreateSecurityRequirementResult
impl BatchCreateSecurityRequirementResult
Sourcepub fn builder() -> BatchCreateSecurityRequirementResultBuilder
pub fn builder() -> BatchCreateSecurityRequirementResultBuilder
Creates a new builder-style object to manufacture BatchCreateSecurityRequirementResult.