#[non_exhaustive]pub struct BatchSecurityRequirementError {
pub security_requirement_name: String,
pub code: String,
pub message: String,
}Expand description
Contains information about an error that occurred for a specific security requirement during a batch operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_requirement_name: StringThe name of the security requirement that caused the error.
code: StringThe error code.
message: StringThe error message.
Implementations
Sourceimpl BatchSecurityRequirementError
impl BatchSecurityRequirementError
Sourcepub fn builder() -> BatchSecurityRequirementErrorBuilder
pub fn builder() -> BatchSecurityRequirementErrorBuilder
Creates a new builder-style object to manufacture BatchSecurityRequirementError.