#[non_exhaustive]pub struct BitbucketIntegrationInput {
pub installation_id: String,
pub workspace: String,
pub code: String,
pub state: String,
}Expand description
The configuration for creating a Bitbucket integration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.installation_id: StringThe Atlassian installation identifier, available from the Atlassian administration console.
workspace: StringThe Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
code: StringThe OAuth 2.0 authorization code returned from the consent redirect.
state: StringThe CSRF state token echoed back from the OAuth redirect.
Implementations
Sourceimpl BitbucketIntegrationInput
impl BitbucketIntegrationInput
Sourcepub fn installation_id(&self) -> &str
pub fn installation_id(&self) -> &str
The Atlassian installation identifier, available from the Atlassian administration console.
Sourcepub fn workspace(&self) -> &str
pub fn workspace(&self) -> &str
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
Sourceimpl BitbucketIntegrationInput
impl BitbucketIntegrationInput
Sourcepub fn builder() -> BitbucketIntegrationInputBuilder
pub fn builder() -> BitbucketIntegrationInputBuilder
Creates a new builder-style object to manufacture BitbucketIntegrationInput.