#[non_exhaustive]pub struct BitbucketResourceCapabilities {
pub leave_comments: Option<bool>,
pub remediate_code: Option<bool>,
}Expand description
Capabilities for an integrated Bitbucket repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.leave_comments: Option<bool>Whether to post code review comments on pull requests.
remediate_code: Option<bool>Whether to create pull requests with automated fixes.
Implementations
Sourceimpl BitbucketResourceCapabilities
impl BitbucketResourceCapabilities
Sourcepub fn leave_comments(&self) -> Option<bool>
pub fn leave_comments(&self) -> Option<bool>
Whether to post code review comments on pull requests.
Sourcepub fn remediate_code(&self) -> Option<bool>
pub fn remediate_code(&self) -> Option<bool>
Whether to create pull requests with automated fixes.
Sourceimpl BitbucketResourceCapabilities
impl BitbucketResourceCapabilities
Sourcepub fn builder() -> BitbucketResourceCapabilitiesBuilder
pub fn builder() -> BitbucketResourceCapabilitiesBuilder
Creates a new builder-style object to manufacture BitbucketResourceCapabilities.