#[non_exhaustive]pub struct CodeReview {
pub code_review_id: String,
pub agent_space_id: String,
pub title: String,
pub assets: Option<Assets>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a code review configuration that defines the parameters for automated security-focused code analysis, including target assets and logging configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_id: StringThe unique identifier of the code review.
agent_space_id: StringThe unique identifier of the agent space that contains the code review.
title: StringThe title of the code review.
assets: Option<Assets>The assets included in the code review.
service_role: Option<String>The IAM service role used for the code review.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the code review.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the code review.
created_at: Option<DateTime>The date and time the code review was created, in UTC format.
updated_at: Option<DateTime>The date and time the code review was last updated, in UTC format.
Implementations
Sourceimpl CodeReview
impl CodeReview
Sourcepub fn code_review_id(&self) -> &str
pub fn code_review_id(&self) -> &str
The unique identifier of the code review.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the agent space that contains the code review.
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the code review.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the code review.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the code review.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the code review was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the code review was last updated, in UTC format.
Sourceimpl CodeReview
impl CodeReview
Sourcepub fn builder() -> CodeReviewBuilder
pub fn builder() -> CodeReviewBuilder
Creates a new builder-style object to manufacture CodeReview.