#[non_exhaustive]pub struct CodeReviewJob {Show 16 fields
pub code_review_job_id: Option<String>,
pub code_review_id: Option<String>,
pub title: Option<String>,
pub overview: Option<String>,
pub status: Option<JobStatus>,
pub documents: Option<Vec<DocumentInfo>>,
pub source_code: Option<Vec<SourceCodeRepository>>,
pub steps: Option<Vec<Step>>,
pub execution_context: Option<Vec<ExecutionContext>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub error_information: Option<ErrorInformation>,
pub integrated_repositories: Option<Vec<IntegratedRepository>>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a code review job, which is an execution instance of a code review. A code review job progresses through preflight, static analysis, and finalizing steps.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_job_id: Option<String>The unique identifier of the code review job.
code_review_id: Option<String>The unique identifier of the code review associated with the job.
title: Option<String>The title of the code review job.
overview: Option<String>An overview of the code review job results.
status: Option<JobStatus>The current status of the code review job.
documents: Option<Vec<DocumentInfo>>The list of documents providing context for the code review job.
source_code: Option<Vec<SourceCodeRepository>>The list of source code repositories analyzed during the code review job.
steps: Option<Vec<Step>>The list of steps in the code review job execution.
execution_context: Option<Vec<ExecutionContext>>The execution context messages for the code review job.
service_role: Option<String>The IAM service role used for the code review job.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the code review job.
error_information: Option<ErrorInformation>Error information if the code review job encountered an error.
integrated_repositories: Option<Vec<IntegratedRepository>>The list of integrated repositories associated with the code review job.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the code review job.
created_at: Option<DateTime>The date and time the code review job was created, in UTC format.
updated_at: Option<DateTime>The date and time the code review job was last updated, in UTC format.
Implementations
Sourceimpl CodeReviewJob
impl CodeReviewJob
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job.
Sourcepub fn code_review_id(&self) -> Option<&str>
pub fn code_review_id(&self) -> Option<&str>
The unique identifier of the code review associated with the job.
Sourcepub fn documents(&self) -> &[DocumentInfo]
pub fn documents(&self) -> &[DocumentInfo]
The list of documents providing context for the code review job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .documents.is_none().
Sourcepub fn source_code(&self) -> &[SourceCodeRepository]
pub fn source_code(&self) -> &[SourceCodeRepository]
The list of source code repositories analyzed during the code review job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_code.is_none().
Sourcepub fn steps(&self) -> &[Step]
pub fn steps(&self) -> &[Step]
The list of steps in the code review job execution.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .steps.is_none().
Sourcepub fn execution_context(&self) -> &[ExecutionContext]
pub fn execution_context(&self) -> &[ExecutionContext]
The execution context messages for the code review job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .execution_context.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the code review job.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the code review job.
Sourcepub fn error_information(&self) -> Option<&ErrorInformation>
pub fn error_information(&self) -> Option<&ErrorInformation>
Error information if the code review job encountered an error.
Sourcepub fn integrated_repositories(&self) -> &[IntegratedRepository]
pub fn integrated_repositories(&self) -> &[IntegratedRepository]
The list of integrated repositories associated with the code review job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrated_repositories.is_none().
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the code review job.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the code review job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the code review job was last updated, in UTC format.
Sourceimpl CodeReviewJob
impl CodeReviewJob
Sourcepub fn builder() -> CodeReviewJobBuilder
pub fn builder() -> CodeReviewJobBuilder
Creates a new builder-style object to manufacture CodeReviewJob.