#[non_exhaustive]pub struct CodeReviewJobSummary {
pub code_review_job_id: String,
pub code_review_id: String,
pub title: Option<String>,
pub status: Option<JobStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a code review job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_review_job_id: StringThe unique identifier of the code review job.
code_review_id: StringThe unique identifier of the code review associated with the job.
title: Option<String>The title of the code review job.
status: Option<JobStatus>The current status of the code review job.
created_at: Option<DateTime>The date and time the code review job was created, in UTC format.
updated_at: Option<DateTime>The date and time the code review job was last updated, in UTC format.
Implementations
Sourceimpl CodeReviewJobSummary
impl CodeReviewJobSummary
Sourcepub fn code_review_job_id(&self) -> &str
pub fn code_review_job_id(&self) -> &str
The unique identifier of the code review job.
Sourcepub fn code_review_id(&self) -> &str
pub fn code_review_id(&self) -> &str
The unique identifier of the code review associated with the job.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the code review job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the code review job was last updated, in UTC format.
Sourceimpl CodeReviewJobSummary
impl CodeReviewJobSummary
Sourcepub fn builder() -> CodeReviewJobSummaryBuilder
pub fn builder() -> CodeReviewJobSummaryBuilder
Creates a new builder-style object to manufacture CodeReviewJobSummary.