#[non_exhaustive]pub struct CodeReviewJobTask {
pub task_id: String,
pub code_review_id: Option<String>,
pub code_review_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub categories: Option<Vec<Category>>,
pub risk_type: Option<RiskType>,
pub execution_status: Option<TaskExecutionStatus>,
pub logs_location: Option<LogLocation>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents an individual security test task within a code review job. Each task targets a specific risk type and executes independently.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringThe unique identifier of the task.
code_review_id: Option<String>The unique identifier of the code review associated with the task.
code_review_job_id: Option<String>The unique identifier of the code review job that contains the task.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the task.
description: Option<String>A description of the task.
categories: Option<Vec<Category>>The list of categories assigned to the task.
risk_type: Option<RiskType>The type of security risk the task is testing for.
execution_status: Option<TaskExecutionStatus>The current execution status of the task.
logs_location: Option<LogLocation>The location of the task execution logs.
created_at: Option<DateTime>The date and time the task was created, in UTC format.
updated_at: Option<DateTime>The date and time the task was last updated, in UTC format.
Implementations
Sourceimpl CodeReviewJobTask
impl CodeReviewJobTask
Sourcepub fn code_review_id(&self) -> Option<&str>
pub fn code_review_id(&self) -> Option<&str>
The unique identifier of the code review associated with the task.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job that contains the task.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the task.
Sourcepub fn categories(&self) -> &[Category]
pub fn categories(&self) -> &[Category]
The list of categories assigned to the task.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .categories.is_none().
Sourcepub fn risk_type(&self) -> Option<&RiskType>
pub fn risk_type(&self) -> Option<&RiskType>
The type of security risk the task is testing for.
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn logs_location(&self) -> Option<&LogLocation>
pub fn logs_location(&self) -> Option<&LogLocation>
The location of the task execution logs.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the task was last updated, in UTC format.
Sourceimpl CodeReviewJobTask
impl CodeReviewJobTask
Sourcepub fn builder() -> CodeReviewJobTaskBuilder
pub fn builder() -> CodeReviewJobTaskBuilder
Creates a new builder-style object to manufacture CodeReviewJobTask.