#[non_exhaustive]pub struct CodeReviewJobTaskSummary {
pub task_id: String,
pub code_review_id: Option<String>,
pub code_review_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub risk_type: Option<RiskType>,
pub execution_status: Option<TaskExecutionStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a code review job task.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringThe unique identifier of the task.
code_review_id: Option<String>The unique identifier of the code review associated with the task.
code_review_job_id: Option<String>The unique identifier of the code review job that contains the task.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the task.
risk_type: Option<RiskType>The type of security risk the task is testing for.
execution_status: Option<TaskExecutionStatus>The current execution status of the task.
created_at: Option<DateTime>The date and time the task was created, in UTC format.
updated_at: Option<DateTime>The date and time the task was last updated, in UTC format.
Implementations
Sourceimpl CodeReviewJobTaskSummary
impl CodeReviewJobTaskSummary
Sourcepub fn code_review_id(&self) -> Option<&str>
pub fn code_review_id(&self) -> Option<&str>
The unique identifier of the code review associated with the task.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job that contains the task.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn risk_type(&self) -> Option<&RiskType>
pub fn risk_type(&self) -> Option<&RiskType>
The type of security risk the task is testing for.
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the task was last updated, in UTC format.
Sourceimpl CodeReviewJobTaskSummary
impl CodeReviewJobTaskSummary
Sourcepub fn builder() -> CodeReviewJobTaskSummaryBuilder
pub fn builder() -> CodeReviewJobTaskSummaryBuilder
Creates a new builder-style object to manufacture CodeReviewJobTaskSummary.