#[non_exhaustive]pub struct CreateSecurityRequirementEntry {
pub name: String,
pub description: String,
pub domain: String,
pub evaluation: String,
pub remediation: Option<String>,
}Expand description
Contains the details for a security requirement to create within a pack.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the security requirement.
description: StringA description of the security requirement.
domain: StringThe security domain the requirement belongs to.
evaluation: StringThe evaluation criteria used to assess compliance with this requirement.
remediation: Option<String>The recommended remediation steps when the requirement is not met.
Implementations
Sourceimpl CreateSecurityRequirementEntry
impl CreateSecurityRequirementEntry
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A description of the security requirement.
Sourcepub fn evaluation(&self) -> &str
pub fn evaluation(&self) -> &str
The evaluation criteria used to assess compliance with this requirement.
Sourcepub fn remediation(&self) -> Option<&str>
pub fn remediation(&self) -> Option<&str>
The recommended remediation steps when the requirement is not met.
Sourceimpl CreateSecurityRequirementEntry
impl CreateSecurityRequirementEntry
Sourcepub fn builder() -> CreateSecurityRequirementEntryBuilder
pub fn builder() -> CreateSecurityRequirementEntryBuilder
Creates a new builder-style object to manufacture CreateSecurityRequirementEntry.