#[non_exhaustive]pub struct DeleteThreatModelFailure {
pub threat_model_id: Option<String>,
pub reason: Option<String>,
}Expand description
Contains information about a threat model that failed to delete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_id: Option<String>The unique identifier of the threat model that failed to delete.
reason: Option<String>The reason the threat model failed to delete.
Implementations
Sourceimpl DeleteThreatModelFailure
impl DeleteThreatModelFailure
Sourcepub fn builder() -> DeleteThreatModelFailureBuilder
pub fn builder() -> DeleteThreatModelFailureBuilder
Creates a new builder-style object to manufacture DeleteThreatModelFailure.