#[non_exhaustive]pub struct DiscoveredEndpoint {
pub uri: String,
pub pentest_job_id: String,
pub task_id: String,
pub agent_space_id: String,
pub evidence: Option<String>,
pub operation: Option<String>,
pub description: Option<String>,
}Expand description
Represents an endpoint discovered during a pentest job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe URI of the discovered endpoint.
pentest_job_id: StringThe unique identifier of the pentest job that discovered the endpoint.
task_id: StringThe unique identifier of the task that discovered the endpoint.
agent_space_id: StringThe unique identifier of the agent space associated with the discovered endpoint.
evidence: Option<String>The evidence that led to the discovery of the endpoint.
operation: Option<String>The HTTP operation associated with the discovered endpoint.
description: Option<String>A description of the discovered endpoint.
Implementations
Sourceimpl DiscoveredEndpoint
impl DiscoveredEndpoint
Sourcepub fn pentest_job_id(&self) -> &str
pub fn pentest_job_id(&self) -> &str
The unique identifier of the pentest job that discovered the endpoint.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the agent space associated with the discovered endpoint.
Sourcepub fn operation(&self) -> Option<&str>
pub fn operation(&self) -> Option<&str>
The HTTP operation associated with the discovered endpoint.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the discovered endpoint.
Sourceimpl DiscoveredEndpoint
impl DiscoveredEndpoint
Sourcepub fn builder() -> DiscoveredEndpointBuilder
pub fn builder() -> DiscoveredEndpointBuilder
Creates a new builder-style object to manufacture DiscoveredEndpoint.