#[non_exhaustive]pub struct FindingSummary {Show 13 fields
pub finding_id: String,
pub agent_space_id: String,
pub pentest_id: Option<String>,
pub pentest_job_id: Option<String>,
pub code_review_id: Option<String>,
pub code_review_job_id: Option<String>,
pub name: Option<String>,
pub status: Option<FindingStatus>,
pub risk_type: Option<String>,
pub risk_level: Option<RiskLevel>,
pub confidence: Option<ConfidenceLevel>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a security finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding_id: StringThe unique identifier of the finding.
agent_space_id: StringThe unique identifier of the agent space associated with the finding.
pentest_id: Option<String>The unique identifier of the pentest associated with the finding.
pentest_job_id: Option<String>The unique identifier of the pentest job that produced the finding.
code_review_id: Option<String>The unique identifier of the code review associated with the finding.
code_review_job_id: Option<String>The unique identifier of the code review job that produced the finding.
name: Option<String>The name of the finding.
status: Option<FindingStatus>The current status of the finding.
risk_type: Option<String>The type of security risk identified by the finding.
risk_level: Option<RiskLevel>The risk level of the finding.
confidence: Option<ConfidenceLevel>The confidence level of the finding.
created_at: Option<DateTime>The date and time the finding was created, in UTC format.
updated_at: Option<DateTime>The date and time the finding was last updated, in UTC format.
Implementations
Sourceimpl FindingSummary
impl FindingSummary
Sourcepub fn finding_id(&self) -> &str
pub fn finding_id(&self) -> &str
The unique identifier of the finding.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the agent space associated with the finding.
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
The unique identifier of the pentest associated with the finding.
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
The unique identifier of the pentest job that produced the finding.
Sourcepub fn code_review_id(&self) -> Option<&str>
pub fn code_review_id(&self) -> Option<&str>
The unique identifier of the code review associated with the finding.
Sourcepub fn code_review_job_id(&self) -> Option<&str>
pub fn code_review_job_id(&self) -> Option<&str>
The unique identifier of the code review job that produced the finding.
Sourcepub fn status(&self) -> Option<&FindingStatus>
pub fn status(&self) -> Option<&FindingStatus>
The current status of the finding.
Sourcepub fn risk_level(&self) -> Option<&RiskLevel>
pub fn risk_level(&self) -> Option<&RiskLevel>
The risk level of the finding.
Sourcepub fn confidence(&self) -> Option<&ConfidenceLevel>
pub fn confidence(&self) -> Option<&ConfidenceLevel>
The confidence level of the finding.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the finding was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the finding was last updated, in UTC format.
Sourceimpl FindingSummary
impl FindingSummary
Sourcepub fn builder() -> FindingSummaryBuilder
pub fn builder() -> FindingSummaryBuilder
Creates a new builder-style object to manufacture FindingSummary.