#[non_exhaustive]pub struct GitLabIntegrationInput {
pub access_token: String,
pub target_url: Option<String>,
pub token_type: GitLabTokenType,
pub group_id: Option<String>,
}Expand description
The configuration for creating a GitLab integration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_token: StringThe GitLab access token used to authenticate. This can be a personal access token or a group access token.
target_url: Option<String>The HTTPS URL of a self-managed GitLab instance. Omit this value for GitLab SaaS (gitlab.com).
token_type: GitLabTokenTypeThe type of GitLab access token provided in accessToken.
group_id: Option<String>The identifier of the GitLab group. Required when tokenType is group and ignored for personal tokens.
Implementations
Sourceimpl GitLabIntegrationInput
impl GitLabIntegrationInput
Sourcepub fn access_token(&self) -> &str
pub fn access_token(&self) -> &str
The GitLab access token used to authenticate. This can be a personal access token or a group access token.
Sourcepub fn target_url(&self) -> Option<&str>
pub fn target_url(&self) -> Option<&str>
The HTTPS URL of a self-managed GitLab instance. Omit this value for GitLab SaaS (gitlab.com).
Sourcepub fn token_type(&self) -> &GitLabTokenType
pub fn token_type(&self) -> &GitLabTokenType
The type of GitLab access token provided in accessToken.
Sourceimpl GitLabIntegrationInput
impl GitLabIntegrationInput
Sourcepub fn builder() -> GitLabIntegrationInputBuilder
pub fn builder() -> GitLabIntegrationInputBuilder
Creates a new builder-style object to manufacture GitLabIntegrationInput.