#[non_exhaustive]pub struct IntegratedDocument {
pub integration_id: String,
pub resource_id: String,
}Expand description
A reference to a document in a third-party provider, such as a Confluence page linked via an integration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_id: StringThe identifier of the integration that provides access to the document.
resource_id: StringThe provider-specific resource identifier for the document.
Implementations
Sourceimpl IntegratedDocument
impl IntegratedDocument
Sourcepub fn integration_id(&self) -> &str
pub fn integration_id(&self) -> &str
The identifier of the integration that provides access to the document.
Sourcepub fn resource_id(&self) -> &str
pub fn resource_id(&self) -> &str
The provider-specific resource identifier for the document.
Sourceimpl IntegratedDocument
impl IntegratedDocument
Sourcepub fn builder() -> IntegratedDocumentBuilder
pub fn builder() -> IntegratedDocumentBuilder
Creates a new builder-style object to manufacture IntegratedDocument.