#[non_exhaustive]pub struct Pentest {
pub pentest_id: String,
pub agent_space_id: String,
pub title: String,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: StringThe unique identifier of the pentest.
agent_space_id: StringThe unique identifier of the agent space that contains the pentest.
title: StringThe title of the pentest.
assets: Option<Assets>The assets included in the pentest.
exclude_risk_types: Option<Vec<RiskType>>The list of risk types excluded from the pentest.
service_role: Option<String>The IAM service role used for the pentest.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the pentest.
vpc_config: Option<VpcConfig>The VPC configuration for the pentest.
network_traffic_config: Option<NetworkTrafficConfig>The network traffic configuration for the pentest.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the pentest.
created_at: Option<DateTime>The date and time the pentest was created, in UTC format.
updated_at: Option<DateTime>The date and time the pentest was last updated, in UTC format.
Implementations
Sourceimpl Pentest
impl Pentest
Sourcepub fn pentest_id(&self) -> &str
pub fn pentest_id(&self) -> &str
The unique identifier of the pentest.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the agent space that contains the pentest.
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
The list of risk types excluded from the pentest.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the pentest.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the pentest.
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
The VPC configuration for the pentest.
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
The network traffic configuration for the pentest.
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the pentest.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the pentest was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the pentest was last updated, in UTC format.