#[non_exhaustive]pub struct PentestJob {Show 23 fields
pub pentest_job_id: Option<String>,
pub pentest_id: Option<String>,
pub title: Option<String>,
pub overview: Option<String>,
pub status: Option<JobStatus>,
pub endpoints: Option<Vec<Endpoint>>,
pub actors: Option<Vec<Actor>>,
pub documents: Option<Vec<DocumentInfo>>,
pub source_code: Option<Vec<SourceCodeRepository>>,
pub exclude_paths: Option<Vec<Endpoint>>,
pub allowed_domains: Option<Vec<Endpoint>>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub steps: Option<Vec<Step>>,
pub execution_context: Option<Vec<ExecutionContext>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub error_information: Option<ErrorInformation>,
pub integrated_repositories: Option<Vec<IntegratedRepository>>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a pentest job, which is an execution instance of a pentest. A pentest job progresses through preflight, static analysis, pentest, and finalizing steps.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_job_id: Option<String>The unique identifier of the pentest job.
pentest_id: Option<String>The unique identifier of the pentest associated with the job.
title: Option<String>The title of the pentest job.
overview: Option<String>An overview of the pentest job results.
status: Option<JobStatus>The current status of the pentest job.
endpoints: Option<Vec<Endpoint>>The list of endpoints being tested in the pentest job.
actors: Option<Vec<Actor>>The list of actors used during the pentest job.
documents: Option<Vec<DocumentInfo>>The list of documents providing context for the pentest job.
source_code: Option<Vec<SourceCodeRepository>>The list of source code repositories analyzed during the pentest job.
exclude_paths: Option<Vec<Endpoint>>The list of paths excluded from the pentest job.
allowed_domains: Option<Vec<Endpoint>>The list of domains allowed during the pentest job.
exclude_risk_types: Option<Vec<RiskType>>The list of risk types excluded from the pentest job.
steps: Option<Vec<Step>>The list of steps in the pentest job execution.
execution_context: Option<Vec<ExecutionContext>>The execution context messages for the pentest job.
service_role: Option<String>The IAM service role used for the pentest job.
log_config: Option<CloudWatchLog>The CloudWatch Logs configuration for the pentest job.
vpc_config: Option<VpcConfig>The VPC configuration for the pentest job.
network_traffic_config: Option<NetworkTrafficConfig>The network traffic configuration for the pentest job.
error_information: Option<ErrorInformation>Error information if the pentest job encountered an error.
integrated_repositories: Option<Vec<IntegratedRepository>>The list of integrated repositories associated with the pentest job.
code_remediation_strategy: Option<CodeRemediationStrategy>The code remediation strategy for the pentest job.
created_at: Option<DateTime>The date and time the pentest job was created, in UTC format.
updated_at: Option<DateTime>The date and time the pentest job was last updated, in UTC format.
Implementations
Sourceimpl PentestJob
impl PentestJob
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
The unique identifier of the pentest job.
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
The unique identifier of the pentest associated with the job.
Sourcepub fn endpoints(&self) -> &[Endpoint]
pub fn endpoints(&self) -> &[Endpoint]
The list of endpoints being tested in the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .endpoints.is_none().
Sourcepub fn actors(&self) -> &[Actor]
pub fn actors(&self) -> &[Actor]
The list of actors used during the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actors.is_none().
Sourcepub fn documents(&self) -> &[DocumentInfo]
pub fn documents(&self) -> &[DocumentInfo]
The list of documents providing context for the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .documents.is_none().
Sourcepub fn source_code(&self) -> &[SourceCodeRepository]
pub fn source_code(&self) -> &[SourceCodeRepository]
The list of source code repositories analyzed during the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_code.is_none().
Sourcepub fn exclude_paths(&self) -> &[Endpoint]
pub fn exclude_paths(&self) -> &[Endpoint]
The list of paths excluded from the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_paths.is_none().
Sourcepub fn allowed_domains(&self) -> &[Endpoint]
pub fn allowed_domains(&self) -> &[Endpoint]
The list of domains allowed during the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_domains.is_none().
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
The list of risk types excluded from the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn steps(&self) -> &[Step]
pub fn steps(&self) -> &[Step]
The list of steps in the pentest job execution.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .steps.is_none().
Sourcepub fn execution_context(&self) -> &[ExecutionContext]
pub fn execution_context(&self) -> &[ExecutionContext]
The execution context messages for the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .execution_context.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
The IAM service role used for the pentest job.
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
The CloudWatch Logs configuration for the pentest job.
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
The VPC configuration for the pentest job.
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
The network traffic configuration for the pentest job.
Sourcepub fn error_information(&self) -> Option<&ErrorInformation>
pub fn error_information(&self) -> Option<&ErrorInformation>
Error information if the pentest job encountered an error.
Sourcepub fn integrated_repositories(&self) -> &[IntegratedRepository]
pub fn integrated_repositories(&self) -> &[IntegratedRepository]
The list of integrated repositories associated with the pentest job.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrated_repositories.is_none().
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
The code remediation strategy for the pentest job.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the pentest job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the pentest job was last updated, in UTC format.
Sourceimpl PentestJob
impl PentestJob
Sourcepub fn builder() -> PentestJobBuilder
pub fn builder() -> PentestJobBuilder
Creates a new builder-style object to manufacture PentestJob.