#[non_exhaustive]pub struct PentestSummary {
pub pentest_id: String,
pub agent_space_id: String,
pub title: String,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Summary information for a pentest
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: StringUnique identifier for the pentest
agent_space_id: StringID of the agent space where the pentest exists
title: StringTitle or name of the pentest
created_at: Option<DateTime>Timestamp when the pentest was created
updated_at: Option<DateTime>Timestamp when the pentest was last updated
Implementations
Sourceimpl PentestSummary
impl PentestSummary
Sourcepub fn pentest_id(&self) -> &str
pub fn pentest_id(&self) -> &str
Unique identifier for the pentest
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
ID of the agent space where the pentest exists
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the pentest was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the pentest was last updated
Sourceimpl PentestSummary
impl PentestSummary
Sourcepub fn builder() -> PentestSummaryBuilder
pub fn builder() -> PentestSummaryBuilder
Creates a new builder-style object to manufacture PentestSummary.