#[non_exhaustive]pub struct PrivateConnectionSummary {
pub name: String,
pub type: PrivateConnectionType,
pub status: PrivateConnectionStatus,
pub resource_gateway_id: Option<String>,
pub host_address: Option<String>,
pub vpc_id: Option<String>,
pub resource_configuration_id: Option<String>,
pub certificate_expiry_time: Option<DateTime>,
pub dns_resolution: Option<ResourceConfigDnsResolution>,
pub failure_message: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Summarizes a private connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the private connection.
type: PrivateConnectionTypeThe type of the private connection, indicating whether it is service-managed or self-managed.
status: PrivateConnectionStatusThe current status of the private connection.
resource_gateway_id: Option<String>The identifier or ARN of the VPC Lattice resource gateway.
host_address: Option<String>The IP address or DNS name of the target resource.
vpc_id: Option<String>The identifier of the VPC the resource gateway is created in.
resource_configuration_id: Option<String>The identifier or ARN of the VPC Lattice resource configuration.
certificate_expiry_time: Option<DateTime>The date and time the connection's certificate expires, in UTC format.
dns_resolution: Option<ResourceConfigDnsResolution>The DNS resolution mode for the resource gateway.
failure_message: Option<String>A message describing why the private connection entered a failed state, if applicable.
The tags attached to the private connection.
Implementations
Sourceimpl PrivateConnectionSummary
impl PrivateConnectionSummary
Sourcepub fn type(&self) -> &PrivateConnectionType
pub fn type(&self) -> &PrivateConnectionType
The type of the private connection, indicating whether it is service-managed or self-managed.
Sourcepub fn status(&self) -> &PrivateConnectionStatus
pub fn status(&self) -> &PrivateConnectionStatus
The current status of the private connection.
Sourcepub fn resource_gateway_id(&self) -> Option<&str>
pub fn resource_gateway_id(&self) -> Option<&str>
The identifier or ARN of the VPC Lattice resource gateway.
Sourcepub fn host_address(&self) -> Option<&str>
pub fn host_address(&self) -> Option<&str>
The IP address or DNS name of the target resource.
Sourcepub fn vpc_id(&self) -> Option<&str>
pub fn vpc_id(&self) -> Option<&str>
The identifier of the VPC the resource gateway is created in.
Sourcepub fn resource_configuration_id(&self) -> Option<&str>
pub fn resource_configuration_id(&self) -> Option<&str>
The identifier or ARN of the VPC Lattice resource configuration.
Sourcepub fn certificate_expiry_time(&self) -> Option<&DateTime>
pub fn certificate_expiry_time(&self) -> Option<&DateTime>
The date and time the connection's certificate expires, in UTC format.
Sourcepub fn dns_resolution(&self) -> Option<&ResourceConfigDnsResolution>
pub fn dns_resolution(&self) -> Option<&ResourceConfigDnsResolution>
The DNS resolution mode for the resource gateway.
Sourcepub fn failure_message(&self) -> Option<&str>
pub fn failure_message(&self) -> Option<&str>
A message describing why the private connection entered a failed state, if applicable.
The tags attached to the private connection.
Sourceimpl PrivateConnectionSummary
impl PrivateConnectionSummary
Sourcepub fn builder() -> PrivateConnectionSummaryBuilder
pub fn builder() -> PrivateConnectionSummaryBuilder
Creates a new builder-style object to manufacture PrivateConnectionSummary.