#[non_exhaustive]pub struct ServiceManagedInput {
pub host_address: String,
pub vpc_id: String,
pub subnet_ids: Vec<String>,
pub security_group_ids: Option<Vec<String>>,
pub ip_address_type: Option<IpAddressType>,
pub ipv4_addresses_per_eni: Option<i32>,
pub port_ranges: Option<Vec<String>>,
pub certificate: Option<String>,
pub dns_resolution: Option<ResourceConfigDnsResolution>,
}Expand description
The configuration for a service-managed private connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.host_address: StringThe IP address or DNS name of the target resource.
vpc_id: StringThe VPC to create the service-managed resource gateway in.
subnet_ids: Vec<String>The subnets that the service-managed resource gateway spans.
security_group_ids: Option<Vec<String>>The security groups to attach to the service-managed resource gateway.
ip_address_type: Option<IpAddressType>The IP address type of the service-managed resource gateway.
ipv4_addresses_per_eni: Option<i32>The number of IPv4 addresses in each elastic network interface for the service-managed resource gateway.
port_ranges: Option<Vec<String>>The TCP port ranges that a consumer can use to access the resource.
certificate: Option<String>The certificate for the private connection.
dns_resolution: Option<ResourceConfigDnsResolution>The DNS resolution mode for the resource gateway. Defaults to PUBLIC when not set.
Implementations
Sourceimpl ServiceManagedInput
impl ServiceManagedInput
Sourcepub fn host_address(&self) -> &str
pub fn host_address(&self) -> &str
The IP address or DNS name of the target resource.
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
The subnets that the service-managed resource gateway spans.
Sourcepub fn security_group_ids(&self) -> &[String]
pub fn security_group_ids(&self) -> &[String]
The security groups to attach to the service-managed resource gateway.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_ids.is_none().
Sourcepub fn ip_address_type(&self) -> Option<&IpAddressType>
pub fn ip_address_type(&self) -> Option<&IpAddressType>
The IP address type of the service-managed resource gateway.
Sourcepub fn ipv4_addresses_per_eni(&self) -> Option<i32>
pub fn ipv4_addresses_per_eni(&self) -> Option<i32>
The number of IPv4 addresses in each elastic network interface for the service-managed resource gateway.
Sourcepub fn port_ranges(&self) -> &[String]
pub fn port_ranges(&self) -> &[String]
The TCP port ranges that a consumer can use to access the resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .port_ranges.is_none().
Sourcepub fn certificate(&self) -> Option<&str>
pub fn certificate(&self) -> Option<&str>
The certificate for the private connection.
Sourcepub fn dns_resolution(&self) -> Option<&ResourceConfigDnsResolution>
pub fn dns_resolution(&self) -> Option<&ResourceConfigDnsResolution>
The DNS resolution mode for the resource gateway. Defaults to PUBLIC when not set.
Sourceimpl ServiceManagedInput
impl ServiceManagedInput
Sourcepub fn builder() -> ServiceManagedInputBuilder
pub fn builder() -> ServiceManagedInputBuilder
Creates a new builder-style object to manufacture ServiceManagedInput.