#[non_exhaustive]pub struct TargetDomain {
pub target_domain_id: String,
pub domain_name: String,
pub verification_status: Option<TargetDomainStatus>,
pub verification_status_reason: Option<String>,
pub verification_details: Option<VerificationDetails>,
pub created_at: Option<DateTime>,
pub verified_at: Option<DateTime>,
}Expand description
Represents a target domain registered for penetration testing. A target domain must be verified through DNS TXT or HTTP route verification before it can be used in pentests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_domain_id: StringThe unique identifier of the target domain.
domain_name: StringThe domain name of the target domain.
verification_status: Option<TargetDomainStatus>The current verification status of the target domain.
verification_status_reason: Option<String>The reason for the current target domain verification status.
verification_details: Option<VerificationDetails>The verification details for the target domain.
created_at: Option<DateTime>The date and time the target domain was created, in UTC format.
verified_at: Option<DateTime>The date and time the target domain was verified, in UTC format.
Implementations
Sourceimpl TargetDomain
impl TargetDomain
Sourcepub fn target_domain_id(&self) -> &str
pub fn target_domain_id(&self) -> &str
The unique identifier of the target domain.
Sourcepub fn domain_name(&self) -> &str
pub fn domain_name(&self) -> &str
The domain name of the target domain.
Sourcepub fn verification_status(&self) -> Option<&TargetDomainStatus>
pub fn verification_status(&self) -> Option<&TargetDomainStatus>
The current verification status of the target domain.
Sourcepub fn verification_status_reason(&self) -> Option<&str>
pub fn verification_status_reason(&self) -> Option<&str>
The reason for the current target domain verification status.
Sourcepub fn verification_details(&self) -> Option<&VerificationDetails>
pub fn verification_details(&self) -> Option<&VerificationDetails>
The verification details for the target domain.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the target domain was created, in UTC format.
Sourcepub fn verified_at(&self) -> Option<&DateTime>
pub fn verified_at(&self) -> Option<&DateTime>
The date and time the target domain was verified, in UTC format.
Sourceimpl TargetDomain
impl TargetDomain
Sourcepub fn builder() -> TargetDomainBuilder
pub fn builder() -> TargetDomainBuilder
Creates a new builder-style object to manufacture TargetDomain.