#[non_exhaustive]pub struct Task {Show 13 fields
pub task_id: String,
pub pentest_id: Option<String>,
pub pentest_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub categories: Option<Vec<Category>>,
pub risk_type: Option<RiskType>,
pub target_endpoint: Option<Endpoint>,
pub execution_status: Option<TaskExecutionStatus>,
pub logs_location: Option<LogLocation>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a task within a pentest job
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringUnique identifier for the task
pentest_id: Option<String>Identifier of the parent pentest
pentest_job_id: Option<String>Identifier of the pentest job this task belongs to
agent_space_id: Option<String>Identifier of the agent space this task belongs to
title: Option<String>Title or name of the task
description: Option<String>Detailed description of the task’s purpose and scope
categories: Option<Vec<Category>>List of categories associated with this task
risk_type: Option<RiskType>Type of security risk this task is designed to test
target_endpoint: Option<Endpoint>Target endpoint for this security test
execution_status: Option<TaskExecutionStatus>Current status of the task execution
logs_location: Option<LogLocation>Location of execution logs for auditing and review
created_at: Option<DateTime>Timestamp when the task was created
updated_at: Option<DateTime>Timestamp when the task was last updated
Implementations
Sourceimpl Task
impl Task
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
Identifier of the parent pentest
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
Identifier of the pentest job this task belongs to
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
Identifier of the agent space this task belongs to
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Detailed description of the task’s purpose and scope
Sourcepub fn categories(&self) -> &[Category]
pub fn categories(&self) -> &[Category]
List of categories associated with this task
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .categories.is_none().
Sourcepub fn risk_type(&self) -> Option<&RiskType>
pub fn risk_type(&self) -> Option<&RiskType>
Type of security risk this task is designed to test
Sourcepub fn target_endpoint(&self) -> Option<&Endpoint>
pub fn target_endpoint(&self) -> Option<&Endpoint>
Target endpoint for this security test
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
Current status of the task execution
Sourcepub fn logs_location(&self) -> Option<&LogLocation>
pub fn logs_location(&self) -> Option<&LogLocation>
Location of execution logs for auditing and review
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the task was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the task was last updated