#[non_exhaustive]pub struct Threat {Show 21 fields
pub threat_id: Option<String>,
pub threat_job_id: Option<String>,
pub title: Option<String>,
pub statement: Option<String>,
pub severity: Option<ThreatSeverity>,
pub status: Option<ThreatStatus>,
pub comments: Option<String>,
pub threat_source: Option<String>,
pub prerequisites: Option<String>,
pub threat_action: Option<String>,
pub threat_impact: Option<String>,
pub impacted_goal: Option<Vec<String>>,
pub impacted_assets: Option<Vec<String>>,
pub anchor: Option<ThreatAnchorShape>,
pub evidence: Option<Vec<ThreatEvidenceShape>>,
pub stride: Option<Vec<StrideCategory>>,
pub recommendation: Option<String>,
pub created_by: Option<ThreatActor>,
pub updated_by: Option<ThreatActor>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a threat identified during threat modeling.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_id: Option<String>The unique identifier of the threat.
threat_job_id: Option<String>The unique identifier of the threat model job that produced the threat.
title: Option<String>A short title summarizing the threat.
statement: Option<String>The natural-language threat statement.
severity: Option<ThreatSeverity>The severity level of the threat.
status: Option<ThreatStatus>The current status of the threat.
comments: Option<String>Optional customer comment on the threat.
threat_source: Option<String>The actor or origin of the threat.
prerequisites: Option<String>The conditions required for the threat to be exploitable.
threat_action: Option<String>What the threat source can do.
threat_impact: Option<String>The direct consequence of the threat action.
impacted_goal: Option<Vec<String>>The security goals affected by the threat.
impacted_assets: Option<Vec<String>>The specific assets affected by the threat.
anchor: Option<ThreatAnchorShape>The DFD element this threat is anchored to.
evidence: Option<Vec<ThreatEvidenceShape>>The source code files supporting the threat.
stride: Option<Vec<StrideCategory>>The STRIDE categories applicable to this threat.
recommendation: Option<String>The recommended mitigation guidance for this threat.
created_by: Option<ThreatActor>Who created this threat.
updated_by: Option<ThreatActor>Who last updated this threat.
created_at: Option<DateTime>The date and time the threat was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat was last updated, in UTC format.
Implementations
Sourceimpl Threat
impl Threat
Sourcepub fn threat_job_id(&self) -> Option<&str>
pub fn threat_job_id(&self) -> Option<&str>
The unique identifier of the threat model job that produced the threat.
Sourcepub fn severity(&self) -> Option<&ThreatSeverity>
pub fn severity(&self) -> Option<&ThreatSeverity>
The severity level of the threat.
Sourcepub fn status(&self) -> Option<&ThreatStatus>
pub fn status(&self) -> Option<&ThreatStatus>
The current status of the threat.
Sourcepub fn threat_source(&self) -> Option<&str>
pub fn threat_source(&self) -> Option<&str>
The actor or origin of the threat.
Sourcepub fn prerequisites(&self) -> Option<&str>
pub fn prerequisites(&self) -> Option<&str>
The conditions required for the threat to be exploitable.
Sourcepub fn threat_action(&self) -> Option<&str>
pub fn threat_action(&self) -> Option<&str>
What the threat source can do.
Sourcepub fn threat_impact(&self) -> Option<&str>
pub fn threat_impact(&self) -> Option<&str>
The direct consequence of the threat action.
Sourcepub fn impacted_goal(&self) -> &[String]
pub fn impacted_goal(&self) -> &[String]
The security goals affected by the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_goal.is_none().
Sourcepub fn impacted_assets(&self) -> &[String]
pub fn impacted_assets(&self) -> &[String]
The specific assets affected by the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .impacted_assets.is_none().
Sourcepub fn anchor(&self) -> Option<&ThreatAnchorShape>
pub fn anchor(&self) -> Option<&ThreatAnchorShape>
The DFD element this threat is anchored to.
Sourcepub fn evidence(&self) -> &[ThreatEvidenceShape]
pub fn evidence(&self) -> &[ThreatEvidenceShape]
The source code files supporting the threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .evidence.is_none().
Sourcepub fn stride(&self) -> &[StrideCategory]
pub fn stride(&self) -> &[StrideCategory]
The STRIDE categories applicable to this threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .stride.is_none().
Sourcepub fn recommendation(&self) -> Option<&str>
pub fn recommendation(&self) -> Option<&str>
The recommended mitigation guidance for this threat.
Sourcepub fn created_by(&self) -> Option<&ThreatActor>
pub fn created_by(&self) -> Option<&ThreatActor>
Who created this threat.
Sourcepub fn updated_by(&self) -> Option<&ThreatActor>
pub fn updated_by(&self) -> Option<&ThreatActor>
Who last updated this threat.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat was last updated, in UTC format.