#[non_exhaustive]pub struct ThreatModelJob {Show 15 fields
pub threat_model_job_id: Option<String>,
pub threat_model_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub status: Option<JobStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub execution_start_time: Option<DateTime>,
pub execution_end_time: Option<DateTime>,
pub source_code: Option<Vec<SourceCodeRepository>>,
pub integrated_repositories: Option<Vec<IntegratedRepository>>,
pub documents: Option<Vec<DocumentInfo>>,
pub scope_docs: Option<Vec<DocumentInfo>>,
pub error_information: Option<ErrorInformation>,
pub system_overview: Option<String>,
}Expand description
Represents a threat model job, which is an execution instance of a threat model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_job_id: Option<String>The unique identifier of the threat model job.
threat_model_id: Option<String>The unique identifier of the threat model associated with the job.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the threat model job.
status: Option<JobStatus>The current status of the threat model job.
created_at: Option<DateTime>The date and time the threat model job was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat model job was last updated, in UTC format.
execution_start_time: Option<DateTime>The date and time the threat model job execution started, in UTC format.
execution_end_time: Option<DateTime>The date and time the threat model job execution ended, in UTC format.
source_code: Option<Vec<SourceCodeRepository>>The list of source code repositories used for threat modeling.
integrated_repositories: Option<Vec<IntegratedRepository>>The list of integrated repositories used for threat modeling.
documents: Option<Vec<DocumentInfo>>The list of documents used for threat modeling.
scope_docs: Option<Vec<DocumentInfo>>The scoped documents for the agent to focus on during threat modeling.
error_information: Option<ErrorInformation>Error information if the threat model job encountered an error.
system_overview: Option<String>The system overview generated during threat modeling.
Implementations
Sourceimpl ThreatModelJob
impl ThreatModelJob
Sourcepub fn threat_model_job_id(&self) -> Option<&str>
pub fn threat_model_job_id(&self) -> Option<&str>
The unique identifier of the threat model job.
Sourcepub fn threat_model_id(&self) -> Option<&str>
pub fn threat_model_id(&self) -> Option<&str>
The unique identifier of the threat model associated with the job.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat model job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat model job was last updated, in UTC format.
Sourcepub fn execution_start_time(&self) -> Option<&DateTime>
pub fn execution_start_time(&self) -> Option<&DateTime>
The date and time the threat model job execution started, in UTC format.
Sourcepub fn execution_end_time(&self) -> Option<&DateTime>
pub fn execution_end_time(&self) -> Option<&DateTime>
The date and time the threat model job execution ended, in UTC format.
Sourcepub fn source_code(&self) -> &[SourceCodeRepository]
pub fn source_code(&self) -> &[SourceCodeRepository]
The list of source code repositories used for threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_code.is_none().
Sourcepub fn integrated_repositories(&self) -> &[IntegratedRepository]
pub fn integrated_repositories(&self) -> &[IntegratedRepository]
The list of integrated repositories used for threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrated_repositories.is_none().
Sourcepub fn documents(&self) -> &[DocumentInfo]
pub fn documents(&self) -> &[DocumentInfo]
The list of documents used for threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .documents.is_none().
Sourcepub fn scope_docs(&self) -> &[DocumentInfo]
pub fn scope_docs(&self) -> &[DocumentInfo]
The scoped documents for the agent to focus on during threat modeling.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scope_docs.is_none().
Sourcepub fn error_information(&self) -> Option<&ErrorInformation>
pub fn error_information(&self) -> Option<&ErrorInformation>
Error information if the threat model job encountered an error.
Sourcepub fn system_overview(&self) -> Option<&str>
pub fn system_overview(&self) -> Option<&str>
The system overview generated during threat modeling.
Sourceimpl ThreatModelJob
impl ThreatModelJob
Sourcepub fn builder() -> ThreatModelJobBuilder
pub fn builder() -> ThreatModelJobBuilder
Creates a new builder-style object to manufacture ThreatModelJob.