#[non_exhaustive]pub struct ThreatModelJobSummary {
pub threat_model_job_id: String,
pub threat_model_id: String,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub status: Option<JobStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a threat model job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_job_id: StringThe unique identifier of the threat model job.
threat_model_id: StringThe unique identifier of the threat model associated with the job.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the threat model job.
status: Option<JobStatus>The current status of the threat model job.
created_at: Option<DateTime>The date and time the threat model job was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat model job was last updated, in UTC format.
Implementations
Sourceimpl ThreatModelJobSummary
impl ThreatModelJobSummary
Sourcepub fn threat_model_job_id(&self) -> &str
pub fn threat_model_job_id(&self) -> &str
The unique identifier of the threat model job.
Sourcepub fn threat_model_id(&self) -> &str
pub fn threat_model_id(&self) -> &str
The unique identifier of the threat model associated with the job.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat model job was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat model job was last updated, in UTC format.
Sourceimpl ThreatModelJobSummary
impl ThreatModelJobSummary
Sourcepub fn builder() -> ThreatModelJobSummaryBuilder
pub fn builder() -> ThreatModelJobSummaryBuilder
Creates a new builder-style object to manufacture ThreatModelJobSummary.