#[non_exhaustive]pub struct ThreatModelJobTask {
pub task_id: String,
pub threat_model_id: Option<String>,
pub threat_model_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub execution_status: Option<TaskExecutionStatus>,
pub logs_location: Option<LogLocation>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents an individual task within a threat model job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringThe unique identifier of the task.
threat_model_id: Option<String>The unique identifier of the threat model associated with the task.
threat_model_job_id: Option<String>The unique identifier of the threat model job that contains the task.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the task.
description: Option<String>A description of the task.
execution_status: Option<TaskExecutionStatus>The current execution status of the task.
logs_location: Option<LogLocation>The location of the task execution logs.
created_at: Option<DateTime>The date and time the task was created, in UTC format.
updated_at: Option<DateTime>The date and time the task was last updated, in UTC format.
Implementations
Sourceimpl ThreatModelJobTask
impl ThreatModelJobTask
Sourcepub fn threat_model_id(&self) -> Option<&str>
pub fn threat_model_id(&self) -> Option<&str>
The unique identifier of the threat model associated with the task.
Sourcepub fn threat_model_job_id(&self) -> Option<&str>
pub fn threat_model_job_id(&self) -> Option<&str>
The unique identifier of the threat model job that contains the task.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the task.
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn logs_location(&self) -> Option<&LogLocation>
pub fn logs_location(&self) -> Option<&LogLocation>
The location of the task execution logs.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the task was last updated, in UTC format.
Sourceimpl ThreatModelJobTask
impl ThreatModelJobTask
Sourcepub fn builder() -> ThreatModelJobTaskBuilder
pub fn builder() -> ThreatModelJobTaskBuilder
Creates a new builder-style object to manufacture ThreatModelJobTask.