#[non_exhaustive]pub struct ThreatModelJobTaskSummary {
pub task_id: String,
pub threat_model_id: Option<String>,
pub threat_model_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub execution_status: Option<TaskExecutionStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a threat model job task.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringThe unique identifier of the task.
threat_model_id: Option<String>The unique identifier of the threat model associated with the task.
threat_model_job_id: Option<String>The unique identifier of the threat model job that contains the task.
agent_space_id: Option<String>The unique identifier of the agent space.
title: Option<String>The title of the task.
execution_status: Option<TaskExecutionStatus>The current execution status of the task.
created_at: Option<DateTime>The date and time the task was created, in UTC format.
updated_at: Option<DateTime>The date and time the task was last updated, in UTC format.
Implementations
Sourceimpl ThreatModelJobTaskSummary
impl ThreatModelJobTaskSummary
Sourcepub fn threat_model_id(&self) -> Option<&str>
pub fn threat_model_id(&self) -> Option<&str>
The unique identifier of the threat model associated with the task.
Sourcepub fn threat_model_job_id(&self) -> Option<&str>
pub fn threat_model_job_id(&self) -> Option<&str>
The unique identifier of the threat model job that contains the task.
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
The unique identifier of the agent space.
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
The current execution status of the task.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the task was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the task was last updated, in UTC format.
Sourceimpl ThreatModelJobTaskSummary
impl ThreatModelJobTaskSummary
Sourcepub fn builder() -> ThreatModelJobTaskSummaryBuilder
pub fn builder() -> ThreatModelJobTaskSummaryBuilder
Creates a new builder-style object to manufacture ThreatModelJobTaskSummary.