#[non_exhaustive]pub struct ThreatModelSummary {
pub threat_model_id: String,
pub agent_space_id: String,
pub title: String,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a threat model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_model_id: StringThe unique identifier of the threat model.
agent_space_id: StringThe unique identifier of the agent space that contains the threat model.
title: StringThe title of the threat model.
created_at: Option<DateTime>The date and time the threat model was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat model was last updated, in UTC format.
Implementations
Sourceimpl ThreatModelSummary
impl ThreatModelSummary
Sourcepub fn threat_model_id(&self) -> &str
pub fn threat_model_id(&self) -> &str
The unique identifier of the threat model.
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the agent space that contains the threat model.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat model was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat model was last updated, in UTC format.
Sourceimpl ThreatModelSummary
impl ThreatModelSummary
Sourcepub fn builder() -> ThreatModelSummaryBuilder
pub fn builder() -> ThreatModelSummaryBuilder
Creates a new builder-style object to manufacture ThreatModelSummary.