#[non_exhaustive]pub struct ThreatSummary {
pub threat_id: Option<String>,
pub threat_job_id: Option<String>,
pub title: Option<String>,
pub statement: Option<String>,
pub severity: Option<ThreatSeverity>,
pub status: Option<ThreatStatus>,
pub stride: Option<Vec<StrideCategory>>,
pub created_by: Option<ThreatActor>,
pub updated_by: Option<ThreatActor>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Contains summary information about a threat.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_id: Option<String>The unique identifier of the threat.
threat_job_id: Option<String>The unique identifier of the threat model job that produced the threat.
title: Option<String>A short title summarizing the threat.
statement: Option<String>The natural-language threat statement.
severity: Option<ThreatSeverity>The severity level of the threat.
status: Option<ThreatStatus>The current status of the threat.
stride: Option<Vec<StrideCategory>>The STRIDE categories applicable to this threat.
created_by: Option<ThreatActor>Who created this threat.
updated_by: Option<ThreatActor>Who last updated this threat.
created_at: Option<DateTime>The date and time the threat was created, in UTC format.
updated_at: Option<DateTime>The date and time the threat was last updated, in UTC format.
Implementations
Sourceimpl ThreatSummary
impl ThreatSummary
Sourcepub fn threat_job_id(&self) -> Option<&str>
pub fn threat_job_id(&self) -> Option<&str>
The unique identifier of the threat model job that produced the threat.
Sourcepub fn severity(&self) -> Option<&ThreatSeverity>
pub fn severity(&self) -> Option<&ThreatSeverity>
The severity level of the threat.
Sourcepub fn status(&self) -> Option<&ThreatStatus>
pub fn status(&self) -> Option<&ThreatStatus>
The current status of the threat.
Sourcepub fn stride(&self) -> &[StrideCategory]
pub fn stride(&self) -> &[StrideCategory]
The STRIDE categories applicable to this threat.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .stride.is_none().
Sourcepub fn created_by(&self) -> Option<&ThreatActor>
pub fn created_by(&self) -> Option<&ThreatActor>
Who created this threat.
Sourcepub fn updated_by(&self) -> Option<&ThreatActor>
pub fn updated_by(&self) -> Option<&ThreatActor>
Who last updated this threat.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the threat was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the threat was last updated, in UTC format.
Sourceimpl ThreatSummary
impl ThreatSummary
Sourcepub fn builder() -> ThreatSummaryBuilder
pub fn builder() -> ThreatSummaryBuilder
Creates a new builder-style object to manufacture ThreatSummary.