#[non_exhaustive]pub struct UpdateSecurityRequirementEntry {
pub name: String,
pub description: Option<String>,
pub domain: Option<String>,
pub evaluation: Option<String>,
pub remediation: Option<String>,
}Expand description
Contains the details for updating an existing security requirement within a pack. The name is an immutable identifier used to locate the requirement and cannot be modified.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
description: Option<String>The updated description of the security requirement.
domain: Option<String>The updated security domain the requirement belongs to.
evaluation: Option<String>The updated evaluation criteria used to assess compliance with this requirement.
remediation: Option<String>The updated remediation steps when the requirement is not met.
Implementations
Sourceimpl UpdateSecurityRequirementEntry
impl UpdateSecurityRequirementEntry
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The updated description of the security requirement.
Sourcepub fn evaluation(&self) -> Option<&str>
pub fn evaluation(&self) -> Option<&str>
The updated evaluation criteria used to assess compliance with this requirement.
Sourcepub fn remediation(&self) -> Option<&str>
pub fn remediation(&self) -> Option<&str>
The updated remediation steps when the requirement is not met.
Sourceimpl UpdateSecurityRequirementEntry
impl UpdateSecurityRequirementEntry
Sourcepub fn builder() -> UpdateSecurityRequirementEntryBuilder
pub fn builder() -> UpdateSecurityRequirementEntryBuilder
Creates a new builder-style object to manufacture UpdateSecurityRequirementEntry.