#[non_exhaustive]pub struct VerificationScript {
pub script_type: Option<String>,
pub script_url: Option<String>,
pub instructions: Option<String>,
pub env_vars: Option<Vec<VerificationScriptEnvVar>>,
}Expand description
Contains metadata for a verification script that can be used to reproduce a security finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.script_type: Option<String>The type of script. Valid values are python and bash.
script_url: Option<String>URL to download the verification script.
instructions: Option<String>Instructions for running the verification script, including prerequisites and how to interpret results.
env_vars: Option<Vec<VerificationScriptEnvVar>>The list of environment variables required to run the verification script.
Implementations
Sourceimpl VerificationScript
impl VerificationScript
Sourcepub fn script_type(&self) -> Option<&str>
pub fn script_type(&self) -> Option<&str>
The type of script. Valid values are python and bash.
Sourcepub fn script_url(&self) -> Option<&str>
pub fn script_url(&self) -> Option<&str>
URL to download the verification script.
Sourcepub fn instructions(&self) -> Option<&str>
pub fn instructions(&self) -> Option<&str>
Instructions for running the verification script, including prerequisites and how to interpret results.
Sourcepub fn env_vars(&self) -> &[VerificationScriptEnvVar]
pub fn env_vars(&self) -> &[VerificationScriptEnvVar]
The list of environment variables required to run the verification script.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .env_vars.is_none().
Sourceimpl VerificationScript
impl VerificationScript
Sourcepub fn builder() -> VerificationScriptBuilder
pub fn builder() -> VerificationScriptBuilder
Creates a new builder-style object to manufacture VerificationScript.