#[non_exhaustive]pub struct VpcConfig {
pub vpc_arn: Option<String>,
pub security_group_arns: Option<Vec<String>>,
pub subnet_arns: Option<Vec<String>>,
}Expand description
Customer VPC configuration that the Security Agent accesses
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vpc_arn: Option<String>ARN or ID of the customer VPC
security_group_arns: Option<Vec<String>>List of security group ARNs or IDs in the customer VPC
subnet_arns: Option<Vec<String>>List of subnet ARNs or IDs in the customer VPC
Implementations
Sourceimpl VpcConfig
impl VpcConfig
Sourcepub fn security_group_arns(&self) -> &[String]
pub fn security_group_arns(&self) -> &[String]
List of security group ARNs or IDs in the customer VPC
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_arns.is_none().
Sourcepub fn subnet_arns(&self) -> &[String]
pub fn subnet_arns(&self) -> &[String]
List of subnet ARNs or IDs in the customer VPC
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_arns.is_none().