#[non_exhaustive]pub struct CreateAgentSpaceOutputBuilder { /* private fields */ }Expand description
A builder for CreateAgentSpaceOutput.
Implementations
Sourceimpl CreateAgentSpaceOutputBuilder
impl CreateAgentSpaceOutputBuilder
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Unique identifier of the created agent space This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Unique identifier of the created agent space
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Unique identifier of the created agent space
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Name of the created agent space This field is required.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Description of the created agent space
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Description of the created agent space
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Description of the created agent space
Sourcepub fn aws_resources(self, input: AwsResources) -> Self
pub fn aws_resources(self, input: AwsResources) -> Self
AWS resource configurations associated with the agent space
Sourcepub fn set_aws_resources(self, input: Option<AwsResources>) -> Self
pub fn set_aws_resources(self, input: Option<AwsResources>) -> Self
AWS resource configurations associated with the agent space
Sourcepub fn get_aws_resources(&self) -> &Option<AwsResources>
pub fn get_aws_resources(&self) -> &Option<AwsResources>
AWS resource configurations associated with the agent space
Sourcepub fn target_domain_ids(self, input: impl Into<String>) -> Self
pub fn target_domain_ids(self, input: impl Into<String>) -> Self
Appends an item to target_domain_ids.
To override the contents of this collection use set_target_domain_ids.
List of target domain IDs registered with the agent space
Sourcepub fn set_target_domain_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_target_domain_ids(self, input: Option<Vec<String>>) -> Self
List of target domain IDs registered with the agent space
Sourcepub fn get_target_domain_ids(&self) -> &Option<Vec<String>>
pub fn get_target_domain_ids(&self) -> &Option<Vec<String>>
List of target domain IDs registered with the agent space
Sourcepub fn code_review_settings(self, input: CodeReviewSettings) -> Self
pub fn code_review_settings(self, input: CodeReviewSettings) -> Self
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourcepub fn set_code_review_settings(self, input: Option<CodeReviewSettings>) -> Self
pub fn set_code_review_settings(self, input: Option<CodeReviewSettings>) -> Self
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourcepub fn get_code_review_settings(&self) -> &Option<CodeReviewSettings>
pub fn get_code_review_settings(&self) -> &Option<CodeReviewSettings>
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the agent space was created
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the agent space was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the agent space was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when the agent space was last updated
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when the agent space was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when the agent space was last updated
Sourcepub fn build(self) -> Result<CreateAgentSpaceOutput, BuildError>
pub fn build(self) -> Result<CreateAgentSpaceOutput, BuildError>
Consumes the builder and constructs a CreateAgentSpaceOutput.
This method will fail if any of the following fields are not set: