#[non_exhaustive]pub struct CreateAgentSpaceInput {
pub name: Option<String>,
pub description: Option<String>,
pub aws_resources: Option<AwsResources>,
pub target_domain_ids: Option<Vec<String>>,
pub code_review_settings: Option<CodeReviewSettings>,
pub kms_key_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Input for creating a new agent space
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Name of the agent space
description: Option<String>Description of the agent space
aws_resources: Option<AwsResources>AWS resource configurations associated with the agent space
target_domain_ids: Option<Vec<String>>Target domain IDs to associate with the agent space
code_review_settings: Option<CodeReviewSettings>Configuration for code review analysis, including controls scanning and general purpose scanning settings
kms_key_id: Option<String>Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.
Tags to associate with the agent space
Implementations
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Description of the agent space
Sourcepub fn aws_resources(&self) -> Option<&AwsResources>
pub fn aws_resources(&self) -> Option<&AwsResources>
AWS resource configurations associated with the agent space
Sourcepub fn target_domain_ids(&self) -> &[String]
pub fn target_domain_ids(&self) -> &[String]
Target domain IDs to associate with the agent space
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .target_domain_ids.is_none().
Sourcepub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
pub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
Identifier of the KMS key used to encrypt data. Can be a key ID, key ARN, alias name, or alias ARN. If not specified, an AWS managed key is used.
Tags to associate with the agent space
Sourceimpl CreateAgentSpaceInput
impl CreateAgentSpaceInput
Sourcepub fn builder() -> CreateAgentSpaceInputBuilder
pub fn builder() -> CreateAgentSpaceInputBuilder
Creates a new builder-style object to manufacture CreateAgentSpaceInput.