#[non_exhaustive]pub struct CreateAgentSpaceOutput {
pub agent_space_id: String,
pub name: String,
pub description: Option<String>,
pub aws_resources: Option<AwsResources>,
pub target_domain_ids: Option<Vec<String>>,
pub code_review_settings: Option<CodeReviewSettings>,
pub kms_key_id: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
/* private fields */
}Expand description
Output for the CreateAgentSpace operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: StringThe unique identifier of the created agent space.
name: StringThe name of the agent space.
description: Option<String>The description of the agent space.
aws_resources: Option<AwsResources>The AWS resources associated with the agent space.
target_domain_ids: Option<Vec<String>>The list of target domain identifiers associated with the agent space.
code_review_settings: Option<CodeReviewSettings>The code review settings for the agent space.
kms_key_id: Option<String>The identifier of the AWS KMS key used to encrypt data in the agent space.
created_at: Option<DateTime>The date and time the agent space was created, in UTC format.
updated_at: Option<DateTime>The date and time the agent space was last updated, in UTC format.
Implementations
Sourceimpl CreateAgentSpaceOutput
impl CreateAgentSpaceOutput
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
The unique identifier of the created agent space.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the agent space.
Sourcepub fn aws_resources(&self) -> Option<&AwsResources>
pub fn aws_resources(&self) -> Option<&AwsResources>
The AWS resources associated with the agent space.
Sourcepub fn target_domain_ids(&self) -> &[String]
pub fn target_domain_ids(&self) -> &[String]
The list of target domain identifiers associated with the agent space.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .target_domain_ids.is_none().
Sourcepub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
pub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
The code review settings for the agent space.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The identifier of the AWS KMS key used to encrypt data in the agent space.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time the agent space was created, in UTC format.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the agent space was last updated, in UTC format.
Sourceimpl CreateAgentSpaceOutput
impl CreateAgentSpaceOutput
Sourcepub fn builder() -> CreateAgentSpaceOutputBuilder
pub fn builder() -> CreateAgentSpaceOutputBuilder
Creates a new builder-style object to manufacture CreateAgentSpaceOutput.