#[non_exhaustive]pub struct CreatePentestOutput {
pub pentest_id: Option<String>,
pub title: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub agent_space_id: Option<String>,
/* private fields */
}Expand description
Output for the CreatePentest operation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: Option<String>Unique identifier of the created pentest
title: Option<String>Title of the created pentest
created_at: Option<DateTime>Timestamp when the pentest was created
updated_at: Option<DateTime>Timestamp when the pentest was last updated
assets: Option<Assets>Assets to be tested in the created pentest
exclude_risk_types: Option<Vec<RiskType>>A list of risk types excluded from the pentest execution
service_role: Option<String>Service role ARN for accessing customer resources
log_config: Option<CloudWatchLog>CloudWatch log group and stream prefix where pentest execution logs are stored
agent_space_id: Option<String>ID of the agent space where the pentest was created
Implementations
Sourceimpl CreatePentestOutput
impl CreatePentestOutput
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
Unique identifier of the created pentest
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the pentest was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the pentest was last updated
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
A list of risk types excluded from the pentest execution
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
Service role ARN for accessing customer resources
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
CloudWatch log group and stream prefix where pentest execution logs are stored
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
ID of the agent space where the pentest was created
Sourceimpl CreatePentestOutput
impl CreatePentestOutput
Sourcepub fn builder() -> CreatePentestOutputBuilder
pub fn builder() -> CreatePentestOutputBuilder
Creates a new builder-style object to manufacture CreatePentestOutput.