#[non_exhaustive]pub struct GetApplicationOutputBuilder { /* private fields */ }Expand description
A builder for GetApplicationOutput.
Implementations
Sourceimpl GetApplicationOutputBuilder
impl GetApplicationOutputBuilder
Sourcepub fn application_id(self, input: impl Into<String>) -> Self
pub fn application_id(self, input: impl Into<String>) -> Self
Application ID This field is required.
Sourcepub fn set_application_id(self, input: Option<String>) -> Self
pub fn set_application_id(self, input: Option<String>) -> Self
Application ID
Sourcepub fn get_application_id(&self) -> &Option<String>
pub fn get_application_id(&self) -> &Option<String>
Application ID
Sourcepub fn domain(self, input: impl Into<String>) -> Self
pub fn domain(self, input: impl Into<String>) -> Self
Domain where the application is available This field is required.
Sourcepub fn set_domain(self, input: Option<String>) -> Self
pub fn set_domain(self, input: Option<String>) -> Self
Domain where the application is available
Sourcepub fn get_domain(&self) -> &Option<String>
pub fn get_domain(&self) -> &Option<String>
Domain where the application is available
Sourcepub fn application_name(self, input: impl Into<String>) -> Self
pub fn application_name(self, input: impl Into<String>) -> Self
Name of the application, automatically assigned by the service
Sourcepub fn set_application_name(self, input: Option<String>) -> Self
pub fn set_application_name(self, input: Option<String>) -> Self
Name of the application, automatically assigned by the service
Sourcepub fn get_application_name(&self) -> &Option<String>
pub fn get_application_name(&self) -> &Option<String>
Name of the application, automatically assigned by the service
Sourcepub fn idc_configuration(self, input: IdCConfiguration) -> Self
pub fn idc_configuration(self, input: IdCConfiguration) -> Self
IAM Identity Center configuration for the application
Sourcepub fn set_idc_configuration(self, input: Option<IdCConfiguration>) -> Self
pub fn set_idc_configuration(self, input: Option<IdCConfiguration>) -> Self
IAM Identity Center configuration for the application
Sourcepub fn get_idc_configuration(&self) -> &Option<IdCConfiguration>
pub fn get_idc_configuration(&self) -> &Option<IdCConfiguration>
IAM Identity Center configuration for the application
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
ARN of the IAM role that the application uses to access AWS resources on your behalf
Sourcepub fn default_kms_key_id(self, input: impl Into<String>) -> Self
pub fn default_kms_key_id(self, input: impl Into<String>) -> Self
Default KMS key identifier used to encrypt application data
Sourcepub fn set_default_kms_key_id(self, input: Option<String>) -> Self
pub fn set_default_kms_key_id(self, input: Option<String>) -> Self
Default KMS key identifier used to encrypt application data
Sourcepub fn get_default_kms_key_id(&self) -> &Option<String>
pub fn get_default_kms_key_id(&self) -> &Option<String>
Default KMS key identifier used to encrypt application data
Sourcepub fn build(self) -> Result<GetApplicationOutput, BuildError>
pub fn build(self) -> Result<GetApplicationOutput, BuildError>
Consumes the builder and constructs a GetApplicationOutput.
This method will fail if any of the following fields are not set: