#[non_exhaustive]pub struct UpdateAgentSpaceOutput {
pub agent_space_id: String,
pub name: String,
pub description: Option<String>,
pub aws_resources: Option<AwsResources>,
pub target_domain_ids: Option<Vec<String>>,
pub code_review_settings: Option<CodeReviewSettings>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
/* private fields */
}Expand description
Output for the UpdateAgentSpace operation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_space_id: StringUnique identifier of the agent space
name: StringName of the agent space
description: Option<String>Description of the agent space
aws_resources: Option<AwsResources>AWS resource configurations associated with the agent space
target_domain_ids: Option<Vec<String>>List of target domain IDs registered with the agent space
code_review_settings: Option<CodeReviewSettings>Configuration for code review analysis, including controls scanning and general purpose scanning settings
created_at: Option<DateTime>Timestamp when the agent space was created
updated_at: Option<DateTime>Timestamp when the agent space was last updated
Implementations
Sourceimpl UpdateAgentSpaceOutput
impl UpdateAgentSpaceOutput
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
Unique identifier of the agent space
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Description of the agent space
Sourcepub fn aws_resources(&self) -> Option<&AwsResources>
pub fn aws_resources(&self) -> Option<&AwsResources>
AWS resource configurations associated with the agent space
Sourcepub fn target_domain_ids(&self) -> &[String]
pub fn target_domain_ids(&self) -> &[String]
List of target domain IDs registered with the agent space
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .target_domain_ids.is_none().
Sourcepub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
pub fn code_review_settings(&self) -> Option<&CodeReviewSettings>
Configuration for code review analysis, including controls scanning and general purpose scanning settings
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the agent space was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the agent space was last updated
Sourceimpl UpdateAgentSpaceOutput
impl UpdateAgentSpaceOutput
Sourcepub fn builder() -> UpdateAgentSpaceOutputBuilder
pub fn builder() -> UpdateAgentSpaceOutputBuilder
Creates a new builder-style object to manufacture UpdateAgentSpaceOutput.