Module types

Module types 

Data structures used by operation inputs/outputs.

Modules

builders
Builders
error
Error types that AWS Security Agent can respond with.

Structs

Actor
Represents an entity that interacts with the system during security testing
AgentSpace
Agent space structure
AgentSpaceSummary
Summary information for an agent space
ApplicationSummary
Application summary for list operations
Artifact
Files containing relevant data for review
ArtifactMetadataItem
Metadata in relation to the artifact
ArtifactSummary
Summary information about an artifact
Assets
Collection of assets to be tested or used during a pentest
Authentication
Authentication information used to access protected resources
AwsResources
AWS resource configurations associated with the agent space
Category
Represents a category classification for tasks
CloudWatchLog
Reference to logs stored in CloudWatch
CodeRemediationTask
Information about task for code remediation
CodeRemediationTaskDetails
Code remediation details for a single repository
CodeReviewSettings
Details of code review settings
CustomHeader
Custom headers to be set for network requests
DeletePentestFailure
Information about a failed pentest deletion attempt
DiscoveredEndpoint
Represents a discovered endpoint during pentest execution
DnsVerification
Represents dns txt verification details
DocumentInfo
Information about a document relevant to security testing
Endpoint
Represents a web application endpoint to be tested
ErrorInformation
Error information regarding the pentest job
ExecutionContext
Additional context about a pentest or task execution
Finding
Represents a security vulnerability or issue discovered during testing
FindingSummary
Summary information for a security finding
GitHubIntegrationInput
Input parameters for GitHub integration
GitHubRepositoryMetadata
Metadata specific to a GitHub repository integrated resource
GitHubRepositoryResource
GitHub repository resource details
GitHubResourceCapabilities
Capabilities for GitHub repositories
HttpVerification
Represents http route verification details
IdCConfiguration
IdC configuration containing application and instance ARNs
IntegratedRepository
Information about an integrated repository
IntegratedResourceInputItem
Input item for updating an integrated resource
IntegratedResourceSummary
Summary information about an integrated resource
IntegrationSummary
Summary information about an integration
LogLocation
Location information for execution logs
MembershipSummary
Membership summary for list operations
NetworkTrafficConfig
Configuration for network traffic filtering
NetworkTrafficRule
Network traffic filtering rule
Pentest
Represents a pentest configuration and execution details
PentestJob
Represents a pentest job
PentestJobSummary
Summary information for a pentest job
PentestSummary
Summary information for a pentest
SourceCodeRepository
Information about a source code repository for static analysis
Step
Represents a single step in pentest job execution
TargetDomain
Represents a target domain
TargetDomainSummary
Summary information for a target domain
Task
Represents a task within a pentest job
TaskSummary
Summary information for a task
UserConfig
User membership configuration
UserMetadata
User-specific metadata
ValidationExceptionField
Describes one specific validation failure for an input member.
VerificationDetails
Verification details to verify registered target domain
VpcConfig
Customer VPC configuration that the Security Agent accesses

Enums

AccessType
When writing a match expression against AccessType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ArtifactType
When writing a match expression against ArtifactType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
AuthenticationProviderType
When writing a match expression against AuthenticationProviderType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
CodeRemediationStrategy
When writing a match expression against CodeRemediationStrategy, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
CodeRemediationTaskStatus
When writing a match expression against CodeRemediationTaskStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ConfidenceLevel
When writing a match expression against ConfidenceLevel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ContextType
When writing a match expression against ContextType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
DnsRecordType
When writing a match expression against DnsRecordType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
DomainVerificationMethod
When writing a match expression against DomainVerificationMethod, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ErrorCode
When writing a match expression against ErrorCode, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
FindingStatus
When writing a match expression against FindingStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
IntegratedResource
Integrated resource details from a provider
IntegratedResourceMetadata
Metadata about an integrated resource
IntegrationFilter
Filter criteria for integrations
JobStatus
When writing a match expression against JobStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
LogType
When writing a match expression against LogType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
MemberMetadata
Metadata associated with the member
MembershipConfig
Member-specific configuration
MembershipType
When writing a match expression against MembershipType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
MembershipTypeFilter
When writing a match expression against MembershipTypeFilter, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
NetworkTrafficRuleEffect
When writing a match expression against NetworkTrafficRuleEffect, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
NetworkTrafficRuleType
When writing a match expression against NetworkTrafficRuleType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
Provider
When writing a match expression against Provider, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ProviderInput
Provider-specific input parameters for integration
ProviderResourceCapabilities
Provider-specific capabilities for integrated resources
ProviderType
When writing a match expression against ProviderType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ResourceType
When writing a match expression against ResourceType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
RiskLevel
When writing a match expression against RiskLevel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
RiskType
When writing a match expression against RiskType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
StepName
When writing a match expression against StepName, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
StepStatus
When writing a match expression against StepStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
TargetDomainStatus
When writing a match expression against TargetDomainStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
TaskExecutionStatus
When writing a match expression against TaskExecutionStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
UserRole
When writing a match expression against UserRole, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.