Data structures used by operation inputs/outputs.
Modules
Structs
- Actor
- Represents an entity that interacts with the system during security testing
- Agent
Space - Agent space structure
- Agent
Space Summary - Summary information for an agent space
- Application
Summary - Application summary for list operations
- Artifact
- Files containing relevant data for review
- Artifact
Metadata Item - Metadata in relation to the artifact
- Artifact
Summary - Summary information about an artifact
- Assets
- Collection of assets to be tested or used during a pentest
- Authentication
- Authentication information used to access protected resources
- AwsResources
- AWS resource configurations associated with the agent space
- Category
- Represents a category classification for tasks
- Cloud
Watch Log - Reference to logs stored in CloudWatch
- Code
Remediation Task - Information about task for code remediation
- Code
Remediation Task Details - Code remediation details for a single repository
- Code
Review Settings - Details of code review settings
- Custom
Header - Custom headers to be set for network requests
- Delete
Pentest Failure - Information about a failed pentest deletion attempt
- Discovered
Endpoint - Represents a discovered endpoint during pentest execution
- DnsVerification
- Represents dns txt verification details
- Document
Info - Information about a document relevant to security testing
- Endpoint
- Represents a web application endpoint to be tested
- Error
Information - Error information regarding the pentest job
- Execution
Context - Additional context about a pentest or task execution
- Finding
- Represents a security vulnerability or issue discovered during testing
- Finding
Summary - Summary information for a security finding
- GitHub
Integration Input - Input parameters for GitHub integration
- GitHub
Repository Metadata - Metadata specific to a GitHub repository integrated resource
- GitHub
Repository Resource - GitHub repository resource details
- GitHub
Resource Capabilities - Capabilities for GitHub repositories
- Http
Verification - Represents http route verification details
- IdCConfiguration
- IdC configuration containing application and instance ARNs
- Integrated
Repository - Information about an integrated repository
- Integrated
Resource Input Item - Input item for updating an integrated resource
- Integrated
Resource Summary - Summary information about an integrated resource
- Integration
Summary - Summary information about an integration
- LogLocation
- Location information for execution logs
- Membership
Summary - Membership summary for list operations
- Network
Traffic Config - Configuration for network traffic filtering
- Network
Traffic Rule - Network traffic filtering rule
- Pentest
- Represents a pentest configuration and execution details
- Pentest
Job - Represents a pentest job
- Pentest
JobSummary - Summary information for a pentest job
- Pentest
Summary - Summary information for a pentest
- Source
Code Repository - Information about a source code repository for static analysis
- Step
- Represents a single step in pentest job execution
- Target
Domain - Represents a target domain
- Target
Domain Summary - Summary information for a target domain
- Task
- Represents a task within a pentest job
- Task
Summary - Summary information for a task
- User
Config - User membership configuration
- User
Metadata - User-specific metadata
- Validation
Exception Field - Describes one specific validation failure for an input member.
- Verification
Details - Verification details to verify registered target domain
- VpcConfig
- Customer VPC configuration that the Security Agent accesses
Enums
- Access
Type - When writing a match expression against
AccessType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Artifact
Type - When writing a match expression against
ArtifactType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Authentication
Provider Type - When writing a match expression against
AuthenticationProviderType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Code
Remediation Strategy - When writing a match expression against
CodeRemediationStrategy, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Code
Remediation Task Status - When writing a match expression against
CodeRemediationTaskStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Confidence
Level - When writing a match expression against
ConfidenceLevel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Context
Type - When writing a match expression against
ContextType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - DnsRecord
Type - When writing a match expression against
DnsRecordType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Domain
Verification Method - When writing a match expression against
DomainVerificationMethod, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Error
Code - When writing a match expression against
ErrorCode, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Finding
Status - When writing a match expression against
FindingStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Integrated
Resource - Integrated resource details from a provider
- Integrated
Resource Metadata - Metadata about an integrated resource
- Integration
Filter - Filter criteria for integrations
- JobStatus
- When writing a match expression against
JobStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - LogType
- When writing a match expression against
LogType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Member
Metadata - Metadata associated with the member
- Membership
Config - Member-specific configuration
- Membership
Type - When writing a match expression against
MembershipType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Membership
Type Filter - When writing a match expression against
MembershipTypeFilter, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Network
Traffic Rule Effect - When writing a match expression against
NetworkTrafficRuleEffect, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Network
Traffic Rule Type - When writing a match expression against
NetworkTrafficRuleType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Provider
- When writing a match expression against
Provider, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Provider
Input - Provider-specific input parameters for integration
- Provider
Resource Capabilities - Provider-specific capabilities for integrated resources
- Provider
Type - When writing a match expression against
ProviderType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Resource
Type - When writing a match expression against
ResourceType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Risk
Level - When writing a match expression against
RiskLevel, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Risk
Type - When writing a match expression against
RiskType, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Step
Name - When writing a match expression against
StepName, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Step
Status - When writing a match expression against
StepStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Target
Domain Status - When writing a match expression against
TargetDomainStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - Task
Execution Status - When writing a match expression against
TaskExecutionStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature. - User
Role - When writing a match expression against
UserRole, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.