#[non_exhaustive]pub struct AssetsBuilder { /* private fields */ }Expand description
A builder for Assets.
Implementations
Sourceimpl AssetsBuilder
impl AssetsBuilder
Sourcepub fn endpoints(self, input: Endpoint) -> Self
pub fn endpoints(self, input: Endpoint) -> Self
Appends an item to endpoints.
To override the contents of this collection use set_endpoints.
List of web application endpoints to test
Sourcepub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
List of web application endpoints to test
Sourcepub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
pub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
List of web application endpoints to test
Sourcepub fn actors(self, input: Actor) -> Self
pub fn actors(self, input: Actor) -> Self
Appends an item to actors.
To override the contents of this collection use set_actors.
List of actors that interact with the system
Sourcepub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
pub fn set_actors(self, input: Option<Vec<Actor>>) -> Self
List of actors that interact with the system
Sourcepub fn get_actors(&self) -> &Option<Vec<Actor>>
pub fn get_actors(&self) -> &Option<Vec<Actor>>
List of actors that interact with the system
Sourcepub fn documents(self, input: DocumentInfo) -> Self
pub fn documents(self, input: DocumentInfo) -> Self
Appends an item to documents.
To override the contents of this collection use set_documents.
List of documents providing context for testing
Sourcepub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
List of documents providing context for testing
Sourcepub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
List of documents providing context for testing
Sourcepub fn source_code(self, input: SourceCodeRepository) -> Self
pub fn source_code(self, input: SourceCodeRepository) -> Self
Appends an item to source_code.
To override the contents of this collection use set_source_code.
List of source code repositories for static analysis
Sourcepub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
List of source code repositories for static analysis
Sourcepub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
List of source code repositories for static analysis
Sourcepub fn integrated_repositories(self, input: IntegratedRepository) -> Self
pub fn integrated_repositories(self, input: IntegratedRepository) -> Self
Appends an item to integrated_repositories.
To override the contents of this collection use set_integrated_repositories.
List of integrated code repositories
Sourcepub fn set_integrated_repositories(
self,
input: Option<Vec<IntegratedRepository>>,
) -> Self
pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self
List of integrated code repositories
Sourcepub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
List of integrated code repositories