CodeReviewJobBuilder

Struct CodeReviewJobBuilder 

#[non_exhaustive]
pub struct CodeReviewJobBuilder { /* private fields */ }
A builder for CodeReviewJob.

Implementations

Source

impl CodeReviewJobBuilder

pub fn code_review_job_id(self, input: impl Into<String>) -> Self

The unique identifier of the code review job.

pub fn set_code_review_job_id(self, input: Option<String>) -> Self

The unique identifier of the code review job.

pub fn get_code_review_job_id(&self) -> &Option<String>

The unique identifier of the code review job.

pub fn code_review_id(self, input: impl Into<String>) -> Self

The unique identifier of the code review associated with the job.

pub fn set_code_review_id(self, input: Option<String>) -> Self

The unique identifier of the code review associated with the job.

pub fn get_code_review_id(&self) -> &Option<String>

The unique identifier of the code review associated with the job.

pub fn title(self, input: impl Into<String>) -> Self

The title of the code review job.

pub fn set_title(self, input: Option<String>) -> Self

The title of the code review job.

pub fn get_title(&self) -> &Option<String>

The title of the code review job.

pub fn overview(self, input: impl Into<String>) -> Self

An overview of the code review job results.

pub fn set_overview(self, input: Option<String>) -> Self

An overview of the code review job results.

pub fn get_overview(&self) -> &Option<String>

An overview of the code review job results.

pub fn status(self, input: JobStatus) -> Self

The current status of the code review job.

pub fn set_status(self, input: Option<JobStatus>) -> Self

The current status of the code review job.

pub fn get_status(&self) -> &Option<JobStatus>

The current status of the code review job.

pub fn documents(self, input: DocumentInfo) -> Self

Appends an item to documents.

To override the contents of this collection use set_documents.

The list of documents providing context for the code review job.

pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self

The list of documents providing context for the code review job.

pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>

The list of documents providing context for the code review job.

pub fn source_code(self, input: SourceCodeRepository) -> Self

Appends an item to source_code.

To override the contents of this collection use set_source_code.

The list of source code repositories analyzed during the code review job.

pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self

The list of source code repositories analyzed during the code review job.

pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>

The list of source code repositories analyzed during the code review job.

pub fn steps(self, input: Step) -> Self

Appends an item to steps.

To override the contents of this collection use set_steps.

The list of steps in the code review job execution.

pub fn set_steps(self, input: Option<Vec<Step>>) -> Self

The list of steps in the code review job execution.

pub fn get_steps(&self) -> &Option<Vec<Step>>

The list of steps in the code review job execution.

pub fn execution_context(self, input: ExecutionContext) -> Self

Appends an item to execution_context.

To override the contents of this collection use set_execution_context.

The execution context messages for the code review job.

pub fn set_execution_context(self, input: Option<Vec<ExecutionContext>>) -> Self

The execution context messages for the code review job.

pub fn get_execution_context(&self) -> &Option<Vec<ExecutionContext>>

The execution context messages for the code review job.

pub fn service_role(self, input: impl Into<String>) -> Self

The IAM service role used for the code review job.

pub fn set_service_role(self, input: Option<String>) -> Self

The IAM service role used for the code review job.

pub fn get_service_role(&self) -> &Option<String>

The IAM service role used for the code review job.

pub fn log_config(self, input: CloudWatchLog) -> Self

The CloudWatch Logs configuration for the code review job.

pub fn set_log_config(self, input: Option<CloudWatchLog>) -> Self

The CloudWatch Logs configuration for the code review job.

pub fn get_log_config(&self) -> &Option<CloudWatchLog>

The CloudWatch Logs configuration for the code review job.

pub fn error_information(self, input: ErrorInformation) -> Self

Error information if the code review job encountered an error.

pub fn set_error_information(self, input: Option<ErrorInformation>) -> Self

Error information if the code review job encountered an error.

pub fn get_error_information(&self) -> &Option<ErrorInformation>

Error information if the code review job encountered an error.

pub fn integrated_repositories(self, input: IntegratedRepository) -> Self

Appends an item to integrated_repositories.

To override the contents of this collection use set_integrated_repositories.

The list of integrated repositories associated with the code review job.

pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self

The list of integrated repositories associated with the code review job.

pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>

The list of integrated repositories associated with the code review job.

pub fn code_remediation_strategy(self, input: CodeRemediationStrategy) -> Self

The code remediation strategy for the code review job.

pub fn set_code_remediation_strategy( self, input: Option<CodeRemediationStrategy>, ) -> Self

The code remediation strategy for the code review job.

pub fn get_code_remediation_strategy(&self) -> &Option<CodeRemediationStrategy>

The code remediation strategy for the code review job.

pub fn created_at(self, input: DateTime) -> Self

The date and time the code review job was created, in UTC format.

pub fn set_created_at(self, input: Option<DateTime>) -> Self

The date and time the code review job was created, in UTC format.

pub fn get_created_at(&self) -> &Option<DateTime>

The date and time the code review job was created, in UTC format.

pub fn updated_at(self, input: DateTime) -> Self

The date and time the code review job was last updated, in UTC format.

pub fn set_updated_at(self, input: Option<DateTime>) -> Self

The date and time the code review job was last updated, in UTC format.

pub fn get_updated_at(&self) -> &Option<DateTime>

The date and time the code review job was last updated, in UTC format.

pub fn build(self) -> CodeReviewJob

Consumes the builder and constructs a CodeReviewJob.