#[non_exhaustive]pub struct FindingSummaryBuilder { /* private fields */ }Expand description
A builder for FindingSummary.
Implementations
Sourceimpl FindingSummaryBuilder
impl FindingSummaryBuilder
Sourcepub fn finding_id(self, input: impl Into<String>) -> Self
pub fn finding_id(self, input: impl Into<String>) -> Self
Unique identifier for the finding This field is required.
Sourcepub fn set_finding_id(self, input: Option<String>) -> Self
pub fn set_finding_id(self, input: Option<String>) -> Self
Unique identifier for the finding
Sourcepub fn get_finding_id(&self) -> &Option<String>
pub fn get_finding_id(&self) -> &Option<String>
Unique identifier for the finding
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
Identifier of the agent space that created this finding This field is required.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
Identifier of the agent space that created this finding
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
Identifier of the agent space that created this finding
Sourcepub fn pentest_id(self, input: impl Into<String>) -> Self
pub fn pentest_id(self, input: impl Into<String>) -> Self
Identifier of the parent pentest
Sourcepub fn set_pentest_id(self, input: Option<String>) -> Self
pub fn set_pentest_id(self, input: Option<String>) -> Self
Identifier of the parent pentest
Sourcepub fn get_pentest_id(&self) -> &Option<String>
pub fn get_pentest_id(&self) -> &Option<String>
Identifier of the parent pentest
Sourcepub fn pentest_job_id(self, input: impl Into<String>) -> Self
pub fn pentest_job_id(self, input: impl Into<String>) -> Self
Identifier of the pentest job
Sourcepub fn set_pentest_job_id(self, input: Option<String>) -> Self
pub fn set_pentest_job_id(self, input: Option<String>) -> Self
Identifier of the pentest job
Sourcepub fn get_pentest_job_id(&self) -> &Option<String>
pub fn get_pentest_job_id(&self) -> &Option<String>
Identifier of the pentest job
Sourcepub fn status(self, input: FindingStatus) -> Self
pub fn status(self, input: FindingStatus) -> Self
Current status of the finding
Sourcepub fn set_status(self, input: Option<FindingStatus>) -> Self
pub fn set_status(self, input: Option<FindingStatus>) -> Self
Current status of the finding
Sourcepub fn get_status(&self) -> &Option<FindingStatus>
pub fn get_status(&self) -> &Option<FindingStatus>
Current status of the finding
Sourcepub fn set_risk_type(self, input: Option<String>) -> Self
pub fn set_risk_type(self, input: Option<String>) -> Self
Type of security risk identified
Sourcepub fn get_risk_type(&self) -> &Option<String>
pub fn get_risk_type(&self) -> &Option<String>
Type of security risk identified
Sourcepub fn risk_level(self, input: RiskLevel) -> Self
pub fn risk_level(self, input: RiskLevel) -> Self
Severity level of the identified risk
Sourcepub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
pub fn set_risk_level(self, input: Option<RiskLevel>) -> Self
Severity level of the identified risk
Sourcepub fn get_risk_level(&self) -> &Option<RiskLevel>
pub fn get_risk_level(&self) -> &Option<RiskLevel>
Severity level of the identified risk
Sourcepub fn confidence(self, input: ConfidenceLevel) -> Self
pub fn confidence(self, input: ConfidenceLevel) -> Self
Confidence level of the finding
Sourcepub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
pub fn set_confidence(self, input: Option<ConfidenceLevel>) -> Self
Confidence level of the finding
Sourcepub fn get_confidence(&self) -> &Option<ConfidenceLevel>
pub fn get_confidence(&self) -> &Option<ConfidenceLevel>
Confidence level of the finding
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
Timestamp when the finding was created
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
Timestamp when the finding was created
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
Timestamp when the finding was created
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
Timestamp when the finding was last updated
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
Timestamp when the finding was last updated
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
Timestamp when the finding was last updated
Sourcepub fn build(self) -> Result<FindingSummary, BuildError>
pub fn build(self) -> Result<FindingSummary, BuildError>
Consumes the builder and constructs a FindingSummary.
This method will fail if any of the following fields are not set: