#[non_exhaustive]pub struct ThreatModelJobBuilder { /* private fields */ }Expand description
A builder for ThreatModelJob.
Implementations
Sourceimpl ThreatModelJobBuilder
impl ThreatModelJobBuilder
Sourcepub fn threat_model_job_id(self, input: impl Into<String>) -> Self
pub fn threat_model_job_id(self, input: impl Into<String>) -> Self
The unique identifier of the threat model job.
Sourcepub fn set_threat_model_job_id(self, input: Option<String>) -> Self
pub fn set_threat_model_job_id(self, input: Option<String>) -> Self
The unique identifier of the threat model job.
Sourcepub fn get_threat_model_job_id(&self) -> &Option<String>
pub fn get_threat_model_job_id(&self) -> &Option<String>
The unique identifier of the threat model job.
Sourcepub fn threat_model_id(self, input: impl Into<String>) -> Self
pub fn threat_model_id(self, input: impl Into<String>) -> Self
The unique identifier of the threat model associated with the job.
Sourcepub fn set_threat_model_id(self, input: Option<String>) -> Self
pub fn set_threat_model_id(self, input: Option<String>) -> Self
The unique identifier of the threat model associated with the job.
Sourcepub fn get_threat_model_id(&self) -> &Option<String>
pub fn get_threat_model_id(&self) -> &Option<String>
The unique identifier of the threat model associated with the job.
Sourcepub fn agent_space_id(self, input: impl Into<String>) -> Self
pub fn agent_space_id(self, input: impl Into<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn set_agent_space_id(self, input: Option<String>) -> Self
pub fn set_agent_space_id(self, input: Option<String>) -> Self
The unique identifier of the agent space.
Sourcepub fn get_agent_space_id(&self) -> &Option<String>
pub fn get_agent_space_id(&self) -> &Option<String>
The unique identifier of the agent space.
Sourcepub fn set_status(self, input: Option<JobStatus>) -> Self
pub fn set_status(self, input: Option<JobStatus>) -> Self
The current status of the threat model job.
Sourcepub fn get_status(&self) -> &Option<JobStatus>
pub fn get_status(&self) -> &Option<JobStatus>
The current status of the threat model job.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the threat model job was created, in UTC format.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the threat model job was created, in UTC format.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the threat model job was created, in UTC format.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time the threat model job was last updated, in UTC format.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time the threat model job was last updated, in UTC format.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time the threat model job was last updated, in UTC format.
Sourcepub fn execution_start_time(self, input: DateTime) -> Self
pub fn execution_start_time(self, input: DateTime) -> Self
The date and time the threat model job execution started, in UTC format.
Sourcepub fn set_execution_start_time(self, input: Option<DateTime>) -> Self
pub fn set_execution_start_time(self, input: Option<DateTime>) -> Self
The date and time the threat model job execution started, in UTC format.
Sourcepub fn get_execution_start_time(&self) -> &Option<DateTime>
pub fn get_execution_start_time(&self) -> &Option<DateTime>
The date and time the threat model job execution started, in UTC format.
Sourcepub fn execution_end_time(self, input: DateTime) -> Self
pub fn execution_end_time(self, input: DateTime) -> Self
The date and time the threat model job execution ended, in UTC format.
Sourcepub fn set_execution_end_time(self, input: Option<DateTime>) -> Self
pub fn set_execution_end_time(self, input: Option<DateTime>) -> Self
The date and time the threat model job execution ended, in UTC format.
Sourcepub fn get_execution_end_time(&self) -> &Option<DateTime>
pub fn get_execution_end_time(&self) -> &Option<DateTime>
The date and time the threat model job execution ended, in UTC format.
Sourcepub fn source_code(self, input: SourceCodeRepository) -> Self
pub fn source_code(self, input: SourceCodeRepository) -> Self
Appends an item to source_code.
To override the contents of this collection use set_source_code.
The list of source code repositories used for threat modeling.
Sourcepub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
pub fn set_source_code(self, input: Option<Vec<SourceCodeRepository>>) -> Self
The list of source code repositories used for threat modeling.
Sourcepub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
pub fn get_source_code(&self) -> &Option<Vec<SourceCodeRepository>>
The list of source code repositories used for threat modeling.
Sourcepub fn integrated_repositories(self, input: IntegratedRepository) -> Self
pub fn integrated_repositories(self, input: IntegratedRepository) -> Self
Appends an item to integrated_repositories.
To override the contents of this collection use set_integrated_repositories.
The list of integrated repositories used for threat modeling.
Sourcepub fn set_integrated_repositories(
self,
input: Option<Vec<IntegratedRepository>>,
) -> Self
pub fn set_integrated_repositories( self, input: Option<Vec<IntegratedRepository>>, ) -> Self
The list of integrated repositories used for threat modeling.
Sourcepub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
pub fn get_integrated_repositories(&self) -> &Option<Vec<IntegratedRepository>>
The list of integrated repositories used for threat modeling.
Sourcepub fn documents(self, input: DocumentInfo) -> Self
pub fn documents(self, input: DocumentInfo) -> Self
Appends an item to documents.
To override the contents of this collection use set_documents.
The list of documents used for threat modeling.
Sourcepub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_documents(self, input: Option<Vec<DocumentInfo>>) -> Self
The list of documents used for threat modeling.
Sourcepub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_documents(&self) -> &Option<Vec<DocumentInfo>>
The list of documents used for threat modeling.
Sourcepub fn scope_docs(self, input: DocumentInfo) -> Self
pub fn scope_docs(self, input: DocumentInfo) -> Self
Appends an item to scope_docs.
To override the contents of this collection use set_scope_docs.
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn set_scope_docs(self, input: Option<Vec<DocumentInfo>>) -> Self
pub fn set_scope_docs(self, input: Option<Vec<DocumentInfo>>) -> Self
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn get_scope_docs(&self) -> &Option<Vec<DocumentInfo>>
pub fn get_scope_docs(&self) -> &Option<Vec<DocumentInfo>>
The scoped documents for the agent to focus on during threat modeling.
Sourcepub fn error_information(self, input: ErrorInformation) -> Self
pub fn error_information(self, input: ErrorInformation) -> Self
Error information if the threat model job encountered an error.
Sourcepub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
pub fn set_error_information(self, input: Option<ErrorInformation>) -> Self
Error information if the threat model job encountered an error.
Sourcepub fn get_error_information(&self) -> &Option<ErrorInformation>
pub fn get_error_information(&self) -> &Option<ErrorInformation>
Error information if the threat model job encountered an error.
Sourcepub fn system_overview(self, input: impl Into<String>) -> Self
pub fn system_overview(self, input: impl Into<String>) -> Self
The system overview generated during threat modeling.
Sourcepub fn set_system_overview(self, input: Option<String>) -> Self
pub fn set_system_overview(self, input: Option<String>) -> Self
The system overview generated during threat modeling.
Sourcepub fn get_system_overview(&self) -> &Option<String>
pub fn get_system_overview(&self) -> &Option<String>
The system overview generated during threat modeling.
Sourcepub fn build(self) -> ThreatModelJob
pub fn build(self) -> ThreatModelJob
Consumes the builder and constructs a ThreatModelJob.