#[non_exhaustive]pub struct DiscoveredEndpoint {
pub uri: String,
pub pentest_job_id: String,
pub task_id: String,
pub agent_space_id: String,
pub evidence: Option<String>,
pub operation: Option<String>,
pub description: Option<String>,
}Expand description
Represents a discovered endpoint during pentest execution
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe URI of the discovered endpoint
pentest_job_id: StringIdentifier of the pentest job that discovered this endpoint
task_id: StringIdentifier of the task that discovered this endpoint
agent_space_id: StringIdentifier of the agent space where the endpoint was discovered
evidence: Option<String>Optional evidence or additional information about the endpoint
operation: Option<String>Operation or action associated with the endpoint
description: Option<String>Additional description of the endpoint
Implementations
Sourceimpl DiscoveredEndpoint
impl DiscoveredEndpoint
Sourcepub fn pentest_job_id(&self) -> &str
pub fn pentest_job_id(&self) -> &str
Identifier of the pentest job that discovered this endpoint
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
Identifier of the agent space where the endpoint was discovered
Sourcepub fn evidence(&self) -> Option<&str>
pub fn evidence(&self) -> Option<&str>
Optional evidence or additional information about the endpoint
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Additional description of the endpoint
Sourceimpl DiscoveredEndpoint
impl DiscoveredEndpoint
Sourcepub fn builder() -> DiscoveredEndpointBuilder
pub fn builder() -> DiscoveredEndpointBuilder
Creates a new builder-style object to manufacture DiscoveredEndpoint.