Finding

Struct Finding 

#[non_exhaustive]
pub struct Finding {
Show 18 fields pub finding_id: String, pub agent_space_id: String, pub pentest_id: Option<String>, pub pentest_job_id: Option<String>, pub task_id: Option<String>, pub name: Option<String>, pub description: Option<String>, pub status: Option<FindingStatus>, pub risk_type: Option<String>, pub risk_level: Option<RiskLevel>, pub risk_score: Option<String>, pub reasoning: Option<String>, pub confidence: Option<ConfidenceLevel>, pub attack_script: Option<String>, pub code_remediation_task: Option<CodeRemediationTask>, pub last_updated_by: Option<String>, pub created_at: Option<DateTime>, pub updated_at: Option<DateTime>,
}
Represents a security vulnerability or issue discovered during testing

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
finding_id: String

Unique identifier for the finding

agent_space_id: String

Identifier of the agent space that created this finding

pentest_id: Option<String>

Identifier of the parent pentest

pentest_job_id: Option<String>

Identifier of the pentest job

task_id: Option<String>

Identifier of the associated task

name: Option<String>

Name or title of the finding

description: Option<String>

Detailed description of the security vulnerability

status: Option<FindingStatus>

Current status of the finding

risk_type: Option<String>

Type of security risk identified

risk_level: Option<RiskLevel>

Severity level of the identified risk

risk_score: Option<String>

Risk score associated with the finding

reasoning: Option<String>

Justification for the assigned risk score

confidence: Option<ConfidenceLevel>

Confidence level of the finding

attack_script: Option<String>

Proof-of-concept code demonstrating the vulnerability

code_remediation_task: Option<CodeRemediationTask>

Code remediation task associated with this finding

last_updated_by: Option<String>

Identifier of the task or agent that last updated this finding

created_at: Option<DateTime>

Timestamp when the finding was created

updated_at: Option<DateTime>

Timestamp when the finding was last updated

Implementations

Source

impl Finding

pub fn finding_id(&self) -> &str

Unique identifier for the finding

pub fn agent_space_id(&self) -> &str

Identifier of the agent space that created this finding

pub fn pentest_id(&self) -> Option<&str>

Identifier of the parent pentest

pub fn pentest_job_id(&self) -> Option<&str>

Identifier of the pentest job

pub fn task_id(&self) -> Option<&str>

Identifier of the associated task

pub fn name(&self) -> Option<&str>

Name or title of the finding

pub fn description(&self) -> Option<&str>

Detailed description of the security vulnerability

pub fn status(&self) -> Option<&FindingStatus>

Current status of the finding

pub fn risk_type(&self) -> Option<&str>

Type of security risk identified

pub fn risk_level(&self) -> Option<&RiskLevel>

Severity level of the identified risk

pub fn risk_score(&self) -> Option<&str>

Risk score associated with the finding

pub fn reasoning(&self) -> Option<&str>

Justification for the assigned risk score

pub fn confidence(&self) -> Option<&ConfidenceLevel>

Confidence level of the finding

pub fn attack_script(&self) -> Option<&str>

Proof-of-concept code demonstrating the vulnerability

pub fn code_remediation_task(&self) -> Option<&CodeRemediationTask>

Code remediation task associated with this finding

pub fn last_updated_by(&self) -> Option<&str>

Identifier of the task or agent that last updated this finding

pub fn created_at(&self) -> Option<&DateTime>

Timestamp when the finding was created

pub fn updated_at(&self) -> Option<&DateTime>

Timestamp when the finding was last updated

Source

impl Finding

pub fn builder() -> FindingBuilder

Creates a new builder-style object to manufacture Finding.