#[non_exhaustive]pub struct FindingSummary {
pub finding_id: String,
pub agent_space_id: String,
pub pentest_id: Option<String>,
pub pentest_job_id: Option<String>,
pub name: Option<String>,
pub status: Option<FindingStatus>,
pub risk_type: Option<String>,
pub risk_level: Option<RiskLevel>,
pub confidence: Option<ConfidenceLevel>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Summary information for a security finding
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.finding_id: StringUnique identifier for the finding
agent_space_id: StringIdentifier of the agent space that created this finding
pentest_id: Option<String>Identifier of the parent pentest
pentest_job_id: Option<String>Identifier of the pentest job
name: Option<String>Name or title of the finding
status: Option<FindingStatus>Current status of the finding
risk_type: Option<String>Type of security risk identified
risk_level: Option<RiskLevel>Severity level of the identified risk
confidence: Option<ConfidenceLevel>Confidence level of the finding
created_at: Option<DateTime>Timestamp when the finding was created
updated_at: Option<DateTime>Timestamp when the finding was last updated
Implementations
Sourceimpl FindingSummary
impl FindingSummary
Sourcepub fn finding_id(&self) -> &str
pub fn finding_id(&self) -> &str
Unique identifier for the finding
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
Identifier of the agent space that created this finding
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
Identifier of the parent pentest
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
Identifier of the pentest job
Sourcepub fn status(&self) -> Option<&FindingStatus>
pub fn status(&self) -> Option<&FindingStatus>
Current status of the finding
Sourcepub fn risk_level(&self) -> Option<&RiskLevel>
pub fn risk_level(&self) -> Option<&RiskLevel>
Severity level of the identified risk
Sourcepub fn confidence(&self) -> Option<&ConfidenceLevel>
pub fn confidence(&self) -> Option<&ConfidenceLevel>
Confidence level of the finding
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the finding was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the finding was last updated
Sourceimpl FindingSummary
impl FindingSummary
Sourcepub fn builder() -> FindingSummaryBuilder
pub fn builder() -> FindingSummaryBuilder
Creates a new builder-style object to manufacture FindingSummary.