#[non_exhaustive]pub struct Pentest {
pub pentest_id: String,
pub agent_space_id: String,
pub title: String,
pub assets: Option<Assets>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a pentest configuration and execution details
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_id: StringUnique identifier for the pentest
agent_space_id: StringID of the agent space where the pentest exists
title: StringTitle or name of the pentest
assets: Option<Assets>Collection of assets to be tested or used during the pentest
exclude_risk_types: Option<Vec<RiskType>>A list of risk types excluded from the pentest execution
service_role: Option<String>Service role ARN for accessing customer resources
log_config: Option<CloudWatchLog>CloudWatch log group and stream prefix where pentest execution logs are stored
vpc_config: Option<VpcConfig>VPC configuration that the Security Agent accesses
network_traffic_config: Option<NetworkTrafficConfig>Configuration for network traffic filtering
code_remediation_strategy: Option<CodeRemediationStrategy>Strategy for code remediation on findings
created_at: Option<DateTime>Timestamp when the pentest was created
updated_at: Option<DateTime>Timestamp when the pentest was last updated
Implementations
Sourceimpl Pentest
impl Pentest
Sourcepub fn pentest_id(&self) -> &str
pub fn pentest_id(&self) -> &str
Unique identifier for the pentest
Sourcepub fn agent_space_id(&self) -> &str
pub fn agent_space_id(&self) -> &str
ID of the agent space where the pentest exists
Sourcepub fn assets(&self) -> Option<&Assets>
pub fn assets(&self) -> Option<&Assets>
Collection of assets to be tested or used during the pentest
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
A list of risk types excluded from the pentest execution
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
Service role ARN for accessing customer resources
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
CloudWatch log group and stream prefix where pentest execution logs are stored
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
VPC configuration that the Security Agent accesses
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
Configuration for network traffic filtering
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
Strategy for code remediation on findings
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the pentest was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the pentest was last updated