#[non_exhaustive]pub struct PentestJob {Show 23 fields
pub pentest_job_id: Option<String>,
pub pentest_id: Option<String>,
pub title: Option<String>,
pub overview: Option<String>,
pub status: Option<JobStatus>,
pub endpoints: Option<Vec<Endpoint>>,
pub actors: Option<Vec<Actor>>,
pub documents: Option<Vec<DocumentInfo>>,
pub source_code: Option<Vec<SourceCodeRepository>>,
pub exclude_paths: Option<Vec<Endpoint>>,
pub allowed_domains: Option<Vec<Endpoint>>,
pub exclude_risk_types: Option<Vec<RiskType>>,
pub steps: Option<Vec<Step>>,
pub execution_context: Option<Vec<ExecutionContext>>,
pub service_role: Option<String>,
pub log_config: Option<CloudWatchLog>,
pub vpc_config: Option<VpcConfig>,
pub network_traffic_config: Option<NetworkTrafficConfig>,
pub error_information: Option<ErrorInformation>,
pub integrated_repositories: Option<Vec<IntegratedRepository>>,
pub code_remediation_strategy: Option<CodeRemediationStrategy>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents a pentest job
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pentest_job_id: Option<String>Unique identifier of the pentest job
pentest_id: Option<String>Identifier of the parent pentest
title: Option<String>Title or name of the pentest
overview: Option<String>Overview or description of the pentest job
status: Option<JobStatus>Current status of the pentest job
endpoints: Option<Vec<Endpoint>>List of web application endpoints to test
actors: Option<Vec<Actor>>List of actors that interact with the system
documents: Option<Vec<DocumentInfo>>List of documents providing context for testing
source_code: Option<Vec<SourceCodeRepository>>List of source code repositories for static analysis
exclude_paths: Option<Vec<Endpoint>>List of URL paths to exclude from testing
allowed_domains: Option<Vec<Endpoint>>List of allowed domains for network access
exclude_risk_types: Option<Vec<RiskType>>A list of risk types excluded from the pentest job
steps: Option<Vec<Step>>List of execution steps for the pentest job
execution_context: Option<Vec<ExecutionContext>>A list of execution context messages associated with the pentest job
service_role: Option<String>Service role ARN for accessing customer resources
log_config: Option<CloudWatchLog>CloudWatch log group and stream prefix where pentest job logs are stored
vpc_config: Option<VpcConfig>VPC configuration that the Security Agent accesses
network_traffic_config: Option<NetworkTrafficConfig>Configuration for network traffic filtering
error_information: Option<ErrorInformation>Error information regarding the pentest job
integrated_repositories: Option<Vec<IntegratedRepository>>List of integrated code repositories
code_remediation_strategy: Option<CodeRemediationStrategy>Strategy for code remediation on findings
created_at: Option<DateTime>Timestamp when the pentest job was created
updated_at: Option<DateTime>Timestamp when the pentest job was last updated
Implementations
Sourceimpl PentestJob
impl PentestJob
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
Unique identifier of the pentest job
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
Identifier of the parent pentest
Sourcepub fn endpoints(&self) -> &[Endpoint]
pub fn endpoints(&self) -> &[Endpoint]
List of web application endpoints to test
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .endpoints.is_none().
Sourcepub fn actors(&self) -> &[Actor]
pub fn actors(&self) -> &[Actor]
List of actors that interact with the system
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actors.is_none().
Sourcepub fn documents(&self) -> &[DocumentInfo]
pub fn documents(&self) -> &[DocumentInfo]
List of documents providing context for testing
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .documents.is_none().
Sourcepub fn source_code(&self) -> &[SourceCodeRepository]
pub fn source_code(&self) -> &[SourceCodeRepository]
List of source code repositories for static analysis
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_code.is_none().
Sourcepub fn exclude_paths(&self) -> &[Endpoint]
pub fn exclude_paths(&self) -> &[Endpoint]
List of URL paths to exclude from testing
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_paths.is_none().
Sourcepub fn allowed_domains(&self) -> &[Endpoint]
pub fn allowed_domains(&self) -> &[Endpoint]
List of allowed domains for network access
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_domains.is_none().
Sourcepub fn exclude_risk_types(&self) -> &[RiskType]
pub fn exclude_risk_types(&self) -> &[RiskType]
A list of risk types excluded from the pentest job
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclude_risk_types.is_none().
Sourcepub fn steps(&self) -> &[Step]
pub fn steps(&self) -> &[Step]
List of execution steps for the pentest job
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .steps.is_none().
Sourcepub fn execution_context(&self) -> &[ExecutionContext]
pub fn execution_context(&self) -> &[ExecutionContext]
A list of execution context messages associated with the pentest job
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .execution_context.is_none().
Sourcepub fn service_role(&self) -> Option<&str>
pub fn service_role(&self) -> Option<&str>
Service role ARN for accessing customer resources
Sourcepub fn log_config(&self) -> Option<&CloudWatchLog>
pub fn log_config(&self) -> Option<&CloudWatchLog>
CloudWatch log group and stream prefix where pentest job logs are stored
Sourcepub fn vpc_config(&self) -> Option<&VpcConfig>
pub fn vpc_config(&self) -> Option<&VpcConfig>
VPC configuration that the Security Agent accesses
Sourcepub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
pub fn network_traffic_config(&self) -> Option<&NetworkTrafficConfig>
Configuration for network traffic filtering
Sourcepub fn error_information(&self) -> Option<&ErrorInformation>
pub fn error_information(&self) -> Option<&ErrorInformation>
Error information regarding the pentest job
Sourcepub fn integrated_repositories(&self) -> &[IntegratedRepository]
pub fn integrated_repositories(&self) -> &[IntegratedRepository]
List of integrated code repositories
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrated_repositories.is_none().
Sourcepub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
pub fn code_remediation_strategy(&self) -> Option<&CodeRemediationStrategy>
Strategy for code remediation on findings
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the pentest job was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the pentest job was last updated
Sourceimpl PentestJob
impl PentestJob
Sourcepub fn builder() -> PentestJobBuilder
pub fn builder() -> PentestJobBuilder
Creates a new builder-style object to manufacture PentestJob.