#[non_exhaustive]pub struct TargetDomain {
pub target_domain_id: String,
pub domain_name: String,
pub verification_status: Option<TargetDomainStatus>,
pub verification_details: Option<VerificationDetails>,
pub created_at: Option<DateTime>,
pub verified_at: Option<DateTime>,
}Expand description
Represents a target domain
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_domain_id: StringUnique identifier of the target domain
domain_name: StringName of the registered target domain
verification_status: Option<TargetDomainStatus>Current verification status of the registered target domain
verification_details: Option<VerificationDetails>Verification details to verify registered target domain
created_at: Option<DateTime>Timestamp when the target domain was registered
verified_at: Option<DateTime>Timestamp when the target domain was last successfully verified
Implementations
Sourceimpl TargetDomain
impl TargetDomain
Sourcepub fn target_domain_id(&self) -> &str
pub fn target_domain_id(&self) -> &str
Unique identifier of the target domain
Sourcepub fn domain_name(&self) -> &str
pub fn domain_name(&self) -> &str
Name of the registered target domain
Sourcepub fn verification_status(&self) -> Option<&TargetDomainStatus>
pub fn verification_status(&self) -> Option<&TargetDomainStatus>
Current verification status of the registered target domain
Sourcepub fn verification_details(&self) -> Option<&VerificationDetails>
pub fn verification_details(&self) -> Option<&VerificationDetails>
Verification details to verify registered target domain
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the target domain was registered
Sourcepub fn verified_at(&self) -> Option<&DateTime>
pub fn verified_at(&self) -> Option<&DateTime>
Timestamp when the target domain was last successfully verified
Sourceimpl TargetDomain
impl TargetDomain
Sourcepub fn builder() -> TargetDomainBuilder
pub fn builder() -> TargetDomainBuilder
Creates a new builder-style object to manufacture TargetDomain.