#[non_exhaustive]pub struct TaskSummary {
pub task_id: String,
pub pentest_id: Option<String>,
pub pentest_job_id: Option<String>,
pub agent_space_id: Option<String>,
pub title: Option<String>,
pub risk_type: Option<RiskType>,
pub execution_status: Option<TaskExecutionStatus>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Summary information for a task
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: StringUnique identifier for the task
pentest_id: Option<String>Identifier of the parent pentest
pentest_job_id: Option<String>Identifier of the pentest job this task belongs to
agent_space_id: Option<String>Identifier of the agent space this task belongs to
title: Option<String>Title or name of the task
risk_type: Option<RiskType>Type of security risk this task is designed to test
execution_status: Option<TaskExecutionStatus>Current status of the task execution
created_at: Option<DateTime>Timestamp when the task was created
updated_at: Option<DateTime>Timestamp when the task was last updated
Implementations
Sourceimpl TaskSummary
impl TaskSummary
Sourcepub fn pentest_id(&self) -> Option<&str>
pub fn pentest_id(&self) -> Option<&str>
Identifier of the parent pentest
Sourcepub fn pentest_job_id(&self) -> Option<&str>
pub fn pentest_job_id(&self) -> Option<&str>
Identifier of the pentest job this task belongs to
Sourcepub fn agent_space_id(&self) -> Option<&str>
pub fn agent_space_id(&self) -> Option<&str>
Identifier of the agent space this task belongs to
Sourcepub fn risk_type(&self) -> Option<&RiskType>
pub fn risk_type(&self) -> Option<&RiskType>
Type of security risk this task is designed to test
Sourcepub fn execution_status(&self) -> Option<&TaskExecutionStatus>
pub fn execution_status(&self) -> Option<&TaskExecutionStatus>
Current status of the task execution
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
Timestamp when the task was created
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
Timestamp when the task was last updated
Sourceimpl TaskSummary
impl TaskSummary
Sourcepub fn builder() -> TaskSummaryBuilder
pub fn builder() -> TaskSummaryBuilder
Creates a new builder-style object to manufacture TaskSummary.